@@ -1,4 +1,5 @@
 """Module for getter interface"""
+
 import json
 import os
 import re
@@ -49,6 +50,7 @@ class Getter(ABC):
             validators.deep_iterable(member_validator=validators.instance_of(str)),
         ],
         factory=list,
+        repr=False,
     )
     """used variables in content but not set in environment"""
 
@@ -101,7 +103,7 @@ class Getter(ABC):
         return parsed_events
 
     @abstractmethod
-    def get_raw(self) -> bytearray:
+    def get_raw(self) -> bytes:
         """Get the content.
 
         Returns
