@@ -7,23 +7,24 @@ import hashlib
 import os
 import zlib
 from abc import abstractmethod
-from functools import partial
+from copy import deepcopy
+from functools import cached_property, partial
 from hmac import HMAC
-from typing import TYPE_CHECKING, Optional, Tuple
+from typing import Optional, Tuple
+from zoneinfo import ZoneInfo
 
 from attrs import define, field, validators
 
 from logprep.abc.connector import Connector
+from logprep.abc.exceptions import LogprepException
 from logprep.metrics.metrics import Metric
-from logprep.util.helper import add_field_to, get_dotted_field_value
+from logprep.processor.base.exceptions import FieldExistsWarning
+from logprep.util.helper import add_fields_to, get_dotted_field_value
 from logprep.util.time import UTC, TimeParser
 from logprep.util.validators import dict_structure_validator
 
-if TYPE_CHECKING:  # pragma: no cover
-    from logprep.abc.output import Output
 
-
-class InputError(Exception):
+class InputError(LogprepException):
     """Base class for Input related exceptions."""
 
     def __init__(self, input_connector: "Input", message: str) -> None:
@@ -35,8 +36,11 @@ class CriticalInputError(InputError):
     """A significant error occurred - log and don't process the event."""
 
     def __init__(self, input_connector: "Input", message, raw_input):
-        self.raw_input = raw_input
-        super().__init__(input_connector, f"{message} -> {raw_input}")
+        super().__init__(
+            input_connector, f"{message} -> event was written to error output if configured"
+        )
+        self.raw_input = deepcopy(raw_input)  # is written to error output
+        self.message = message
 
 
 class CriticalInputParsingError(CriticalInputError):
@@ -47,7 +51,7 @@ class FatalInputError(InputError):
     """Must not be catched."""
 
 
-class InputWarning(Exception):
+class InputWarning(LogprepException):
     """May be catched but must be displayed to the user/logged."""
 
     def __init__(self, input_connector: "Input", message: str) -> None:
@@ -84,12 +88,12 @@ class HmacConfig:
 
 @define(kw_only=True)
 class TimeDeltaConfig:
-    """TimeDetla Configurations
+    """TimeDelta Configurations
     Works only if the preprocessor log_arrival_time_target_field is set."""
 
-    target_field: field(validator=[validators.instance_of(str), lambda _, __, x: bool(x)])
+    target_field: str = field(validator=(validators.instance_of(str), lambda _, __, x: bool(x)))
     """Defines the fieldname to which the time difference should be written to."""
-    reference_field: field(validator=[validators.instance_of(str), lambda _, __, x: bool(x)])
+    reference_field: str = field(validator=(validators.instance_of(str), lambda _, __, x: bool(x)))
     """Defines a field with a timestamp that should be used for the time difference.
     The calculation will be the arrival time minus the time of this reference field."""
 
@@ -182,10 +186,6 @@ class Input(Connector):
             },
         )
 
-    pipeline_index: int
-    output_connector: Optional["Output"]
-    __slots__ = ["pipeline_index", "output_connector"]
-
     @property
     def _add_hmac(self):
         """Check and return if a hmac should be added or not."""
@@ -199,6 +199,11 @@ class Input(Connector):
         """Check and return if the version info should be added to the event."""
         return bool(self._config.preprocessing.get("version_info_target_field"))
 
+    @cached_property
+    def _log_arrival_timestamp_timezone(self):
+        """Returns the timezone for log arrival timestamps"""
+        return ZoneInfo("UTC")
+
     @property
     def _add_log_arrival_time_information(self):
         """Check and return if the log arrival time info should be added to the event."""
@@ -228,7 +233,7 @@ class Input(Connector):
         """Check and return if the env enrichment should be added to the event."""
         return bool(self._config.preprocessing.get("enrich_by_env_variables"))
 
-    def _get_raw_event(self, timeout: float) -> bytearray:  # pylint: disable=unused-argument
+    def _get_raw_event(self, timeout: float) -> bytes | None:  # pylint: disable=unused-argument
         """Implements the details how to get the raw event
 
         Parameters
@@ -258,7 +263,7 @@ class Input(Connector):
         """
 
     @Metric.measure_time()
-    def get_next(self, timeout: float) -> Tuple[Optional[dict], Optional[str]]:
+    def get_next(self, timeout: float) -> dict | None:
         """Return the next document
 
         Parameters
@@ -277,23 +282,25 @@ class Input(Connector):
             After timeout (usually a fraction of seconds) if no input data was available by then.
         """
         event, raw_event = self._get_event(timeout)
-        non_critical_error_msg = None
         if event is None:
-            return None, None
+            return None
         self.metrics.number_of_processed_events += 1
         if not isinstance(event, dict):
             raise CriticalInputError(self, "not a dict", event)
-        if self._add_hmac:
-            event, non_critical_error_msg = self._add_hmac_to(event, raw_event)
-        if self._add_version_info:
-            self._add_version_information_to_event(event)
-        if self._add_log_arrival_time_information:
-            self._add_arrival_time_information_to_event(event)
-        if self._add_log_arrival_timedelta_information:
-            self._add_arrival_timedelta_information_to_event(event)
-        if self._add_env_enrichment:
-            self._add_env_enrichment_to_event(event)
-        return event, non_critical_error_msg
+        try:
+            if self._add_hmac:
+                event = self._add_hmac_to(event, raw_event)
+            if self._add_version_info:
+                self._add_version_information_to_event(event)
+            if self._add_log_arrival_time_information:
+                self._add_arrival_time_information_to_event(event)
+            if self._add_log_arrival_timedelta_information:
+                self._add_arrival_timedelta_information_to_event(event)
+            if self._add_env_enrichment:
+                self._add_env_enrichment_to_event(event)
+        except FieldExistsWarning as error:
+            raise CriticalInputError(self, error.args[0], event) from error
+        return event
 
     def batch_finished_callback(self):
         """Can be called by output connectors after processing a batch of one or more records."""
@@ -303,13 +310,28 @@ class Input(Connector):
         enrichments = self._config.preprocessing.get("enrich_by_env_variables")
         if not enrichments:
             return
-        for target_field, variable_name in enrichments.items():
-            add_field_to(event, target_field, os.environ.get(variable_name, ""))
+        fields = {
+            target: os.environ.get(variable_name, "")
+            for target, variable_name in enrichments.items()
+        }
+        add_fields_to(event, fields)
 
     def _add_arrival_time_information_to_event(self, event: dict):
-        now = TimeParser.now()
-        target_field = self._config.preprocessing.get("log_arrival_time_target_field")
-        add_field_to(event, target_field, now.isoformat())
+        target = self._config.preprocessing.get("log_arrival_time_target_field")
+        time = TimeParser.now(self._log_arrival_timestamp_timezone).isoformat()
+        try:
+            add_fields_to(event, {target: time})
+        except FieldExistsWarning as error:
+            if len(target.split(".")) == 1:
+                raise error
+            original_target = target
+            target_value = get_dotted_field_value(event, target)
+            while target_value is None:
+                target, _, _ = target.rpartition(".")
+                target_value = get_dotted_field_value(event, target)
+            add_fields_to(event, {original_target: time}, overwrite_target=True)
+            add_fields_to(event, {f"{target}.@original": target_value})
+            assert True
 
     def _add_arrival_timedelta_information_to_event(self, event: dict):
         log_arrival_timedelta_config = self._config.preprocessing.get("log_arrival_timedelta")
@@ -325,16 +347,16 @@ class Input(Connector):
                 TimeParser.from_string(log_arrival_time).astimezone(UTC)
                 - TimeParser.from_string(time_reference).astimezone(UTC)
             ).total_seconds()
-            add_field_to(event, target_field, delta_time_sec)
+            add_fields_to(event, fields={target_field: delta_time_sec})
 
     def _add_version_information_to_event(self, event: dict):
         """Add the version information to the event"""
         target_field = self._config.preprocessing.get("version_info_target_field")
         # pylint: disable=protected-access
-        add_field_to(event, target_field, self._config._version_information)
+        add_fields_to(event, fields={target_field: self._config._version_information})
         # pylint: enable=protected-access
 
-    def _add_hmac_to(self, event_dict, raw_event) -> Tuple[dict, str]:
+    def _add_hmac_to(self, event_dict, raw_event) -> dict:
         """
         Calculates an HMAC (Hash-based message authentication code) based on a given target field
         and adds it to the given event. If the target field has the value '<RAW_MSG>' the full raw
@@ -355,10 +377,15 @@ class Input(Connector):
         event_dict: dict
             The original event extended with a field that has the hmac and the corresponding target
             field, which was used to calculate the hmac.
+
+        Raises
+        ------
+        CriticalInputError
+            If the hmac could not be added to the event because the desired output field already
+            exists or can't be found.
         """
         hmac_options = self._config.preprocessing.get("hmac", {})
         hmac_target_field_name = hmac_options.get("target")
-        non_critical_error_msg = None
 
         if raw_event is None:
             raw_event = self._encoder.encode(event_dict)
@@ -369,32 +396,21 @@ class Input(Connector):
             received_orig_message = get_dotted_field_value(event_dict, hmac_target_field_name)
 
         if received_orig_message is None:
-            hmac = "error"
-            received_orig_message = (
-                f"<expected hmac target field '{hmac_target_field_name}' not found>".encode()
-            )
-            non_critical_error_msg = (
-                f"Couldn't find the hmac target " f"field '{hmac_target_field_name}'"
-            )
-        else:
-            if isinstance(received_orig_message, str):
-                received_orig_message = received_orig_message.encode("utf-8")
-            hmac = HMAC(
-                key=hmac_options.get("key").encode(),
-                msg=received_orig_message,
-                digestmod=hashlib.sha256,
-            ).hexdigest()
+            error_message = f"Couldn't find the hmac target field '{hmac_target_field_name}'"
+            raise CriticalInputError(self, error_message, raw_event)
+        if isinstance(received_orig_message, str):
+            received_orig_message = received_orig_message.encode("utf-8")
+        hmac = HMAC(
+            key=hmac_options.get("key").encode(),
+            msg=received_orig_message,
+            digestmod=hashlib.sha256,
+        ).hexdigest()
         compressed = zlib.compress(received_orig_message, level=-1)
-        hmac_output = {"hmac": hmac, "compressed_base64": base64.b64encode(compressed).decode()}
-        add_was_successful = add_field_to(
-            event_dict,
-            hmac_options.get("output_field"),
-            hmac_output,
-        )
-        if not add_was_successful:
-            non_critical_error_msg = (
-                f"Couldn't add the hmac to the input event as the desired "
-                f"output field '{hmac_options.get('output_field')}' already "
-                f"exist."
-            )
-        return event_dict, non_critical_error_msg
+        new_field = {
+            hmac_options.get("output_field"): {
+                "hmac": hmac,
+                "compressed_base64": base64.b64encode(compressed).decode(),
+            }
+        }
+        add_fields_to(event_dict, new_field)
+        return event_dict
