@@ -3,16 +3,16 @@ New output endpoint types are created by implementing it.
 """
 
 from abc import abstractmethod
-from logging import Logger
-from typing import Optional
+from copy import deepcopy
+from typing import Any, Optional
 
 from attrs import define, field, validators
 
 from logprep.abc.connector import Connector
-from logprep.abc.input import Input
+from logprep.abc.exceptions import LogprepException
 
 
-class OutputError(Exception):
+class OutputError(LogprepException):
     """Base class for Output related exceptions."""
 
     def __init__(self, output: "Output", message: str) -> None:
@@ -20,7 +20,7 @@ class OutputError(Exception):
         super().__init__(f"{self.__class__.__name__} in {output.describe()}: {message}")
 
 
-class OutputWarning(Exception):
+class OutputWarning(LogprepException):
     """Base class for Output related warnings."""
 
     def __init__(self, output: "Output", message: str) -> None:
@@ -31,14 +31,16 @@ class OutputWarning(Exception):
 class CriticalOutputError(OutputError):
     """A significant error occurred - log and don't process the event."""
 
-    def __init__(self, output, message, raw_input):
-        if raw_input:
-            output.store_failed(str(self), raw_input, {})
-        super().__init__(output, f"{message} for event: {raw_input}")
+    __match_args__ = ("raw_input",)
+
+    def __init__(self, output: "Output", message: str, raw_input: Any) -> None:
+        super().__init__(output, f"{message} -> event was written to error output if configured")
+        self.raw_input = deepcopy(raw_input)
+        self.message = message
 
 
 class FatalOutputError(OutputError):
-    """Must not be catched."""
+    """Must not be caught."""
 
 
 class Output(Connector):
@@ -53,10 +55,6 @@ class Output(Connector):
         But this output can be called as output for extra_data.
         """
 
-    __slots__ = {"input_connector"}
-
-    input_connector: Optional[Input]
-
     @property
     def default(self):
         """returns the default parameter"""
@@ -72,8 +70,8 @@ class Output(Connector):
             "name": self.name,
         }
 
-    def __init__(self, name: str, configuration: "Connector.Config", logger: Logger):
-        super().__init__(name, configuration, logger)
+    def __init__(self, name: str, configuration: "Connector.Config"):
+        super().__init__(name, configuration)
         self.input_connector = None
 
     @abstractmethod
@@ -90,6 +88,5 @@ class Output(Connector):
     def store_custom(self, document: dict, target: str):
         """Store additional data in a custom location inside the output destination."""
 
-    @abstractmethod
-    def store_failed(self, error_message: str, document_received: dict, document_processed: dict):
-        """Store an event when an error occurred during the processing."""
+    def _write_backlog(self):
+        """Write the backlog to the output destination."""
