@@ -28,10 +28,12 @@ Example
             auto.offset.reset: "earliest"
 """
 # pylint: enable=line-too-long
+import logging
+import os
 from functools import cached_property, partial
-from logging import Logger
 from socket import getfqdn
-from typing import Callable, Optional, Tuple, Union
+from types import MappingProxyType
+from typing import Optional, Tuple, Union
 
 import msgspec
 from attrs import define, field, validators
@@ -42,8 +44,10 @@ from confluent_kafka import (
     OFFSET_STORED,
     Consumer,
     KafkaException,
+    Message,
     TopicPartition,
 )
+from confluent_kafka.admin import AdminClient
 
 from logprep.abc.connector import Connector
 from logprep.abc.input import (
@@ -75,6 +79,8 @@ SPECIAL_OFFSETS = {
 
 DEFAULT_RETURN = 0
 
+logger = logging.getLogger("KafkaInput")
+
 
 class ConfluentKafkaInput(Input):
     """A kafka input connector."""
@@ -209,15 +215,16 @@ class ConfluentKafkaInput(Input):
         topic: str = field(validator=validators.instance_of(str))
         """The topic from which new log messages will be fetched."""
 
-        kafka_config: Optional[dict] = field(
+        kafka_config: Optional[MappingProxyType] = field(
             validator=[
-                validators.instance_of(dict),
+                validators.instance_of(MappingProxyType),
                 validators.deep_mapping(
                     key_validator=validators.instance_of(str),
                     value_validator=validators.instance_of(str),
                 ),
                 partial(keys_in_validator, expected_keys=["bootstrap.servers", "group.id"]),
-            ]
+            ],
+            converter=MappingProxyType,
         )
         """ Kafka configuration for the kafka client.
         At minimum the following keys must be set:
@@ -225,21 +232,67 @@ class ConfluentKafkaInput(Input):
         - bootstrap.servers (STRING): a comma separated list of kafka brokers
         - group.id (STRING): a unique identifier for the consumer group
 
-        For additional configuration options and their description see:
-        <https://github.com/edenhill/librdkafka/blob/master/CONFIGURATION.md>
+        The following keys are injected by the connector and should not be set:
+
+        - "enable.auto.offset.store" is set to "false",
+        - "enable.auto.commit" is set to "true",
+
+        For additional configuration options see the official:
+        `librdkafka configuration <https://github.com/edenhill/librdkafka/blob/master/CONFIGURATION.md>`_.
 
         .. datatemplate:import-module:: logprep.connector.confluent_kafka.input
             :template: defaults-renderer.tmpl
 
         """
 
-    _last_valid_records: dict
+    _last_valid_record: Message
 
-    __slots__ = ["_last_valid_records"]
+    __slots__ = ["_last_valid_record"]
 
-    def __init__(self, name: str, configuration: "Connector.Config", logger: Logger) -> None:
-        super().__init__(name, configuration, logger)
-        self._last_valid_records = {}
+    def __init__(self, name: str, configuration: "Connector.Config") -> None:
+        super().__init__(name, configuration)
+        self._last_valid_record = None
+
+    @property
+    def _kafka_config(self) -> dict:
+        """Get the kafka configuration.
+
+        Returns
+        -------
+        dict
+            The kafka configuration.
+        """
+        injected_config = {
+            "logger": logger,
+            "enable.auto.offset.store": "false",
+            "enable.auto.commit": "true",
+            "on_commit": self._commit_callback,
+            "stats_cb": self._stats_callback,
+            "error_cb": self._error_callback,
+        }
+        DEFAULTS.update({"client.id": getfqdn()})
+        DEFAULTS.update(
+            {
+                "group.instance.id": f"{getfqdn().strip('.')}-"
+                f"Pipeline{self.pipeline_index}-pid{os.getpid()}"
+            }
+        )
+        return DEFAULTS | self._config.kafka_config | injected_config
+
+    @cached_property
+    def _admin(self) -> AdminClient:
+        """configures and returns the admin client
+
+        Returns
+        -------
+        AdminClient
+            confluent_kafka admin client object
+        """
+        admin_config = {"bootstrap.servers": self._config.kafka_config["bootstrap.servers"]}
+        for key, value in self._config.kafka_config.items():
+            if key.startswith(("security.", "ssl.")):
+                admin_config[key] = value
+        return AdminClient(admin_config)
 
     @cached_property
     def _consumer(self) -> Consumer:
@@ -250,22 +303,7 @@ class ConfluentKafkaInput(Input):
         Consumer
             confluent_kafka consumer object
         """
-        injected_config = {
-            "logger": self._logger,
-            "on_commit": self._commit_callback,
-            "stats_cb": self._stats_callback,
-            "error_cb": self._error_callback,
-        }
-        DEFAULTS.update({"client.id": getfqdn()})
-        self._config.kafka_config = DEFAULTS | self._config.kafka_config
-        consumer = Consumer(self._config.kafka_config | injected_config)
-        consumer.subscribe(
-            [self._config.topic],
-            on_assign=self._assign_callback,
-            on_revoke=self._revoke_callback,
-            on_lost=self._lost_callback,
-        )
-        return consumer
+        return Consumer(self._kafka_config)
 
     def _error_callback(self, error: KafkaException) -> None:
         """Callback for generic/global error events, these errors are typically
@@ -278,7 +316,7 @@ class ConfluentKafkaInput(Input):
             the error that occurred
         """
         self.metrics.number_of_errors += 1
-        self._logger.error(f"{self.describe()}: {error}")
+        logger.error(f"{self.describe()}: {error}")
 
     def _stats_callback(self, stats: str) -> None:
         """Callback for statistics data. This callback is triggered by poll()
@@ -341,7 +379,8 @@ class ConfluentKafkaInput(Input):
             if offset in SPECIAL_OFFSETS:
                 offset = 0
             labels = {
-                "description": f"topic: {self._config.topic} - partition: {topic_partition.partition}"
+                "description": f"topic: {self._config.topic} - "
+                f"partition: {topic_partition.partition}"
             }
             self.metrics.committed_offsets.add_with_labels(offset, labels)
 
@@ -383,9 +422,9 @@ class ConfluentKafkaInput(Input):
         kafka_error = message.error()
         if kafka_error:
             raise CriticalInputError(
-                self, "A confluent-kafka record contains an error code", kafka_error
+                self, "A confluent-kafka record contains an error code", str(kafka_error)
             )
-        self._last_valid_records[message.partition()] = message
+        self._last_valid_record = message
         labels = {"description": f"topic: {self._config.topic} - partition: {message.partition()}"}
         self.metrics.current_offsets.add_with_labels(message.offset() + 1, labels)
         return message.value()
@@ -414,7 +453,11 @@ class ConfluentKafkaInput(Input):
         if raw_event is None:
             return None, None
         try:
-            event_dict = self._decoder.decode(raw_event)
+            event_dict = self._decoder.decode(raw_event.decode("utf-8"))
+        except UnicodeDecodeError as error:
+            raise CriticalInputParsingError(
+                self, "Input record value is not 'utf-8' encoded", str(raw_event)
+            ) from error
         except msgspec.DecodeError as error:
             raise CriticalInputParsingError(
                 self, "Input record value is not a valid json string", raw_event
@@ -430,31 +473,28 @@ class ConfluentKafkaInput(Input):
         return self._config.kafka_config.get("enable.auto.commit") == "true"
 
     def batch_finished_callback(self) -> None:
-        """Store offsets for each kafka partition in `self._last_valid_records`
-        and if configured commit them. Should be called by output connectors if
-        they are finished processing a batch of records.
+        """Store offsets for last message referenced by `self._last_valid_records`.
+        Should be called after delivering the current message to the output or error queue.
         """
         if self._enable_auto_offset_store:
             return
-        self._handle_offsets(self._consumer.store_offsets)
-        if not self._enable_auto_commit:
-            self._handle_offsets(self._consumer.commit)
-        self._last_valid_records.clear()
-
-    def _handle_offsets(self, offset_handler: Callable) -> None:
-        for message in self._last_valid_records.values():
-            try:
-                offset_handler(message=message)
-            except KafkaException as error:
-                raise InputWarning(self, f"{error}, {message}") from error
+        # in case the ConfluentKafkaInput._revoke_callback is triggered before the first message
+        # was polled
+        if not self._last_valid_record:
+            return
+        try:
+            self._consumer.store_offsets(message=self._last_valid_record)
+        except KafkaException as error:
+            raise InputWarning(self, f"{error}, {self._last_valid_record}") from error
 
     def _assign_callback(self, consumer, topic_partitions):
         for topic_partition in topic_partitions:
             offset, partition = topic_partition.offset, topic_partition.partition
-            self._logger.info(
-                f"{consumer.memberid()} was assigned to "
-                f"topic: {topic_partition.topic} | "
-                f"partition {partition}"
+            logger.info(
+                "%s was assigned to topic: %s | partition %s",
+                consumer.memberid(),
+                topic_partition.topic,
+                partition,
             )
             if offset in SPECIAL_OFFSETS:
                 offset = 0
@@ -466,34 +506,58 @@ class ConfluentKafkaInput(Input):
     def _revoke_callback(self, consumer, topic_partitions):
         for topic_partition in topic_partitions:
             self.metrics.number_of_warnings += 1
-            self._logger.warning(
-                f"{consumer.memberid()} to be revoked from "
-                f"topic: {topic_partition.topic} | "
-                f"partition {topic_partition.partition}"
+            logger.warning(
+                "%s to be revoked from topic: %s | partition %s",
+                consumer.memberid(),
+                topic_partition.topic,
+                topic_partition.partition,
             )
-        self.output_connector._write_backlog()
         self.batch_finished_callback()
 
     def _lost_callback(self, consumer, topic_partitions):
         for topic_partition in topic_partitions:
             self.metrics.number_of_warnings += 1
-            self._logger.warning(
-                f"{consumer.memberid()} has lost "
-                f"topic: {topic_partition.topic} | "
-                f"partition {topic_partition.partition}"
-                "- try to reassign"
+            logger.warning(
+                "%s has lost topic: %s | partition %s - try to reassign",
+                consumer.memberid(),
+                topic_partition.topic,
+                topic_partition.partition,
             )
-            topic_partition.offset = OFFSET_STORED
-        self._consumer.assign(topic_partitions)
-
-    def setup(self) -> None:
-        super().setup()
-        try:
-            _ = self._consumer
-        except (KafkaException, ValueError) as error:
-            raise FatalInputError(self, str(error)) from error
 
     def shut_down(self) -> None:
         """Close consumer, which also commits kafka offsets."""
         self._consumer.close()
         super().shut_down()
+
+    def health(self) -> bool:
+        """Check the health of the component.
+
+        Returns
+        -------
+        bool
+            True if the component is healthy, False otherwise.
+        """
+
+        try:
+            metadata = self._admin.list_topics(timeout=self._config.health_timeout)
+            if not self._config.topic in metadata.topics:
+                logger.error("Topic  '%s' does not exit", self._config.topic)
+                return False
+        except KafkaException as error:
+            logger.error("Health check failed: %s", error)
+            self.metrics.number_of_errors += 1
+            return False
+        return super().health()
+
+    def setup(self) -> None:
+        """Set the component up."""
+        try:
+            self._consumer.subscribe(
+                [self._config.topic],
+                on_assign=self._assign_callback,
+                on_revoke=self._revoke_callback,
+                on_lost=self._lost_callback,
+            )
+            super().setup()
+        except KafkaException as error:
+            raise FatalInputError(self, f"Could not setup kafka consumer: {error}") from error
