@@ -1,6 +1,4 @@
 """This module contains a factory to create connectors and processors."""
-import copy
-from typing import TYPE_CHECKING
 
 from logprep.abc.component import Component
 from logprep.configuration import Configuration
@@ -9,15 +7,12 @@ from logprep.factory_error import (
     InvalidConfigurationError,
 )
 
-if TYPE_CHECKING:  # pragma: no cover
-    from logging import Logger
-
 
 class Factory:
     """Create components for logprep."""
 
     @classmethod
-    def create(cls, configuration: dict, logger: "Logger") -> Component:
+    def create(cls, configuration: dict) -> Component | None:
         """Create component."""
         if configuration == {} or configuration is None:
             raise InvalidConfigurationError("The component definition is empty.")
@@ -35,12 +30,9 @@ class Factory:
                 )
             if not isinstance(component_configuration_dict, dict):
                 raise InvalidConfigSpecificationError(component_name)
-            metric_labels = {}
-            if "metric_labels" in configuration[component_name]:
-                metric_labels = configuration[component_name].pop("metric_labels")
             component = Configuration.get_class(component_name, component_configuration_dict)
             component_configuration = Configuration.create(
                 component_name, component_configuration_dict
             )
-            component_configuration.metric_labels = copy.deepcopy(metric_labels)
-            return component(component_name, component_configuration, logger)
+            return component(component_name, component_configuration)
+        return None
