@@ -2,13 +2,14 @@
 
 from typing import TYPE_CHECKING, Any, List
 
+from logprep.abc.exceptions import LogprepException
 from logprep.factory_error import FactoryError
 
 if TYPE_CHECKING:  # pragma: no cover
     from logprep.processor.base.rule import Rule
 
 
-class RuleError(BaseException):
+class RuleError(LogprepException):
     """Base class for Rule related exceptions."""
 
 
@@ -48,7 +49,7 @@ class SkipImportError(FactoryError):
             super().__init__("Processor can't be imported")
 
 
-class ProcessingError(Exception):
+class ProcessingError(LogprepException):
     """Base class for exceptions related to processing events."""
 
     def __init__(self, message: str, rule: "Rule"):
@@ -59,27 +60,30 @@ class ProcessingError(Exception):
 class ProcessingCriticalError(ProcessingError):
     """A critical error occurred - stop processing of this event"""
 
-    def __init__(self, message: str, rule: "Rule", event: dict):
-        message = (
-            f"{message} -> event was send to error output and further processing stopped"
-            f", {rule.id=}, {rule.description=}, {event=}"
-        )
-        super().__init__(f"{self.__class__.__name__}: {message}", rule)
+    def __init__(self, message: str, rule: "Rule"):
+        message = f"'{message}' -> rule.id: '{rule.id}'"
+        full_message = f"{message} -> event was send to error output and further processing stopped"
+        super().__init__(f"{self.__class__.__name__}: {full_message}", rule)
+        self.message = message
 
 
 class ProcessingWarning(Warning):
     """A warning occurred - log the warning, but continue processing the event."""
 
-    def __init__(self, message: str, rule: "Rule", event: dict):
-        rule.metrics.number_of_warnings += 1
-        message = f"{message}, {rule.id=}, {rule.description=}, {event=}"
+    def __init__(self, message: str, rule: "Rule | None", event: dict, tags: List[str] = None):
+        self.tags = tags if tags else []
+        if rule:
+            rule.metrics.number_of_warnings += 1
+            message += f", {rule.id=}, {rule.description=}"
+        message += f", {event=}"
         super().__init__(f"{self.__class__.__name__}: {message}")
 
 
 class FieldExistsWarning(ProcessingWarning):
     """Raised if field already exists."""
 
-    def __init__(self, rule: "Rule", event: dict, skipped_fields: List[str]):
+    def __init__(self, rule: "Rule | None", event: dict, skipped_fields: List[str]):
+        self.skipped_fields = skipped_fields
         message = (
             "The following fields could not be written, because "
             "one or more subfields existed and could not be extended: "
