@@ -86,6 +86,7 @@ retrieved from a field with the schema :code:`${your.dotted.field}`:
 The calc expression is not whitespace sensitive.
 
 """
+
 import re
 
 from attrs import define, field, validators
@@ -100,13 +101,11 @@ class CalculatorRule(FieldManagerRule):
     class Config(FieldManagerRule.Config):
         """Config for Calculator"""
 
-        calc: str = field(
-            validator=[validators.instance_of(str), validators.min_len(3)],
-        )
+        calc: str = field(validator=(validators.instance_of(str), validators.min_len(3)))
         """The calculation expression. Fields from the event can be used by
         surrounding them with :code:`${` and :code:`}`."""
         source_fields: list = field(factory=list, init=False, repr=False, eq=False)
-        extend_target_list: bool = field(validator=validators.instance_of(bool), default=False)
+        merge_with_target: bool = field(validator=validators.instance_of(bool), default=False)
         """If the target field exists and is a list, the list will be extended with the values
         of the source fields.
         """
