@@ -12,10 +12,8 @@ Processor Configuration
 
     - datetimeextractorname:
         type: datetime_extractor
-        specific_rules:
-            - tests/testdata/rules/specific/
-        generic_rules:
-            - tests/testdata/rules/generic/
+        rules:
+            - tests/testdata/rules/rules
 
 .. autoclass:: logprep.processor.datetime_extractor.processor.DatetimeExtractor.Config
    :members:
@@ -28,20 +26,13 @@ Processor Configuration
 
 from datetime import datetime
 
-from logprep.abc.processor import Processor
 from logprep.processor.datetime_extractor.rule import DatetimeExtractorRule
+from logprep.processor.field_manager.processor import FieldManager
 from logprep.util.helper import get_dotted_field_value
 from logprep.util.time import TimeParser
 
 
-class DateTimeExtractorError(BaseException):
-    """Base class for DateTimeExtractor related exceptions."""
-
-    def __init__(self, name: str, message: str):
-        super().__init__(f"DateTimeExtractor ({name}): {message}")
-
-
-class DatetimeExtractor(Processor):
+class DatetimeExtractor(FieldManager):
     """Split timestamps into fields containing their parts."""
 
     _local_timezone_name: str
@@ -60,7 +51,10 @@ class DatetimeExtractor(Processor):
         datetime_field = rule.source_fields[0]
         destination_field = rule.target_field
 
-        if destination_field and self._field_exists(event, datetime_field):
+        if self._handle_missing_fields(event, rule, rule.source_fields, [datetime_field]):
+            return
+
+        if destination_field:
             datetime_value = get_dotted_field_value(event, datetime_field)
 
             parsed_timestamp = TimeParser.from_string(datetime_value)
