@@ -12,10 +12,8 @@ Processor Configuration
 
     - droppername:
         type: dropper
-        specific_rules:
-            - tests/testdata/rules/specific/
-        generic_rules:
-            - tests/testdata/rules/generic/
+        rules:
+            - tests/testdata/rules/rules
 
 .. autoclass:: logprep.processor.dropper.processor.Dropper.Config
    :members:
