@@ -1,6 +1,6 @@
 """
-Dropper
-=======
+Rule Configuration
+^^^^^^^^^^^^^^^^^^
 
 Which fields are removed is defined in the additional field :code:`drop`.
 It contains a list of fields in dot notation.
@@ -40,14 +40,20 @@ the fields :code:`keep_me` and :code:`keep_me.keep_me_too` are kept.
             "keep_me_too": "something"
         }
     }]
+
+.. autoclass:: logprep.processor.dropper.rule.DropperRule.Config
+   :members:
+   :undoc-members:
+   :inherited-members:
+   :noindex:
 """
 
 from typing import List
-import warnings
+
 from attrs import define, field, validators
 
 from logprep.processor.base.rule import Rule
-from logprep.util.helper import pop_dotted_field_value, add_and_overwrite
+from logprep.util.helper import get_dotted_field_value
 
 
 class DropperRule(Rule):
@@ -62,19 +68,10 @@ class DropperRule(Rule):
         drop_full: bool = field(validator=validators.instance_of(bool), default=True)
         """Drop recursive? defaults to [True]"""
 
-    @classmethod
-    def normalize_rule_dict(cls, rule: dict) -> None:
-        if rule.get("dropper") is None:
-            drop_fields = pop_dotted_field_value(rule, "drop")
-            if drop_fields is not None:
-                add_and_overwrite(rule, "dropper.drop", drop_fields)
-                warnings.warn("drop is deprecated. Use dropper.drop instead", DeprecationWarning)
-            drop_full = pop_dotted_field_value(rule, "drop_full")
-            if drop_full is not None:
-                add_and_overwrite(rule, "dropper.drop_full", drop_full)
-                warnings.warn(
-                    "drop_full is deprecated. Use dropper.drop_full instead", DeprecationWarning
-                )
+        def __attrs_post_init__(self):
+            # to ensure no split operations during processing
+            for dotted_field in self.drop:  # pylint: disable=not-an-iterable
+                get_dotted_field_value({}, dotted_field)
 
     @property
     def fields_to_drop(self) -> List[str]:
