@@ -11,10 +11,8 @@ Processor Configuration
 
     - geoipenrichername:
         type: geoip_enricher
-        specific_rules:
-            - tests/testdata/geoip_enricher/rules/
-        generic_rules:
-            - tests/testdata/geoip_enricher/rules/
+        rules:
+            - tests/testdata/geoip_enricher/rules
         db_path: /path/to/GeoLite2-City.mmdb
 
 .. autoclass:: logprep.processor.geoip_enricher.processor.GeoipEnricher.Config
@@ -25,6 +23,8 @@ Processor Configuration
 
 .. automodule:: logprep.processor.geoip_enricher.rule
 """
+
+import logging
 import os
 import tempfile
 from functools import cached_property
@@ -36,18 +36,19 @@ from filelock import FileLock
 from geoip2 import database
 from geoip2.errors import AddressNotFoundError
 
-from logprep.abc.processor import Processor
-from logprep.processor.base.exceptions import FieldExistsWarning, ProcessingWarning
+from logprep.processor.field_manager.processor import FieldManager
 from logprep.processor.geoip_enricher.rule import GEOIP_DATA_STUBS, GeoipEnricherRule
 from logprep.util.getter import GetterFactory
-from logprep.util.helper import add_field_to, get_dotted_field_value
+from logprep.util.helper import add_fields_to, get_dotted_field_value
+
+logger = logging.getLogger("GeoipEnricher")
 
 
-class GeoipEnricher(Processor):
+class GeoipEnricher(FieldManager):
     """Resolve values in documents by referencing a mapping list."""
 
     @define(kw_only=True)
-    class Config(Processor.Config):
+    class Config(FieldManager.Config):
         """geoip_enricher config"""
 
         db_path: str = field(validator=validators.instance_of(str))
@@ -64,13 +65,9 @@ class GeoipEnricher(Processor):
 
     @cached_property
     def _city_db(self):
-        return database.Reader(self._config.db_path)
-
-    def setup(self):
-        super().setup()
         db_path = Path(self._config.db_path)
         if not db_path.exists():
-            self._logger.debug("start geoip database download...")
+            logger.debug("start geoip database download...")
             logprep_tmp_dir = Path(tempfile.gettempdir()) / "logprep"
             os.makedirs(logprep_tmp_dir, exist_ok=True)
             db_path_file = logprep_tmp_dir / f"{self.name}.mmdb"
@@ -80,8 +77,13 @@ class GeoipEnricher(Processor):
                     db_path_file.write_bytes(
                         GetterFactory.from_string(str(self._config.db_path)).get_raw()
                     )
-            self._logger.debug("finished geoip database download.")
-            self._config.db_path = str(db_path_file.absolute())
+            db_path = str(db_path_file.absolute())
+            logger.debug("finished geoip database download.")
+        return database.Reader(db_path)
+
+    def setup(self):
+        super().setup()
+        _ = self._city_db  # trigger download
 
     def _try_getting_geoip_data(self, ip_string):
         try:
@@ -119,25 +121,19 @@ class GeoipEnricher(Processor):
 
     def _apply_rules(self, event, rule):
         ip_string = get_dotted_field_value(event, rule.source_fields[0])
-        if ip_string is None:
-            raise ProcessingWarning(
-                f"Value of IP field '{rule.source_fields[0]}' is 'None'", rule, event
-            )
+        if self._handle_missing_fields(event, rule, rule.source_fields, [ip_string]):
+            return
         geoip_data = self._try_getting_geoip_data(ip_string)
         if not geoip_data:
             return
-        for target_subfield, value in geoip_data.items():
-            if value is None:
-                continue
-            full_output_field = f"{rule.target_field}.{target_subfield}"
-            if target_subfield in rule.customize_target_subfields:
-                full_output_field = rule.customize_target_subfields.get(target_subfield)
-            adding_was_successful = add_field_to(
-                event=event,
-                output_field=full_output_field,
-                content=value,
-                extends_lists=False,
-                overwrite_output_field=rule.overwrite_target,
-            )
-            if not adding_was_successful:
-                raise FieldExistsWarning(rule, event, [full_output_field])
+        fields = {
+            rule.customize_target_subfields.get(target, f"{rule.target_field}.{target}"): value
+            for target, value in geoip_data.items()
+        }
+        add_fields_to(
+            event,
+            fields,
+            rule=rule,
+            merge_with_target=False,
+            overwrite_target=rule.overwrite_target,
+        )
