@@ -13,10 +13,8 @@ Processor Configuration
 
     - listcomparisonname:
         type: list_comparison
-        specific_rules:
-            - tests/testdata/rules/specific/
-        generic_rules:
-            - tests/testdata/rules/generic/
+        rules:
+            - tests/testdata/rules/rules
         list_search_base_path: /path/to/list/dir
 
 .. autoclass:: logprep.processor.list_comparison.processor.ListComparison.Config
@@ -27,21 +25,12 @@ Processor Configuration
 
 .. automodule:: logprep.processor.list_comparison.rule
 """
-from logging import Logger
 
 from attr import define, field, validators
 
 from logprep.abc.processor import Processor
-from logprep.processor.base.exceptions import FieldExistsWarning
 from logprep.processor.list_comparison.rule import ListComparisonRule
-from logprep.util.helper import add_field_to, get_dotted_field_value
-
-
-class ListComparisonError(BaseException):
-    """Base class for ListComparison related exceptions."""
-
-    def __init__(self, name: str, message: str):
-        super().__init__(f"ListComparison ({name}): {message}")
+from logprep.util.helper import add_fields_to, get_dotted_field_value
 
 
 class ListComparison(Processor):
@@ -60,12 +49,9 @@ class ListComparison(Processor):
 
     rule_class = ListComparisonRule
 
-    def __init__(self, name: str, configuration: "Processor.Config", logger: Logger):
-        super().__init__(name, configuration, logger)
-        self.setup()
-
     def setup(self):
-        for rule in [*self._specific_rules, *self._generic_rules]:
+        super().setup()
+        for rule in self.rules:
             rule.init_list_comparison(self._config.list_search_base_path)
 
     def _apply_rules(self, event, rule):
@@ -83,14 +69,10 @@ class ListComparison(Processor):
             Currently applied list comparison rule.
 
         """
-
         comparison_result, comparison_key = self._list_comparison(rule, event)
-
         if comparison_result is not None:
-            output_field = f"{ rule.target_field }.{ comparison_key }"
-            field_possible = add_field_to(event, output_field, comparison_result, True)
-            if not field_possible:
-                raise FieldExistsWarning(rule, event, [output_field])
+            fields = {f"{rule.target_field}.{comparison_key}": comparison_result}
+            add_fields_to(event, fields, rule=rule, merge_with_target=True)
 
     def _list_comparison(self, rule: ListComparisonRule, event: dict):
         """
