@@ -2,9 +2,20 @@
 Pseudonymizer
 =============
 
-The `pseudonymizer` is a processor that pseudonymizes certain fields of log messages to ensure
+The :code:`pseudonymizer` is a processor that pseudonymizes certain fields of log messages to ensure
 privacy regulations can be adhered to.
 
+.. security-best-practice::
+   :title: Processor - Pseudonymizer
+
+   The :code:`pseudonymizer` works with two public keys for different roles.
+   It is suggested to ensure that two different keys are being used such that the separation of the
+   roles can be maintained.
+
+   It is suggested to use the :code:`GCM` mode for encryption as it decouples the key length of the
+   depseudo and analyst keys. This leads to additional 152 bytes of overhead for the encryption
+   compared to the :code:`CTR` mode encrypter.
+
 Processor Configuration
 ^^^^^^^^^^^^^^^^^^^^^^^
 ..  code-block:: yaml
@@ -12,10 +23,8 @@ Processor Configuration
 
     - pseudonymizername:
         type: pseudonymizer
-        specific_rules:
-            - tests/testdata/rules/specific/
-        generic_rules:
-            - tests/testdata/rules/generic/
+        rules:
+            - tests/testdata/rules/rules
         outputs:
             - kafka: pseudonyms_topic
         pubkey_analyst: /path/to/analyst_pubkey.pem
@@ -23,8 +32,7 @@ Processor Configuration
         hash_salt: secret_salt
         regex_mapping: /path/to/regex_mapping.json
         max_cached_pseudonyms: 1000000
-        tld_lists:
-            -/path/to/tld_list.dat
+        mode: GCM
 
 .. autoclass:: logprep.processor.pseudonymizer.processor.Pseudonymizer.Config
    :members:
@@ -34,32 +42,36 @@ Processor Configuration
 
 .. automodule:: logprep.processor.pseudonymizer.rule
 """
+
 import re
 from functools import cached_property, lru_cache
 from itertools import chain
-from logging import Logger
-from typing import List, Optional, Pattern
+from typing import Pattern
 from urllib.parse import parse_qs, urlencode, urlparse
 
 from attrs import define, field, validators
-from tldextract import TLDExtract
-from urlextract import URLExtract
 
 from logprep.abc.processor import Processor
+from logprep.factory_error import InvalidConfigurationError
 from logprep.metrics.metrics import CounterMetric, GaugeMetric
-from logprep.processor.pseudonymizer.encrypter import DualPKCS1HybridEncrypter
+from logprep.processor.field_manager.processor import FieldManager
 from logprep.processor.pseudonymizer.rule import PseudonymizerRule
 from logprep.util.getter import GetterFactory
 from logprep.util.hasher import SHA256Hasher
-from logprep.util.helper import add_field_to, get_dotted_field_value
-from logprep.util.validators import list_of_urls_validator
+from logprep.util.helper import add_fields_to, get_dotted_field_value
+from logprep.util.pseudo.encrypter import (
+    DualPKCS1HybridCTREncrypter,
+    DualPKCS1HybridGCMEncrypter,
+    Encrypter,
+)
+from logprep.util.url.url import extract_urls
 
 
-class Pseudonymizer(Processor):
+class Pseudonymizer(FieldManager):
     """Pseudonymize log events to conform to EU privacy laws."""
 
     @define(kw_only=True)
-    class Config(Processor.Config):
+    class Config(FieldManager.Config):
         """Pseudonymizer config"""
 
         outputs: tuple[dict[str, str]] = field(
@@ -103,30 +115,31 @@ class Pseudonymizer(Processor):
         * /var/git/logprep-rules/pseudonymizer_rules/regex_mapping.json
         """
         max_cached_pseudonyms: int = field(
-            validator=[validators.instance_of(int), validators.gt(0)]
+            validator=(validators.instance_of(int), validators.gt(0))
         )
         """
         The maximum number of cached pseudonyms. One cache entry requires ~250 Byte, thus 10
         million elements would require about 2.3 GB RAM. The cache is not persisted. Restarting
         Logprep does therefore clear the cache.
         This caching reduces the CPU load of Logprep (no demanding encryption must be performed
-        repeatedly) and the load on subsequent components (i.e. Logstash or Elasticsearch).
+        repeatedly) and the load on subsequent components (i.e. Logstash or Opensearch).
         In case the cache size has been exceeded, the least recently used
         entry is deleted. Has to be greater than 0.
         """
         max_cached_pseudonymized_urls: int = field(
-            validator=[validators.instance_of(int), validators.gt(0)], default=10000
+            validator=(validators.instance_of(int), validators.gt(0)), default=10000
         )
         """The maximum number of cached pseudonymized urls. Default is 10000.
         Behaves similarly to the max_cached_pseudonyms. Has to be greater than 0."""
-        tld_lists: Optional[list] = field(default=None, validator=[list_of_urls_validator])
-        """Optional list of path to files with top-level domain lists
-        (like https://publicsuffix.org/list/public_suffix_list.dat). If no path is given,
-        a default list will be retrieved online and cached in a local directory. For local
-        files the path has to be given with :code:`file:///path/to/file.dat`."""
+        mode: str = field(
+            validator=(validators.instance_of(str), validators.in_(("GCM", "CTR"))), default="GCM"
+        )
+        """Optional mode of operation for the encryption. Can be either 'GCM' or 'CTR'.
+        Default is 'GCM'.
+        """
 
     @define(kw_only=True)
-    class Metrics(Processor.Metrics):
+    class Metrics(Processor.Metrics):  # type: ignore
         """Tracks statistics about the Pseudonymizer"""
 
         pseudonymized_urls: CounterMetric = field(
@@ -166,10 +179,6 @@ class Pseudonymizer(Processor):
         )
         """Relative cache load."""
 
-    __slots__ = ["pseudonyms"]
-
-    pseudonyms: list
-
     HASH_PREFIX = "<pseudonym:"
     HASH_SUFFIX = ">"
 
@@ -177,25 +186,18 @@ class Pseudonymizer(Processor):
 
     rule_class = PseudonymizerRule
 
-    @cached_property
-    def _url_extractor(self):
-        return URLExtract()
-
     @cached_property
     def _hasher(self):
         return SHA256Hasher()
 
     @cached_property
-    def _encrypter(self) -> DualPKCS1HybridEncrypter:
-        _encrypter = DualPKCS1HybridEncrypter()
-        _encrypter.load_public_keys(self._config.pubkey_analyst, self._config.pubkey_depseudo)
-        return _encrypter
-
-    @cached_property
-    def _tld_extractor(self) -> TLDExtract:
-        if self._config.tld_lists is not None:
-            return TLDExtract(suffix_list_urls=self._config.tld_lists)
-        return TLDExtract()
+    def _encrypter(self) -> Encrypter:
+        if self._config.mode == "CTR":
+            encrypter = DualPKCS1HybridCTREncrypter()
+        else:
+            encrypter = DualPKCS1HybridGCMEncrypter()
+        encrypter.load_public_keys(self._config.pubkey_analyst, self._config.pubkey_depseudo)
+        return encrypter
 
     @cached_property
     def _regex_mapping(self) -> dict:
@@ -209,25 +211,28 @@ class Pseudonymizer(Processor):
     def _pseudonymize_url_cached(self):
         return lru_cache(maxsize=self._config.max_cached_pseudonymized_urls)(self._pseudonymize_url)
 
-    def __init__(self, name: str, configuration: Processor.Config, logger: Logger):
-        super().__init__(name=name, configuration=configuration, logger=logger)
-        self.pseudonyms = []
-
-    def load_rules(self, specific_rules_targets: List[str], generic_rules_targets: List[str]):
-        super().load_rules(specific_rules_targets, generic_rules_targets)
+    def setup(self):
+        super().setup()
         self._replace_regex_keywords_by_regex_expression()
 
-    def process(self, event: dict):
-        self.pseudonyms = []
-        super().process(event)
-        unique_pseudonyms = list(
-            {pseudonyms["pseudonym"]: pseudonyms for pseudonyms in self.pseudonyms}.values()
-        )
-        return (unique_pseudonyms, self._config.outputs) if unique_pseudonyms else None
+    def _replace_regex_keywords_by_regex_expression(self):
+        for rule in self.rules:
+            for dotted_field, regex_keyword in rule.pseudonyms.items():
+                if regex_keyword in self._regex_mapping:
+                    rule.pseudonyms[dotted_field] = re.compile(self._regex_mapping[regex_keyword])
+                elif isinstance(regex_keyword, str):  # after the first run, the regex is compiled
+                    raise InvalidConfigurationError(
+                        f"Regex keyword '{regex_keyword}' not found in regex_mapping '{self._config.regex_mapping}'"
+                    )
 
     def _apply_rules(self, event: dict, rule: PseudonymizerRule):
-        for dotted_field, regex in rule.pseudonyms.items():
-            field_value = get_dotted_field_value(event, dotted_field)
+        source_dict = {}
+        for source_field in rule.pseudonyms:
+            source_dict[source_field] = get_dotted_field_value(event, source_field)
+        self._handle_missing_fields(event, rule, source_dict.keys(), source_dict.values())
+
+        for dotted_field, field_value in source_dict.items():
+            regex = rule.pseudonyms[dotted_field]
             if field_value is None:
                 continue
             if isinstance(field_value, list):
@@ -237,9 +242,11 @@ class Pseudonymizer(Processor):
                 ]
             else:
                 field_value = self._pseudonymize_field(rule, dotted_field, regex, field_value)
-            _ = add_field_to(event, dotted_field, field_value, overwrite_output_field=True)
+            add_fields_to(
+                event, fields={dotted_field: field_value}, rule=rule, overwrite_target=True
+            )
         if "@timestamp" in event:
-            for pseudonym in self.pseudonyms:
+            for pseudonym, _ in self.result.data:
                 pseudonym["@timestamp"] = event["@timestamp"]
         self._update_cache_metrics()
 
@@ -251,7 +258,7 @@ class Pseudonymizer(Processor):
         else:
             plaintext_values = set(chain(*[value for value in regex.findall(field_value) if value]))
         if plaintext_values and dotted_field in rule.url_fields:
-            for url_string in self._url_extractor.gen_urls(field_value):
+            for url_string in extract_urls(field_value):
                 field_value = field_value.replace(
                     url_string, self._pseudonymize_url_cached(url_string)
                 )
@@ -269,7 +276,9 @@ class Pseudonymizer(Processor):
         if self.pseudonymized_pattern.match(value):
             return value
         pseudonym_dict = self._get_pseudonym_dict_cached(value)
-        self.pseudonyms.append(pseudonym_dict)
+        extra = (pseudonym_dict, self._config.outputs)
+        if extra not in self.result.data:
+            self.result.data.append(extra)
         return self._wrap_hash(pseudonym_dict["pseudonym"])
 
     def _pseudonymize(self, value):
@@ -278,13 +287,15 @@ class Pseudonymizer(Processor):
         return {"pseudonym": hash_string, "origin": encrypted_origin}
 
     def _pseudonymize_url(self, url_string: str) -> str:
-        url = self._tld_extractor(url_string)
         if url_string.startswith(("http://", "https://")):
             parsed_url = urlparse(url_string)
         else:
-            parsed_url = urlparse("http://" + url_string)
-        if url.subdomain:
-            url_string = url_string.replace(url.subdomain, self._pseudonymize_string(url.subdomain))
+            parsed_url = urlparse(f"http://{url_string}")
+        if parsed_url.hostname:
+            splitted_hostname = parsed_url.hostname.split(".")
+            if len(splitted_hostname) > 2:
+                subdomain = ".".join(splitted_hostname[0:-2])
+                url_string = url_string.replace(subdomain, self._pseudonymize_string(subdomain))
         if parsed_url.fragment:
             url_string = url_string.replace(
                 f"#{parsed_url.fragment}", f"#{self._pseudonymize_string(parsed_url.fragment)}"
@@ -309,25 +320,15 @@ class Pseudonymizer(Processor):
         self.metrics.pseudonymized_urls += 1
         return url_string
 
-    def _replace_regex_keywords_by_regex_expression(self):
-        for rule in self._specific_rules:
-            for dotted_field, regex_keyword in rule.pseudonyms.items():
-                if regex_keyword in self._regex_mapping:
-                    rule.pseudonyms[dotted_field] = re.compile(self._regex_mapping[regex_keyword])
-        for rule in self._generic_rules:
-            for dotted_field, regex_keyword in rule.pseudonyms.items():
-                if regex_keyword in self._regex_mapping:
-                    rule.pseudonyms[dotted_field] = re.compile(self._regex_mapping[regex_keyword])
-
     def _wrap_hash(self, hash_string: str) -> str:
         return self.HASH_PREFIX + hash_string + self.HASH_SUFFIX
 
     def _update_cache_metrics(self):
         cache_info_pseudonyms = self._get_pseudonym_dict_cached.cache_info()
         cache_info_urls = self._pseudonymize_url_cached.cache_info()
-        self.metrics.new_results = cache_info_pseudonyms.misses + cache_info_urls.misses
-        self.metrics.cached_results = cache_info_pseudonyms.hits + cache_info_urls.hits
-        self.metrics.num_cache_entries = cache_info_pseudonyms.currsize + cache_info_urls.currsize
-        self.metrics.cache_load = (cache_info_pseudonyms.currsize + cache_info_urls.currsize) / (
+        self.metrics.new_results += cache_info_pseudonyms.misses + cache_info_urls.misses
+        self.metrics.cached_results += cache_info_pseudonyms.hits + cache_info_urls.hits
+        self.metrics.num_cache_entries += cache_info_pseudonyms.currsize + cache_info_urls.currsize
+        self.metrics.cache_load += (cache_info_pseudonyms.currsize + cache_info_urls.currsize) / (
             cache_info_pseudonyms.maxsize + cache_info_urls.maxsize
         )
