@@ -5,6 +5,16 @@ Requester
 A processor to invoke http requests. Can be used to enrich events from an external api or
 to trigger external systems by and with event field values.
 
+.. security-best-practice::
+   :title: Processor - Requester
+
+   As the `requester` can execute arbitrary http requests it is advised to execute requests only
+   against known and trusted endpoints and that the communication is protected with a valid
+   SSL-Certificate. Do so by setting a certificate path with the option :code:`cert`.
+   To ensure that the communication is trusted it is also recommended to set either an
+   :code:`Authorization`-Header or a corresponding authentication with a username and password, via
+   :code:`auth`.
+
 Processor Configuration
 ^^^^^^^^^^^^^^^^^^^^^^^
 ..  code-block:: yaml
@@ -12,10 +22,8 @@ Processor Configuration
 
     - requestername:
         type: requester
-        specific_rules:
-            - tests/testdata/rules/specific/
-        generic_rules:
-            - tests/testdata/rules/generic/
+        rules:
+            - tests/testdata/rules/rules
 
 .. autoclass:: logprep.processor.requester.processor.Requester.Config
    :members:
@@ -25,24 +33,21 @@ Processor Configuration
 
 .. automodule:: logprep.processor.requester.rule
 """
+
 import json
 import re
 
 import requests
 
-from logprep.abc.processor import Processor
 from logprep.processor.base.exceptions import FieldExistsWarning
+from logprep.processor.field_manager.processor import FieldManager
 from logprep.processor.requester.rule import RequesterRule
-from logprep.util.helper import (
-    add_field_to,
-    get_dotted_field_value,
-    get_source_fields_dict,
-)
+from logprep.util.helper import add_fields_to, get_source_fields_dict
 
 TEMPLATE_KWARGS = ("url", "json", "data", "params")
 
 
-class Requester(Processor):
+class Requester(FieldManager):
     """A processor to invoke http requests with field data
     and parses response data to field values"""
 
@@ -50,6 +55,8 @@ class Requester(Processor):
 
     def _apply_rules(self, event, rule):
         source_field_dict = get_source_fields_dict(event, rule)
+        if self._handle_missing_fields(event, rule, rule.source_fields, source_field_dict.values()):
+            return
         if self._has_missing_values(event, rule, source_field_dict):
             return
         kwargs = self._template_kwargs(rule.kwargs, source_field_dict)
@@ -60,31 +67,32 @@ class Requester(Processor):
     def _handle_response(self, event, rule, response):
         conflicting_fields = []
         if rule.target_field:
-            result = self._get_result(response)
-            successful = add_field_to(
-                event,
-                rule.target_field,
-                result,
-                rule.extend_target_list,
-                rule.overwrite_target,
-            )
-            if not successful:
-                conflicting_fields.append(rule.target_field)
-        if rule.target_field_mapping:
-            result = self._get_result(response)
-            for source_field, target_field in rule.target_field_mapping.items():
-                source_field_value = get_dotted_field_value(result, source_field)
-                successful = add_field_to(
+            try:
+                add_fields_to(
                     event,
-                    target_field,
-                    source_field_value,
-                    rule.extend_target_list,
+                    fields={rule.target_field: self._get_result(response)},
+                    rule=rule,
+                    merge_with_target=rule.merge_with_target,
+                    overwrite_target=rule.overwrite_target,
+                )
+            except FieldExistsWarning as error:
+                conflicting_fields.extend(error.skipped_fields)
+        if rule.target_field_mapping:
+            source_fields = rule.target_field_mapping.keys()
+            contents = self._get_field_values(self._get_result(response), source_fields)
+            targets = rule.target_field_mapping.values()
+            try:
+                add_fields_to(
+                    event,
+                    dict(zip(targets, contents)),
+                    rule,
+                    rule.merge_with_target,
                     rule.overwrite_target,
                 )
-                if not successful:
-                    conflicting_fields.append(rule.target_field)
+            except FieldExistsWarning as error:
+                conflicting_fields.extend(error.skipped_fields)
         if conflicting_fields:
-            raise FieldExistsWarning(rule, event, [rule.target_field])
+            raise FieldExistsWarning(rule, event, conflicting_fields)
 
     def _request(self, event, rule, kwargs):
         try:
