@@ -16,9 +16,8 @@ A speaking example for event enrichment via external api:
     requester:
       url: https://internal.cmdb.local/api/v1/locations
       method: POST
-      content_type: application/json
       target_field: cmdb.location
-      header:
+      headers:
         Authorization: Bearer askdfjpiowejf283u9r
       json:
         hostname: ${message.hostname}
@@ -62,6 +61,7 @@ A speaking example for event enrichment via external api:
    :inherited-members:
    :noindex:
 """
+
 import inspect
 import json
 import re
@@ -150,7 +150,7 @@ class RequesterRule(FieldManagerRule):
         )
         """ (Optional) The http headers as dictionary."""
         auth: tuple = field(
-            validator=[validators.instance_of(tuple)],
+            validator=(validators.instance_of(tuple)),
             converter=tuple,
             factory=tuple,
         )
