@@ -2,9 +2,7 @@
 Rule Configuration
 ^^^^^^^^^^^^^^^^^^
 
-The timestamp format can be specified per timestamp. Following patterns can be used to define the
-timestamp format:
-`Timestamp tokens <https://docs.python.org/3/library/datetime.html#strftime-and-strptime-format-codes>`_.
+The timestamp format can be specified per timestamp.
 
 A speaking example:
 
@@ -31,7 +29,7 @@ A speaking example:
 
     {"ingest": "2022-12-06 10:00:00", "processed": "2022-12-06 10:00:05", "processing_time": "5.0"}
 
-.. autoclass:: logprep.processor.timestamper.rule.TimestamperRule.Config
+.. autoclass:: logprep.processor.timestamp_differ.rule.TimestampDifferRule.Config
    :members:
    :undoc-members:
    :inherited-members:
@@ -43,6 +41,7 @@ Examples for timestamp_differ:
 .. datatemplate:import-module:: tests.unit.processor.timestamp_differ.test_timestamp_differ
    :template: testcase-renderer.tmpl
 """
+
 import re
 
 from attr import field
@@ -68,8 +67,8 @@ class TimestampDifferRule(FieldManagerRule):
         and the timestamp format can be specified in the form of:
         :code:`${dotted.field.path:timestamp-format}`. If no timestamp format is given, e.g.
         :code:`${dotted.field.path}`, the string will be assumed as an iso8601 compliant string and
-        parsed. For more information on the format syntax see 
-        `datetime strftime/strptime <https://docs.python.org/3/library/datetime.html#strftime-and-strptime-format-codes>`_."""
+        parsed. For more information on the format syntax see `datetime strftime/strptime
+        <https://docs.python.org/3/library/datetime.html#strftime-and-strptime-format-codes>`_."""
         source_fields: list = field(factory=list)
         source_field_formats: list = field(factory=list)
         output_format: str = field(
