@@ -1,12 +1,14 @@
 # pylint: disable=missing-docstring
+# pylint: disable=line-too-long
+# pylint: disable=too-many-locals
 import os
 import re
 import tempfile
+import time
 from pathlib import Path
 
 import requests
 
-from logprep.util.json_handling import dump_config_as_file
 from tests.acceptance.util import (
     HTTPServerForTesting,
     convert_to_http_config,
@@ -14,20 +16,20 @@ from tests.acceptance.util import (
     get_full_pipeline,
     start_logprep,
     stop_logprep,
+    wait_for_output,
 )
 
 
 def teardown_function():
     Path("generated_config.yml").unlink(missing_ok=True)
-    stop_logprep()
 
 
 def test_start_of_logprep_with_full_configuration_from_file(tmp_path):
-    pipeline = get_full_pipeline(exclude=["normalizer"])
+    pipeline = get_full_pipeline(exclude=["normalizer", "geoip_enricher"])
     config = get_default_logprep_config(pipeline, with_hmac=False)
-    config.get("output").update({"kafka": {"type": "dummy_output", "default": False}})
-    config_path = str(tmp_path / "generated_config.yml")
-    dump_config_as_file(config_path, config)
+    config.output.update({"kafka": {"type": "dummy_output", "default": False}})
+    config_path = tmp_path / "generated_config.yml"
+    config_path.write_text(config.as_yaml(), encoding="utf-8")
     proc = start_logprep(config_path)
     output = proc.stdout.readline().decode("utf8")
     while True:
@@ -39,28 +41,30 @@ def test_start_of_logprep_with_full_configuration_from_file(tmp_path):
         if re.search("Startup complete", output):
             break
         output = proc.stdout.readline().decode("utf8")
+    stop_logprep(proc)
 
 
 def test_start_of_logprep_with_full_configuration_http():
-    pipeline = get_full_pipeline(exclude=["normalizer"])
+    pipeline = get_full_pipeline(exclude=["normalizer", "geoip_enricher"])
     config = get_default_logprep_config(pipeline, with_hmac=False)
-    config.get("output").update({"kafka": {"type": "dummy_output", "default": False}})
+    config.output.update({"kafka": {"type": "dummy_output", "default": False}})
     endpoint = "http://localhost:32000"
     config = convert_to_http_config(config, endpoint)
-    config_path = "generated_config.yml"
-    dump_config_as_file(config_path, config)
+    config_path = Path("generated_config.yml")
+    config_path.write_text(config.as_yaml(), encoding="utf-8")
     with HTTPServerForTesting.run_in_thread():
-        proc = start_logprep(f"{endpoint}/{config_path}")
+        proc = start_logprep(f"{endpoint}/{str(config_path)}")
         output = proc.stdout.readline().decode("utf8")
         while True:
-            assert not re.search("Invalid", output)
-            assert not re.search("Exception", output)
-            assert not re.search("critical", output)
-            assert not re.search("Error", output)
-            assert not re.search("ERROR", output)
+            assert not re.search("Invalid", output), output
+            assert not re.search("Exception", output), output
+            assert not re.search("critical", output), output
+            assert not re.search("Error", output), output
+            assert not re.search("ERROR", output), output
             if re.search("Startup complete", output):
                 break
             output = proc.stdout.readline().decode("utf8")
+    stop_logprep(proc)
 
 
 def test_start_of_logprep_from_http_with_templated_url_and_config():
@@ -87,12 +91,10 @@ $LOGPREP_OUTPUT
 pipeline:
     - labelername:
         type: labeler
-        schema: quickstart/exampledata/rules/labeler/schema.json
+        schema: examples/exampledata/rules/labeler/schema.json
         include_parent_labels: true
-        specific_rules:
-            - quickstart/exampledata/rules/labeler/specific
-        generic_rules:
-            - quickstart/exampledata/rules/labeler/generic
+        rules:
+            - examples/exampledata/rules/labeler/rules
 """,
         "LOGPREP_OUTPUT": """
 output:
@@ -103,61 +105,53 @@ output:
     }
     with HTTPServerForTesting.run_in_thread():
         proc = start_logprep("${LOGPREP_API_ENDPOINT}/generated_config.yml", env=env)
-        output = proc.stdout.readline().decode("utf8")
-        while True:
-            assert not re.search("Invalid", output)
-            assert not re.search("Exception", output)
-            assert not re.search("critical", output)
-            assert not re.search("Error", output)
-            assert not re.search("ERROR", output)
-            if re.search("Startup complete", output):
-                break
-            output = proc.stdout.readline().decode("utf8")
+        wait_for_output(proc, "Startup complete")
+        stop_logprep(proc)
 
 
-def test_logprep_exposes_prometheus_metrics(tmp_path):
+def test_logprep_exposes_prometheus_metrics_and_healthchecks(tmp_path):
     temp_dir = tempfile.gettempdir()
     input_file_path = Path(os.path.join(temp_dir, "input.txt"))
     input_file_path.touch()
     # requester is excluded because it tries to connect to non-existing server
     # selective_extractor is excluded because of output mismatch (rules expect kafka as output)
     # normalizer is excluded because of deprecation
-    pipeline = get_full_pipeline(exclude=["requester", "selective_extractor", "normalizer"])
+    # geoip_enricher is excluded because of missing maxmind license
+    pipeline = get_full_pipeline(
+        exclude=["requester", "selective_extractor", "normalizer", "geoip_enricher"]
+    )
     config = get_default_logprep_config(pipeline, with_hmac=False)
-    config |= {
-        "version": "my_custom_version",
-        "config_refresh_interval": 300,
-        "metrics": {"enabled": True, "port": 8000},
-        "input": {
-            "fileinput": {
-                "type": "file_input",
-                "logfile_path": str(input_file_path),
-                "start": "begin",
-                "interval": 1,
-                "watch_file": True,
-            }
+    config.version = "my_custom_version"
+    config.config_refresh_interval = 300
+    config.metrics = {"enabled": True, "port": 8003}
+    config.input = {
+        "fileinput": {
+            "type": "file_input",
+            "logfile_path": str(input_file_path),
+            "start": "begin",
+            "interval": 1,
+            "watch_file": True,
+        }
+    }
+    config.output = {
+        "kafka": {  # the name has to be kafka for some default rules
+            "type": "console_output",
         },
-        "output": {
-            "kafka": {  # the name has to be kafka for some default rules
-                "type": "console_output",
-            },
-            "second_output": {
-                "type": "console_output",
-            },
+        "second_output": {
+            "type": "console_output",
         },
     }
-    config_path = str(tmp_path / "generated_config.yml")
+    config_path = tmp_path / "generated_config.yml"
     # duplicate one processor to test that rule metrics are separated by processor names and not by type
-    config["pipeline"].append(
+    config.pipeline.append(
         {
             "calculator2": {
-                "generic_rules": ["tests/testdata/unit/calculator/generic_rules"],
-                "specific_rules": ["tests/testdata/unit/calculator/specific_rules"],
+                "rules": ["tests/testdata/unit/calculator/rules"],
                 "type": "calculator",
             }
         }
     )
-    dump_config_as_file(config_path, config)
+    config_path.write_text(config.as_yaml(), encoding="utf-8")
     proc = start_logprep(config_path, env={"PROMETHEUS_MULTIPROC_DIR": tmp_path})
     input_file_path.write_text("user root logged in\n", encoding="utf8")
     while True:
@@ -165,9 +159,11 @@ def test_logprep_exposes_prometheus_metrics(tmp_path):
         assert "error" not in output.lower(), "error message"
         assert "critical" not in output.lower(), "error message"
         assert "exception" not in output.lower(), "error message"
-        if "Finished building pipeline" in output:
+        assert not re.search("Shutting down", output)
+        if "Startup complete" in output:
             break
-    response = requests.get("http://127.0.0.1:8000", timeout=5)
+    time.sleep(2)
+    response = requests.get("http://127.0.0.1:8003", timeout=7)
     response.raise_for_status()
     metrics = response.text
     expected_metrics = [
@@ -216,7 +212,10 @@ def test_logprep_exposes_prometheus_metrics(tmp_path):
         r"logprep_number_of_config_refreshes.+0",
     ]
     for expeced_metric in expected_metrics:
-        assert re.search(expeced_metric, metrics), f"Metric {expeced_metric} not found in metrics"
+        assert re.search(
+            expeced_metric, metrics
+        ), f"Metric '{expeced_metric}' not found in expected metrics"
+
     forbidden_metrics = [
         r"component=\"None\"",
         r"type=\"None\"",
@@ -232,15 +231,20 @@ def test_logprep_exposes_prometheus_metrics(tmp_path):
     assert re.search(first_calculator, metrics), "First calculator not found"
     assert (
         len(re.findall(first_calculator, metrics)) == 2
-    ), "More or less than two rules (specific, generic) were found for first calculator"
+    ), "More or less than two rules were found for first calculator"
     second_calculator = r"logprep_number_of_processed_events_total\{component=\"rule\",description=\"id:.+\",name=\"calculator2\",type\=\"calculator\"}"
     assert re.search(second_calculator, metrics), "Second calculator not found"
     assert (
         len(re.findall(second_calculator, metrics)) == 2
-    ), "More or less than two rules (specific, generic) were found for second calculator"
+    ), "More or less than two rules were found for second calculator"
     both_calculators = r"logprep_number_of_processed_events_total\{component=\"rule\",description=\"id:.+\",name=\".+\",type\=\"calculator\"}"
     assert (
         len(re.findall(both_calculators, metrics)) == 4
     ), "More or less than 4 rules were found for both calculator"
 
-    proc.kill()
+    # check health endpoint
+    response = requests.get("http://127.0.0.1:8003/health", timeout=7)
+    response.raise_for_status()
+    assert "OK" == response.text
+
+    stop_logprep(proc)
