@@ -6,23 +6,27 @@ import contextlib
 import http.server
 import inspect
 import json
-import os
 import re
-import signal
 import socketserver
 import subprocess
 import sys
+import tempfile
 import threading
 import time
 from copy import deepcopy
 from importlib import import_module
 from logging import DEBUG, basicConfig, getLogger
 from os import makedirs, path
+from pathlib import Path
+
+import psutil
 
 from logprep.abc.processor import Processor
 from logprep.registry import Registry
 from logprep.runner import Runner
+from logprep.util.configuration import Configuration
 from logprep.util.decorators import timeout
+from logprep.util.defaults import RULE_FILE_EXTENSIONS
 from logprep.util.helper import recursive_compare, remove_file_if_exists
 from logprep.util.json_handling import parse_jsonl
 from tests.unit.processor.base import BaseProcessorTestCase
@@ -113,7 +117,7 @@ def store_latest_test_output(target_output_identifier, output_of_test):
             latest_output.write(json.dumps(test_output_line) + "\n")
 
 
-def get_runner_outputs(patched_runner) -> list:
+def get_runner_outputs(patched_runner: Runner) -> list:
     # pylint: disable=protected-access
     """
     Extracts the outputs of a patched logprep runner.
@@ -130,16 +134,22 @@ def get_runner_outputs(patched_runner) -> list:
         and errors
     """
     parsed_outputs = [None, None, None]
-    output_config = list(patched_runner._configuration.get("output").values())[0]
+    output_config = list(patched_runner._configuration.output.values())[0]
     output_paths = [
         output_path for key, output_path in output_config.items() if "output_file" in key
     ]
-
+    if patched_runner._configuration.error_output:
+        config = list(patched_runner._configuration.error_output.values())[0]
+        if "output_file" in config:
+            output_paths.append(config["output_file"])
     for output_path in output_paths:
         remove_file_if_exists(output_path)
 
-    patched_runner.start()
-
+    try:
+        patched_runner.start()
+        patched_runner.stop_and_exit()
+    except SystemExit as error:
+        assert not error.code, f"Runner exited with code {error.code}"
     for index, output_path in enumerate(output_paths):
         parsed_outputs[index] = parse_jsonl(output_path)
         remove_file_if_exists(output_path)
@@ -164,13 +174,12 @@ def get_patched_runner(config_path):
     runner : Runner
         The patched logprep runner
     """
-    runner = Runner(bypass_check_to_obtain_non_singleton_instance=True)
-    runner.load_configuration(config_path)
+    runner = Runner(Configuration.from_sources([config_path]))
 
     # patch runner to stop on empty pipeline
     def keep_iterating():
         """generator that stops on first iteration"""
-        return  # nosemgrep
+        return
         yield
 
     runner._keep_iterating = keep_iterating  # pylint: disable=protected-access
@@ -178,7 +187,7 @@ def get_patched_runner(config_path):
     return runner
 
 
-def get_test_output(config_path):
+def get_test_output(config_path: str) -> list[dict]:
     patched_runner = get_patched_runner(config_path)
     return get_runner_outputs(patched_runner=patched_runner)
 
@@ -202,11 +211,10 @@ class TmpFileProducerMock:
         with open(self.tmp_path, "a", encoding="utf-8") as tmp_file:
             tmp_file.write(f"{target} {value.decode()}\n")
 
-    def poll(self, _):
-        ...
+    def poll(self, _): ...
 
 
-def get_default_logprep_config(pipeline_config, with_hmac=True):
+def get_default_logprep_config(pipeline_config, with_hmac=True) -> Configuration:
     config_yml = {
         "version": "1",
         "process_count": 1,
@@ -222,9 +230,8 @@ def get_default_logprep_config(pipeline_config, with_hmac=True):
         "output": {
             "jsonl": {
                 "type": "jsonl_output",
-                "output_file": "tests/testdata/acceptance/test_kafka_data_processing_acceptance.out",
-                "output_file_custom": "tests/testdata/acceptance/test_kafka_data_processing_acceptance_custom.out",
-                "output_file_error": "tests/testdata/acceptance/test_kafka_data_processing_acceptance_error.out",
+                "output_file": tempfile.mkstemp(suffix="output.jsonl")[1],
+                "output_file_custom": tempfile.mkstemp(suffix="custom.jsonl")[1],
             }
         },
     }
@@ -239,15 +246,15 @@ def get_default_logprep_config(pipeline_config, with_hmac=True):
             }
         }
 
-    return config_yml
+    return Configuration(**config_yml)
 
 
 def start_logprep(config_path: str, env: dict = None) -> subprocess.Popen:
     if env is None:
         env = {}
     env.update({"PYTHONPATH": "."})
-    return subprocess.Popen(  # nosemgrep
-        f"{sys.executable} logprep/run_logprep.py {config_path}",
+    return subprocess.Popen(
+        f"{sys.executable} logprep/run_logprep.py run {config_path}",
         shell=True,
         env=env,
         stdin=subprocess.PIPE,
@@ -257,34 +264,53 @@ def start_logprep(config_path: str, env: dict = None) -> subprocess.Popen:
     )
 
 
-def wait_for_output(proc, expected_output, test_timeout=10):
+def wait_for_output(
+    proc: subprocess.Popen, expected_output, test_timeout=10, forbidden_outputs=None
+) -> None:
+    if forbidden_outputs is None:
+        forbidden_outputs = ["Invalid", "Exception", "critical", "Error", "ERROR"]
+
     @timeout(test_timeout)
-    def wait_for_output_inner(proc, expected_output):
+    def wait_for_output_inner(
+        proc,
+        expected_output,
+        forbidden_outputs,
+    ):
         output = proc.stdout.readline()
-        while not re.search(expected_output, output.decode("utf8")):
+        while 1:
+            if re.search(expected_output, output.decode("utf8")):
+                break
+            for forbidden_output in forbidden_outputs:
+                assert not re.search(forbidden_output, output.decode("utf8")), output
             output = proc.stdout.readline()
 
-    wait_for_output_inner(proc, expected_output)
-    time.sleep(0.1)  # nosemgrep
+    wait_for_output_inner(proc, expected_output, forbidden_outputs)
+    time.sleep(0.1)
 
 
-def stop_logprep(proc=None):
-    if proc:
-        proc.send_signal(signal.SIGINT)
-        try:
-            wait_for_output(proc, "Shutdown complete", test_timeout=10)
-        except TimeoutError:
-            proc.kill()
+def stop_logprep(proc: subprocess.Popen) -> None:
+    if proc is None or not psutil.pid_exists(proc.pid):
+        return
 
-    output = subprocess.check_output("ps -x | grep run_logprep", shell=True)  # nosemgrep
-    for line in output.decode("utf8").splitlines():
-        process_id = re.match(r"^(\s+)?(\d+)\s.+", line)
-        process_id = process_id.group(2) if process_id else None
-        try:
-            if process_id is not None:
-                os.kill(int(process_id), signal.SIGKILL)
-        except ProcessLookupError:
-            pass
+    try:
+        process = psutil.Process(proc.pid)
+        for p in process.children(recursive=True):
+            if p.is_running():
+                p.terminate()
+
+        process.wait(timeout=5)
+        process.terminate()
+        for p in process.children(recursive=True):
+            if p.is_running():
+                p.kill()
+
+        if process.is_running():
+            process.kill()
+
+    except (psutil.NoSuchProcess, psutil.ZombieProcess):
+        pass
+    except psutil.TimeoutExpired:
+        process.kill()
 
 
 def get_full_pipeline(exclude=None):
@@ -312,7 +338,7 @@ def get_full_pipeline(exclude=None):
     return [{processor_name: config} for processor_name, config in processor_configs if config]
 
 
-def convert_to_http_config(config: dict, endpoint) -> dict:
+def convert_to_http_config(config: Configuration, endpoint) -> Configuration:
     config = deepcopy(config)
     http_fields = [
         "regex_mapping",
@@ -324,11 +350,23 @@ def convert_to_http_config(config: dict, endpoint) -> dict:
         "schema",
         "template",
     ]
-    for processor_config in config.get("pipeline"):
+    for processor_config in config.pipeline:
         name, value = processor_config.popitem()
-        for rule_kind in ("specific_rules", "generic_rules"):
-            rules = Processor.resolve_directories(value.get(rule_kind))
-            value[rule_kind] = [f"{endpoint}/{rule}" for rule in rules]
+        rules = []
+        for rule in value["rules"]:
+            match rule:
+                case str():
+                    path = Path(rule)
+                    if path.is_file():
+                        rules.append(str(path))
+                    if path.is_dir():
+                        files = (
+                            str(p)
+                            for p in Path(path).glob("**/*")
+                            if p.suffix in RULE_FILE_EXTENSIONS
+                        )
+                        rules.extend(files)
+        value["rules"] = [f"{endpoint}/{rule}" for rule in rules]
         for config_key, config_value in value.items():
             if config_key in http_fields:
                 value.update({config_key: f"{endpoint}/{config_value}"})
