@@ -5,15 +5,19 @@
 import base64
 import json
 import os
+import re
 import zlib
 from copy import deepcopy
 from logging import getLogger
 from unittest import mock
 
+import pytest
+
 from logprep.abc.connector import Connector
-from logprep.abc.input import Input
+from logprep.abc.input import CriticalInputError, Input
 from logprep.abc.output import Output
 from logprep.factory import Factory
+from logprep.util.helper import get_dotted_field_value
 from logprep.util.time import TimeParser
 from tests.unit.component.base import BaseComponentTestCase
 
@@ -26,7 +30,6 @@ class BaseConnectorTestCase(BaseComponentTestCase):
     expected_metrics = [
         "logprep_processing_time_per_event",
         "logprep_number_of_processed_events",
-        "logprep_number_of_failed_events",
         "logprep_number_of_warnings",
         "logprep_number_of_errors",
     ]
@@ -42,7 +45,7 @@ class BaseInputTestCase(BaseConnectorTestCase):
     def test_get_next_returns_event(self):
         return_value = ({"message": "test message"}, b'{"message": "test message"}')
         self.object._get_event = mock.MagicMock(return_value=return_value)
-        event, _ = self.object.get_next(0.01)
+        event = self.object.get_next(0.01)
         assert isinstance(event, dict)
 
     def test_add_hmac_returns_true_if_hmac_options(self):
@@ -58,7 +61,7 @@ class BaseInputTestCase(BaseConnectorTestCase):
                 }
             }
         )
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         assert connector._add_hmac is True
 
     def test_add_hmac_to_adds_hmac(self):
@@ -74,11 +77,8 @@ class BaseInputTestCase(BaseConnectorTestCase):
                 }
             }
         )
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
-        processed_event, non_critical_error_msg = connector._add_hmac_to(
-            {"message": "test message"}, b"test message"
-        )
-        assert non_critical_error_msg is None
+        connector = Factory.create({"test connector": connector_config})
+        processed_event = connector._add_hmac_to({"message": "test message"}, b"test message")
         assert processed_event.get("Hmac")
         assert (
             processed_event.get("Hmac").get("hmac")
@@ -101,11 +101,8 @@ class BaseInputTestCase(BaseConnectorTestCase):
                 }
             }
         )
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
-        processed_event, non_critical_error_msg = connector._add_hmac_to(
-            {"message": "test message"}, None
-        )
-        assert non_critical_error_msg is None
+        connector = Factory.create({"test connector": connector_config})
+        processed_event = connector._add_hmac_to({"message": "test message"}, None)
         assert processed_event.get("Hmac")
         calculated_hmac = processed_event.get("Hmac").get("hmac")
         assert (
@@ -129,7 +126,7 @@ class BaseInputTestCase(BaseConnectorTestCase):
                 }
             }
         )
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"message": "with_content"}
         raw_encoded_test_event = json.dumps(test_event, separators=(",", ":")).encode("utf-8")
         connector._get_event = mock.MagicMock(
@@ -142,7 +139,7 @@ class BaseInputTestCase(BaseConnectorTestCase):
                 "hmac": "dfe78753da634d7b76760488dbb2cf7bfe1b0e4e794930c36e98a984b6b6be63",
             },
         }
-        connector_next_msg, _ = connector.get_next(1)
+        connector_next_msg = connector.get_next(1)
         assert connector_next_msg == expected_event, "Output event with hmac is not as expected"
 
         decoded = base64.b64decode(connector_next_msg["Hmac"]["compressed_base64"])
@@ -164,7 +161,7 @@ class BaseInputTestCase(BaseConnectorTestCase):
                 }
             }
         )
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"message": {"with_subfield": "content"}}
         raw_encoded_test_event = json.dumps(test_event, separators=(",", ":")).encode("utf-8")
         connector._get_event = mock.MagicMock(
@@ -178,7 +175,7 @@ class BaseInputTestCase(BaseConnectorTestCase):
             },
         }
 
-        connector_next_msg, _ = connector.get_next(1)
+        connector_next_msg = connector.get_next(1)
         assert connector_next_msg == expected_event
 
         decoded = base64.b64decode(connector_next_msg["Hmac"]["compressed_base64"])
@@ -200,26 +197,16 @@ class BaseInputTestCase(BaseConnectorTestCase):
                 }
             }
         )
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"message": {"with_subfield": "content"}}
         raw_encoded_test_event = json.dumps(test_event, separators=(",", ":")).encode("utf-8")
         connector._get_event = mock.MagicMock(
             return_value=(test_event.copy(), raw_encoded_test_event)
         )
-        expected_output_event = {
-            "message": {"with_subfield": "content"},
-            "Hmac": {
-                "hmac": "error",
-                "compressed_base64": "eJyzSa0oSE0uSU1RyMhNTFYoSSxKTy1RSMtMzUlRUM/Lz4tPrcgsLsnMS48Hi"
-                "6kr5OUDpfNL81LsAJILFeQ=",
-            },
-        }
-        connector_next_msg, non_critical_error_msg = connector.get_next(1)
-        assert connector_next_msg == expected_output_event
-        decoded = base64.b64decode(connector_next_msg["Hmac"]["compressed_base64"])
-        decoded_message = zlib.decompress(decoded).decode("utf8")
-        assert decoded_message == "<expected hmac target field 'non_existing_field' not found>"
-        assert non_critical_error_msg == "Couldn't find the hmac target field 'non_existing_field'"
+        critical_input_error_msg = "Couldn't find the hmac target field 'non_existing_field'"
+        with pytest.raises(CriticalInputError, match=critical_input_error_msg) as error:
+            _ = connector.get_next(1)
+        assert error.value.raw_input == b'{"message":{"with_subfield":"content"}}'
 
     def test_get_next_with_hmac_result_in_dotted_subfield(self):
         connector_config = deepcopy(self.CONFIG)
@@ -234,7 +221,7 @@ class BaseInputTestCase(BaseConnectorTestCase):
                 }
             }
         )
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"message": "with_content"}
         raw_encoded_test_event = json.dumps(test_event, separators=(",", ":")).encode("utf-8")
         connector._get_event = mock.MagicMock(
@@ -252,7 +239,7 @@ class BaseInputTestCase(BaseConnectorTestCase):
             },
         }
 
-        connector_next_msg, _ = connector.get_next(1)
+        connector_next_msg = connector.get_next(1)
         assert connector_next_msg == expected_event
         decoded = base64.b64decode(
             connector_next_msg["Hmac"]["dotted"]["subfield"]["compressed_base64"]
@@ -275,28 +262,26 @@ class BaseInputTestCase(BaseConnectorTestCase):
                 }
             }
         )
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"message": {"with_subfield": "content"}}
         raw_encoded_test_event = json.dumps(test_event, separators=(",", ":")).encode("utf-8")
         connector._get_event = mock.MagicMock(
             return_value=(test_event.copy(), raw_encoded_test_event)
         )
-        _, non_critical_error_msg = connector.get_next(1)
-        assert (
-            non_critical_error_msg
-            == "Couldn't add the hmac to the input event as the desired output field 'message' already exist."
-        )
+        with pytest.raises(CriticalInputError, match="could not be written") as error:
+            _ = connector.get_next(1)
+        assert error.value.raw_input == {"message": {"with_subfield": "content"}}
 
     def test_get_next_without_hmac(self):
         connector_config = deepcopy(self.CONFIG)
         assert not connector_config.get("preprocessing", {}).get("hmac")
         test_event = {"message": "with_content"}
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         raw_encoded_test_event = json.dumps(test_event, separators=(",", ":")).encode("utf-8")
         connector._get_event = mock.MagicMock(
             return_value=(test_event.copy(), raw_encoded_test_event)
         )
-        connector_next_msg, _ = connector.get_next(1)
+        connector_next_msg = connector.get_next(1)
         assert connector_next_msg == test_event
 
     def test_preprocessing_version_info_is_added_if_configured(self):
@@ -309,10 +294,10 @@ class BaseInputTestCase(BaseConnectorTestCase):
         }
         connector_config = deepcopy(self.CONFIG)
         connector_config.update(preprocessing_config)
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"any": "content"}
         connector._get_event = mock.MagicMock(return_value=(test_event, None))
-        result, _ = connector.get_next(0.01)
+        result = connector.get_next(0.01)
         assert result.get("version_info", {}).get("logprep") == "3.3.0"
         assert result.get("version_info", {}).get("configuration") == "unset"
 
@@ -325,11 +310,12 @@ class BaseInputTestCase(BaseConnectorTestCase):
         }
         connector_config = deepcopy(self.CONFIG)
         connector_config.update(preprocessing_config)
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"any": "content", "version_info": "something random"}
         connector._get_event = mock.MagicMock(return_value=(test_event, None))
-        result, _ = connector.get_next(0.01)
-        assert result == {"any": "content", "version_info": "something random"}
+        with pytest.raises(CriticalInputError, match="could not be written") as error:
+            _ = connector.get_next(0.01)
+        assert error.value.raw_input == {"any": "content", "version_info": "something random"}
 
     def test_pipeline_preprocessing_only_version_information(self):
         preprocessing_config = {
@@ -339,11 +325,12 @@ class BaseInputTestCase(BaseConnectorTestCase):
         }
         connector_config = deepcopy(self.CONFIG)
         connector_config.update(preprocessing_config)
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"any": "content", "version_info": "something random"}
         connector._get_event = mock.MagicMock(return_value=(test_event, None))
-        result, _ = connector.get_next(0.01)
-        assert result == {"any": "content", "version_info": "something random"}
+        with pytest.raises(CriticalInputError, match="could not be written") as error:
+            _ = connector.get_next(0.01)
+        assert error.value.raw_input == {"any": "content", "version_info": "something random"}
 
     def test_get_raw_event_is_callable(self):
         # should be overwritten for special implementation
@@ -370,9 +357,9 @@ class BaseInputTestCase(BaseConnectorTestCase):
         }
         connector_config = deepcopy(self.CONFIG)
         connector_config.update(preprocessing_config)
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         connector._get_event = mock.MagicMock(return_value=({"any": "content"}, None))
-        result, _ = connector.get_next(0.01)
+        result = connector.get_next(0.01)
         target_field = preprocessing_config.get("preprocessing", {}).get(
             "log_arrival_time_target_field"
         )
@@ -390,11 +377,56 @@ class BaseInputTestCase(BaseConnectorTestCase):
         }
         connector_config = deepcopy(self.CONFIG)
         connector_config.update(preprocessing_config)
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"any": "content", "arrival_time": "does not matter"}
         connector._get_event = mock.MagicMock(return_value=(test_event, None))
-        result, _ = connector.get_next(0.01)
-        assert result == {"any": "content", "arrival_time": "does not matter"}
+        with pytest.raises(CriticalInputError, match="could not be written") as error:
+            _ = connector.get_next(0.01)
+        assert error.value.raw_input == {"any": "content", "arrival_time": "does not matter"}
+
+    def test_pipeline_preprocessing_add_log_arrival_time_if_target_parent_field_exists_already_and_is_dict(
+        self,
+    ):
+        preprocessing_config = {
+            "preprocessing": {
+                "log_arrival_time_target_field": "event.created",
+            }
+        }
+        connector_config = deepcopy(self.CONFIG)
+        connector_config.update(preprocessing_config)
+        connector = Factory.create({"test connector": connector_config})
+        test_event = {"any": "content", "event": {"does not": "matter"}}
+        connector._get_event = mock.MagicMock(return_value=(test_event, None))
+        event = connector.get_next(0.01)
+        time_value = get_dotted_field_value(event, "event.created")
+        assert time_value
+        iso8601_regex = (
+            r"^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2})(\.\d+)?(Z|([+-]\d{2}:\d{2})$)"
+        )
+        assert re.search(iso8601_regex, time_value)
+
+    def test_pipeline_preprocessing_add_log_arrival_time_if_target_parent_field_exists_already_and_not_dict(
+        self,
+    ):
+        preprocessing_config = {
+            "preprocessing": {
+                "log_arrival_time_target_field": "event.created",
+            }
+        }
+        connector_config = deepcopy(self.CONFIG)
+        connector_config.update(preprocessing_config)
+        connector = Factory.create({"test connector": connector_config})
+        test_event = {"any": "content", "event": "does not matter"}
+        connector._get_event = mock.MagicMock(return_value=(test_event, None))
+        event = connector.get_next(0.01)
+        time_value = get_dotted_field_value(event, "event.created")
+        assert time_value
+        iso8601_regex = (
+            r"^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2})(\.\d+)?(Z|([+-]\d{2}:\d{2})$)"
+        )
+        assert re.search(iso8601_regex, time_value)
+        original_event = get_dotted_field_value(event, "event.@original")
+        assert original_event == "does not matter"
 
     def test_pipeline_preprocessing_adds_timestamp_delta_if_configured(self):
         preprocessing_config = {
@@ -408,10 +440,10 @@ class BaseInputTestCase(BaseConnectorTestCase):
         }
         connector_config = deepcopy(self.CONFIG)
         connector_config.update(preprocessing_config)
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"any": "content", "@timestamp": "1999-09-09T09:09:09.448319+02:00"}
         connector._get_event = mock.MagicMock(return_value=(test_event, None))
-        result, _ = connector.get_next(0.01)
+        result = connector.get_next(0.01)
         target_field = (
             preprocessing_config.get("preprocessing")
             .get("log_arrival_timedelta")
@@ -434,10 +466,10 @@ class BaseInputTestCase(BaseConnectorTestCase):
         }
         connector_config = deepcopy(self.CONFIG)
         connector_config.update(preprocessing_config)
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"any": "content"}
         connector._get_event = mock.MagicMock(return_value=(test_event, None))
-        result, _ = connector.get_next(0.01)
+        result = connector.get_next(0.01)
         assert "arrival_time" in result
         assert "log_arrival_timedelta" not in result
 
@@ -449,10 +481,10 @@ class BaseInputTestCase(BaseConnectorTestCase):
         }
         connector_config = deepcopy(self.CONFIG)
         connector_config.update(preprocessing_config)
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"any": "content"}
         connector._get_event = mock.MagicMock(return_value=(test_event, None))
-        result, _ = connector.get_next(0.01)
+        result = connector.get_next(0.01)
         assert "arrival_time" in result
 
     def test_pipeline_preprocessing_does_not_add_timestamp_delta_if_configured_but_log_arrival_timestamp_not(
@@ -468,10 +500,10 @@ class BaseInputTestCase(BaseConnectorTestCase):
         }
         connector_config = deepcopy(self.CONFIG)
         connector_config.update(preprocessing_config)
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"any": "content"}
         connector._get_event = mock.MagicMock(return_value=(test_event, None))
-        result, _ = connector.get_next(0.01)
+        result = connector.get_next(0.01)
         assert result == {"any": "content"}
 
     def test_preprocessing_enriches_by_env_variable(self):
@@ -484,11 +516,11 @@ class BaseInputTestCase(BaseConnectorTestCase):
         }
         connector_config = deepcopy(self.CONFIG)
         connector_config.update(preprocessing_config)
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"any": "content"}
         os.environ["TEST_ENV_VARIABLE"] = "test_value"
         connector._get_event = mock.MagicMock(return_value=(test_event, None))
-        result, _ = connector.get_next(0.01)
+        result = connector.get_next(0.01)
         assert result == {"any": "content", "enriched_field": "test_value"}
 
     def test_preprocessing_enriches_by_multiple_env_variables(self):
@@ -502,12 +534,12 @@ class BaseInputTestCase(BaseConnectorTestCase):
         }
         connector_config = deepcopy(self.CONFIG)
         connector_config.update(preprocessing_config)
-        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        connector = Factory.create({"test connector": connector_config})
         test_event = {"any": "content"}
         os.environ["TEST_ENV_VARIABLE_FOO"] = "test_value_foo"
         os.environ["TEST_ENV_VARIABLE_BAR"] = "test_value_bar"
         connector._get_event = mock.MagicMock(return_value=(test_event, None))
-        result, _ = connector.get_next(0.01)
+        result = connector.get_next(0.01)
         assert result == {
             "any": "content",
             "enriched_field1": "test_value_foo",
@@ -521,7 +553,7 @@ class BaseInputTestCase(BaseConnectorTestCase):
         self.object.get_next(0.01)
         assert self.object.metrics.number_of_processed_events == 1
 
-    def test_get_next_doesnt_count_numer_of_processed_events_if_event_is_none(self):
+    def test_get_next_does_not_count_number_of_processed_events_if_event_is_none(self):
         self.object.metrics.number_of_processed_events = 0
         self.object._get_event = mock.MagicMock(return_value=(None, None))
         self.object.get_next(0.01)
@@ -546,13 +578,3 @@ class BaseOutputTestCase(BaseConnectorTestCase):
         self.object.metrics.number_of_processed_events = 0
         self.object.store({"message": "my event message"})
         assert self.object.metrics.number_of_processed_events == 1
-
-    def test_store_failed_counts_failed_events(self):
-        self.object.metrics.number_of_failed_events = 0
-        self.object.store_failed("error", {"message": "my event message"}, {})
-        assert self.object.metrics.number_of_failed_events == 1
-
-    def test_store_calls_batch_finished_callback(self):
-        self.object.input_connector = mock.MagicMock()
-        self.object.store({"message": "my event message"})
-        self.object.input_connector.batch_finished_callback.assert_called()
