@@ -3,12 +3,13 @@
 # pylint: disable=wrong-import-position
 # pylint: disable=wrong-import-order
 # pylint: disable=attribute-defined-outside-init
+import os
 import socket
 from copy import deepcopy
 from unittest import mock
 
 import pytest
-from confluent_kafka import OFFSET_BEGINNING, KafkaException
+from confluent_kafka import OFFSET_BEGINNING, KafkaError, KafkaException
 
 from logprep.abc.input import (
     CriticalInputError,
@@ -16,6 +17,7 @@ from logprep.abc.input import (
     FatalInputError,
     InputWarning,
 )
+from logprep.connector.confluent_kafka.input import logger
 from logprep.factory import Factory
 from logprep.factory_error import InvalidConfigurationError
 from tests.unit.connector.base import BaseInputTestCase
@@ -31,6 +33,7 @@ class TestConfluentKafkaInput(BaseInputTestCase, CommonConfluentKafkaTestCase):
         "type": "confluentkafka_input",
         "kafka_config": {"bootstrap.servers": "testserver:9092", "group.id": "testgroup"},
         "topic": "test_input_raw",
+        "health_timeout": 0.1,
     }
 
     expected_metrics = [
@@ -52,7 +55,6 @@ class TestConfluentKafkaInput(BaseInputTestCase, CommonConfluentKafkaTestCase):
         "logprep_confluent_kafka_input_librdkafka_tx_bytes",
         "logprep_processing_time_per_event",
         "logprep_number_of_processed_events",
-        "logprep_number_of_failed_events",
         "logprep_number_of_warnings",
         "logprep_number_of_errors",
     ]
@@ -60,14 +62,23 @@ class TestConfluentKafkaInput(BaseInputTestCase, CommonConfluentKafkaTestCase):
     @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
     def test_get_next_returns_none_if_no_records(self, _):
         self.object._consumer.poll = mock.MagicMock(return_value=None)
-        event, non_critical_error_msg = self.object.get_next(1)
+        event = self.object.get_next(1)
         assert event is None
-        assert non_critical_error_msg is None
 
     @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
     def test_get_next_raises_critical_input_exception_for_invalid_confluent_kafka_record(self, _):
         mock_record = mock.MagicMock()
-        mock_record.error = mock.MagicMock(return_value="An arbitrary confluent-kafka error")
+        mock_record.error = mock.MagicMock(
+            return_value=KafkaError(
+                error=3,
+                reason="Subscribed topic not available: (Test Instance Name) : "
+                "Broker: Unknown topic or partition",
+                fatal=False,
+                retriable=False,
+                txn_requires_abort=False,
+            )
+        )
+
         mock_record.value = mock.MagicMock(return_value=None)
         self.object._consumer.poll = mock.MagicMock(return_value=mock_record)
         with pytest.raises(
@@ -76,10 +87,10 @@ class TestConfluentKafkaInput(BaseInputTestCase, CommonConfluentKafkaTestCase):
                 r"CriticalInputError in ConfluentKafkaInput \(Test Instance Name\) - "
                 r"Kafka Input: testserver:9092: "
                 r"A confluent-kafka record contains an error code -> "
-                r"An arbitrary confluent-kafka error"
+                r"event was written to error output if configured"
             ),
         ):
-            _, _ = self.object.get_next(1)
+            _ = self.object.get_next(1)
 
     @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
     def test_shut_down_calls_consumer_close(self, _):
@@ -87,60 +98,38 @@ class TestConfluentKafkaInput(BaseInputTestCase, CommonConfluentKafkaTestCase):
         self.object.shut_down()
         kafka_consumer.close.assert_called()
 
-    @pytest.mark.parametrize(
-        "settings,handlers",
-        [
-            (
-                {"enable.auto.offset.store": "false", "enable.auto.commit": "true"},
-                ("store_offsets",),
-            ),
-            (
-                {"enable.auto.offset.store": "false", "enable.auto.commit": "false"},
-                ("store_offsets", "commit"),
-            ),
-            ({"enable.auto.offset.store": "true", "enable.auto.commit": "false"}, None),
-            ({"enable.auto.offset.store": "true", "enable.auto.commit": "true"}, None),
-        ],
-    )
     @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
-    def test_batch_finished_callback_calls_offsets_handler_for_setting(self, _, settings, handlers):
+    def test_batch_finished_callback_calls_store_offsets(self, _):
         input_config = deepcopy(self.CONFIG)
-        kafka_input = Factory.create({"test": input_config}, logger=self.logger)
-        kafka_input._config.kafka_config.update(settings)
+        kafka_input = Factory.create({"test": input_config})
         kafka_consumer = kafka_input._consumer
         message = "test message"
-        kafka_input._last_valid_records = {0: message}
+        kafka_input._last_valid_record = message
         kafka_input.batch_finished_callback()
-        if handlers is None:
-            assert kafka_consumer.commit.call_count == 0
-            assert kafka_consumer.store_offsets.call_count == 0
-        else:
-            for handler in handlers:
-                getattr(kafka_consumer, handler).assert_called()
-                getattr(kafka_consumer, handler).assert_called_with(message=message)
+        kafka_consumer.store_offsets.assert_called()
+        kafka_consumer.store_offsets.assert_called_with(message=message)
 
-    @pytest.mark.parametrize(
-        "settings,handler",
-        [
-            ({"enable.auto.offset.store": "false", "enable.auto.commit": "true"}, "store_offsets"),
-            ({"enable.auto.offset.store": "false", "enable.auto.commit": "false"}, "commit"),
-        ],
-    )
     @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
-    def test_batch_finished_callback_raises_input_warning_on_kafka_exception(
-        self, _, settings, handler
-    ):
+    def test_batch_finished_callback_does_not_call_store_offsets(self, _):
         input_config = deepcopy(self.CONFIG)
-        kafka_input = Factory.create({"test": input_config}, logger=self.logger)
-        kafka_input._config.kafka_config.update(settings)
+        kafka_input = Factory.create({"test": input_config})
+        kafka_consumer = kafka_input._consumer
+        kafka_input._last_valid_record = None
+        kafka_input.batch_finished_callback()
+        kafka_consumer.store_offsets.assert_not_called()
+
+    @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
+    def test_batch_finished_callback_raises_input_warning_on_kafka_exception(self, _):
+        input_config = deepcopy(self.CONFIG)
+        kafka_input = Factory.create({"test": input_config})
         kafka_consumer = kafka_input._consumer
         return_sequence = [KafkaException("test error"), None]
 
         def raise_generator(return_sequence):
             return list(reversed(return_sequence)).pop()
 
-        getattr(kafka_consumer, handler).side_effect = raise_generator(return_sequence)
-        kafka_input._last_valid_records = {0: "message"}
+        kafka_consumer.store_offsets.side_effect = raise_generator(return_sequence)
+        kafka_input._last_valid_record = {0: "message"}
         with pytest.raises(InputWarning):
             kafka_input.batch_finished_callback()
 
@@ -156,7 +145,7 @@ class TestConfluentKafkaInput(BaseInputTestCase, CommonConfluentKafkaTestCase):
             self.object.get_next(1)
 
     @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
-    def test_get_next_raises_critical_input_error_if_unvalid_json(self, _):
+    def test_get_next_raises_critical_input_error_if_invalid_json(self, _):
         mock_record = mock.MagicMock()
         mock_record.error = mock.MagicMock()
         mock_record.error.return_value = None
@@ -190,15 +179,53 @@ class TestConfluentKafkaInput(BaseInputTestCase, CommonConfluentKafkaTestCase):
         result = self.object._get_raw_event(0.001)
         assert result
 
+    @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
+    def test_get_event_raises_exception_if_input_invalid_json(self, _):
+        mock_record = mock.MagicMock()
+        mock_record.error = mock.MagicMock()
+        mock_record.error.return_value = None
+        self.object._consumer.poll = mock.MagicMock(return_value=mock_record)
+        mock_record.value = mock.MagicMock()
+        mock_record.value.return_value = '{"invalid_json"}'.encode("utf8")
+        with pytest.raises(
+            CriticalInputParsingError,
+            match=(
+                r"Input record value is not a valid json string ->"
+                r" event was written to error output if configured"
+            ),
+        ) as error:
+            self.object._get_event(0.001)
+        assert error.value.raw_input == b'{"invalid_json"}'
+
+    @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
+    def test_get_event_raises_exception_if_input_not_utf(self, _):
+        mock_record = mock.MagicMock()
+        mock_record.error = mock.MagicMock()
+        mock_record.error.return_value = None
+        self.object._consumer.poll = mock.MagicMock(return_value=mock_record)
+        mock_record.value = mock.MagicMock()
+        mock_record.value.return_value = '{"not_utf-8": \xfc}'.encode("cp1252")
+        with pytest.raises(
+            CriticalInputParsingError,
+            match=(
+                r"Input record value is not \'utf-8\' encoded ->"
+                r" event was written to error output if configured"
+            ),
+        ) as error:
+            self.object._get_event(0.001)
+        assert error.value.raw_input == "b'{\"not_utf-8\": \\xfc}'"
+
     def test_setup_raises_fatal_input_error_on_invalid_config(self):
-        config = {
+        kafka_config = {
             "bootstrap.servers": "testinstance:9092",
             "group.id": "sapsal",
             "myconfig": "the config",
         }
-        self.object._config.kafka_config = config
+        config = deepcopy(self.CONFIG)
+        config["kafka_config"] = kafka_config
+        connector = Factory.create({"test": config})
         with pytest.raises(FatalInputError, match="No such configuration property"):
-            self.object.setup()
+            connector.setup()
 
     def test_get_next_raises_critical_input_parsing_error(self):
         return_value = b'{"invalid": "json'
@@ -208,7 +235,7 @@ class TestConfluentKafkaInput(BaseInputTestCase, CommonConfluentKafkaTestCase):
 
     def test_commit_callback_raises_warning_error_and_counts_failures(self):
         with pytest.raises(InputWarning, match="Could not commit offsets"):
-            self.object._commit_callback(BaseException, ["topic_partition"])
+            self.object._commit_callback(Exception, ["topic_partition"])
             assert self.object._commit_failures == 1
 
     def test_commit_callback_counts_commit_success(self):
@@ -237,7 +264,8 @@ class TestConfluentKafkaInput(BaseInputTestCase, CommonConfluentKafkaTestCase):
             "statistics.interval.ms": "30000",
             "bootstrap.servers": "testserver:9092",
             "group.id": "testgroup",
-            "logger": self.object._logger,
+            "group.instance.id": f"{socket.getfqdn().strip('.')}-PipelineNone-pid{os.getpid()}",
+            "logger": logger,
             "on_commit": self.object._commit_callback,
             "stats_cb": self.object._stats_callback,
             "error_cb": self.object._error_callback,
@@ -246,19 +274,42 @@ class TestConfluentKafkaInput(BaseInputTestCase, CommonConfluentKafkaTestCase):
         mock_consumer.assert_called_with(injected_config)
 
     @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
-    def test_client_id_can_be_overwritten(self, mock_consumer):
+    def test_auto_offset_store_and_auto_commit_are_managed_by_connector(self, mock_consumer):
+        config = deepcopy(self.CONFIG)
+        config["kafka_config"] |= {
+            "enable.auto.offset.store": "true",
+            "enable.auto.commit": "false",
+        }
+        kafka_input = Factory.create({"test": config})
+        _ = kafka_input._consumer
+        mock_consumer.assert_called()
+        injected_config = mock_consumer.call_args[0][0]
+        assert injected_config.get("enable.auto.offset.store") == "false"
+        assert injected_config.get("enable.auto.commit") == "true"
+
+    @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
+    @mock.patch("logprep.connector.confluent_kafka.input.AdminClient")
+    def test_client_id_can_be_overwritten(self, _, mock_consumer):
         input_config = deepcopy(self.CONFIG)
-        kafka_input = Factory.create({"test": input_config}, logger=self.logger)
-        kafka_input._config.kafka_config["client.id"] = "thisclientid"
+        input_config["kafka_config"]["client.id"] = "thisclientid"
+        kafka_input = Factory.create({"test": input_config})
+        metadata = mock.MagicMock()
+        metadata.topics = [kafka_input._config.topic]
+        kafka_input._admin.list_topics.return_value = metadata
         kafka_input.setup()
         mock_consumer.assert_called()
         assert mock_consumer.call_args[0][0].get("client.id") == "thisclientid"
         assert not mock_consumer.call_args[0][0].get("client.id") == socket.getfqdn()
 
     @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
-    def test_statistics_interval_can_be_overwritten(self, mock_consumer):
-        kafka_input = Factory.create({"test": self.CONFIG}, logger=self.logger)
-        kafka_input._config.kafka_config["statistics.interval.ms"] = "999999999"
+    @mock.patch("logprep.connector.confluent_kafka.input.AdminClient")
+    def test_statistics_interval_can_be_overwritten(self, _, mock_consumer):
+        input_config = deepcopy(self.CONFIG)
+        input_config["kafka_config"]["statistics.interval.ms"] = "999999999"
+        kafka_input = Factory.create({"test": input_config})
+        metadata = mock.MagicMock()
+        metadata.topics = [kafka_input._config.topic]
+        kafka_input._admin.list_topics.return_value = metadata
         kafka_input.setup()
         mock_consumer.assert_called()
         assert mock_consumer.call_args[0][0].get("statistics.interval.ms") == "999999999"
@@ -275,7 +326,7 @@ class TestConfluentKafkaInput(BaseInputTestCase, CommonConfluentKafkaTestCase):
         config.get("kafka_config").pop("group.id")
         expected_error_message = r"keys are missing: {'(bootstrap.servers|group.id)', '(bootstrap.servers|group.id)'}"  # pylint: disable=line-too-long
         with pytest.raises(InvalidConfigurationError, match=expected_error_message):
-            Factory.create({"test": config}, logger=self.logger)
+            Factory.create({"test": config})
 
     @pytest.mark.parametrize(
         "metric_name",
@@ -290,17 +341,12 @@ class TestConfluentKafkaInput(BaseInputTestCase, CommonConfluentKafkaTestCase):
         assert len(metric_object.samples) == 0
 
     @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
-    def test_lost_callback_reassings_to_partitions(self, mock_consumer):
-        mock_partitions = [mock.MagicMock()]
-        self.object._consumer.assign = mock.MagicMock()
-        self.object._lost_callback(mock_consumer, mock_partitions)
-        self.object._consumer.assign.assert_called_with(mock_partitions)
-
-    @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
-    def test_lost_callback_counts_warnings(self, mock_consumer):
+    def test_lost_callback_counts_warnings_and_logs(self, mock_consumer):
         self.object.metrics.number_of_warnings = 0
         mock_partitions = [mock.MagicMock()]
-        self.object._lost_callback(mock_consumer, mock_partitions)
+        with mock.patch("logging.Logger.warning") as mock_warning:
+            self.object._lost_callback(mock_consumer, mock_partitions)
+        mock_warning.assert_called()
         assert self.object.metrics.number_of_warnings == 1
 
     @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
@@ -340,12 +386,71 @@ class TestConfluentKafkaInput(BaseInputTestCase, CommonConfluentKafkaTestCase):
         assert self.object.metrics.number_of_warnings == 1
 
     @mock.patch("logprep.connector.confluent_kafka.input.Consumer")
-    def test_revoke_callback_writes_output_backlog_and_calls_batch_finished_callback(
-        self, mock_consumer
-    ):
+    def test_revoke_callback_calls_batch_finished_callback(self, mock_consumer):
         self.object.output_connector = mock.MagicMock()
         self.object.batch_finished_callback = mock.MagicMock()
         mock_partitions = [mock.MagicMock()]
         self.object._revoke_callback(mock_consumer, mock_partitions)
-        self.object.output_connector._write_backlog.assert_called()
         self.object.batch_finished_callback.assert_called()
+
+    def test_health_returns_true_if_no_error(self):
+        self.object._admin = mock.MagicMock()
+        metadata = mock.MagicMock()
+        metadata.topics = [self.object._config.topic]
+        self.object._admin.list_topics.return_value = metadata
+        assert self.object.health()
+
+    def test_health_returns_false_if_topic_not_present(self):
+        self.object._consumer = mock.MagicMock()
+        metadata = mock.MagicMock()
+        metadata.topics = ["not_the_topic"]
+        self.object._consumer.list_topics.return_value = metadata
+        assert not self.object.health()
+
+    def test_health_returns_false_on_kafka_exception(self):
+        self.object._consumer = mock.MagicMock()
+        self.object._consumer.list_topics.side_effect = KafkaException("test error")
+        assert not self.object.health()
+
+    def test_health_logs_error_on_kafka_exception(self):
+        self.object._consumer = mock.MagicMock()
+        self.object._consumer.list_topics.side_effect = KafkaException("test error")
+        with mock.patch("logging.Logger.error") as mock_error:
+            self.object.health()
+        mock_error.assert_called()
+
+    def test_health_counts_metrics_on_kafka_exception(self):
+        self.object.metrics.number_of_errors = 0
+        self.object._consumer = mock.MagicMock()
+        self.object._consumer.list_topics.side_effect = KafkaException("test error")
+        assert not self.object.health()
+        assert self.object.metrics.number_of_errors == 1
+
+    @pytest.mark.parametrize(
+        ["kafka_config_update", "expected_admin_client_config"],
+        [
+            ({}, {"bootstrap.servers": "testserver:9092"}),
+            ({"statistics.foo": "bar"}, {"bootstrap.servers": "testserver:9092"}),
+            (
+                {"security.foo": "bar"},
+                {"bootstrap.servers": "testserver:9092", "security.foo": "bar"},
+            ),
+            (
+                {"ssl.foo": "bar"},
+                {"bootstrap.servers": "testserver:9092", "ssl.foo": "bar"},
+            ),
+            (
+                {"security.foo": "bar", "ssl.foo": "bar"},
+                {"bootstrap.servers": "testserver:9092", "security.foo": "bar", "ssl.foo": "bar"},
+            ),
+        ],
+    )
+    @mock.patch("logprep.connector.confluent_kafka.input.AdminClient")
+    def test_set_security_related_config_in_admin_client(
+        self, admin_client, kafka_config_update, expected_admin_client_config
+    ):
+        new_kafka_config = deepcopy(self.CONFIG)
+        new_kafka_config["kafka_config"].update(kafka_config_update)
+        input_connector = Factory.create({"input_connector": new_kafka_config})
+        _ = input_connector._admin
+        admin_client.assert_called_with(expected_admin_client_config)
