@@ -10,7 +10,7 @@ from logprep.factory import Factory
 from tests.unit.connector.base import BaseInputTestCase
 
 
-class DummyError(BaseException):
+class DummyError(Exception):
     pass
 
 
@@ -24,31 +24,37 @@ class TestDummyInput(BaseInputTestCase):
             self.object.get_next(self.timeout)
 
     def test_returns_documents_in_order_provided(self):
-        self.object._config.documents = [{"order": 0}, {"order": 1}, {"order": 2}]
+        config = copy.deepcopy(self.CONFIG)
+        config["documents"] = [{"order": 0}, {"order": 1}, {"order": 2}]
+        self.object = Factory.create({"Test Instance Name": config})
         for order in range(0, 3):
-            event, _ = self.object.get_next(self.timeout)
+            event = self.object.get_next(self.timeout)
             assert event.get("order") == order
 
     def test_raises_exceptions_instead_of_returning_them_in_document(self):
-        self.object._config.documents = [{"order": 0}, DummyError, {"order": 1}]
-        event, _ = self.object.get_next(self.timeout)
+        config = copy.deepcopy(self.CONFIG)
+        config["documents"] = [{"order": 0}, DummyError, {"order": 1}]
+        self.object = Factory.create({"Test Instance Name": config})
+        event = self.object.get_next(self.timeout)
         assert event.get("order") == 0
         with raises(DummyError):
             _, _ = self.object.get_next(self.timeout)
-        event, _ = self.object.get_next(self.timeout)
+        event = self.object.get_next(self.timeout)
         assert event.get("order") == 1
 
     def test_raises_exceptions_instead_of_returning_them(self):
-        self.object._config.documents = [BaseException]
-        with raises(BaseException):
+        config = copy.deepcopy(self.CONFIG)
+        config["documents"] = [Exception]
+        self.object = Factory.create({"Test Instance Name": config})
+        with raises(Exception):
             self.object.get_next(self.timeout)
 
     def test_repeat_documents_repeats_documents(self):
         config = copy.deepcopy(self.CONFIG)
         config["repeat_documents"] = True
-        connector = Factory.create(configuration={"Test Instance Name": config}, logger=self.logger)
-        connector._config.documents = [{"order": 0}, {"order": 1}, {"order": 2}]
+        config["documents"] = [{"order": 0}, {"order": 1}, {"order": 2}]
+        connector = Factory.create(configuration={"Test Instance Name": config})
 
         for order in range(0, 9):
-            event, _ = connector.get_next(self.timeout)
+            event = connector.get_next(self.timeout)
             assert event.get("order") == order % 3
