@@ -2,7 +2,7 @@
 # pylint: disable=no-self-use
 from copy import deepcopy
 
-from pytest import raises, fail
+from pytest import fail, raises
 
 from logprep.abc.output import FatalOutputError
 from logprep.factory import Factory
@@ -28,11 +28,6 @@ class TestDummyOutput(BaseOutputTestCase):
         assert len(self.object.events) == 1
         assert self.object.events[0] == document
 
-    def test_increments_setup_called_count_when_setup_was_called(self):
-        assert self.object.setup_called_count == 0
-        self.object.setup()
-        assert self.object.setup_called_count == 1
-
     def test_increments_shutdown_called_count_when_shutdown_was_called(self):
         assert self.object.shut_down_called_count == 0
         self.object.shut_down()
@@ -48,15 +43,15 @@ class TestDummyOutput(BaseOutputTestCase):
     def test_raises_exception_on_call_to_store(self):
         config = deepcopy(self.CONFIG)
         config.update({"exceptions": ["FatalOutputError"]})
-        dummy_output = Factory.create({"test connector": config}, logger=self.logger)
+        dummy_output = Factory.create({"test connector": config})
 
-        with raises(BaseException, match="FatalOutputError"):
+        with raises(Exception, match="FatalOutputError"):
             dummy_output.store({"order": 0})
 
     def test_raises_exception_on_call_to_store_custom(self):
         config = deepcopy(self.CONFIG)
         config.update({"exceptions": ["FatalOutputError"]})
-        dummy_output = Factory.create({"test connector": config}, logger=self.logger)
+        dummy_output = Factory.create({"test connector": config})
 
         with raises(Exception, match="FatalOutputError"):
             dummy_output.store_custom({"order": 0}, target="whatever")
@@ -64,7 +59,7 @@ class TestDummyOutput(BaseOutputTestCase):
     def test_raises_exception_only_once(self):
         config = deepcopy(self.CONFIG)
         config.update({"exceptions": ["FatalOutputError"]})
-        dummy_output = Factory.create({"test connector": config}, logger=self.logger)
+        dummy_output = Factory.create({"test connector": config})
 
         with raises(Exception, match="FatalOutputError"):
             dummy_output.store({"order": 0})
@@ -76,19 +71,9 @@ class TestDummyOutput(BaseOutputTestCase):
     def test_raises_exception_only_when_not_none(self):
         config = deepcopy(self.CONFIG)
         config.update({"exceptions": [None, "FatalOutputError", None]})
-        dummy_output = Factory.create({"test connector": config}, logger=self.logger)
+        dummy_output = Factory.create({"test connector": config})
 
         dummy_output.store({"order": 0})
         with raises(Exception, match="FatalOutputError"):
             dummy_output.store({"order": 1})
         dummy_output.store({"order": 2})
-
-    def test_stores_failed_events_in_respective_list(self):
-        self.object.store_failed("message", {"doc": "received"}, {"doc": "processed"})
-
-        assert len(self.object.failed_events) == 1
-        assert self.object.failed_events[0] == (
-            "message",
-            {"doc": "received"},
-            {"doc": "processed"},
-        )
