@@ -144,12 +144,12 @@ class TestFileInput(BaseInputTestCase):
 
     def test_input_line_function_returns_empty_string(self):
         wait_for_interval(CHECK_INTERVAL)
-        assert self.object._line_to_dict("") == ""
+        assert not self.object._line_to_dict("")
 
     def test_log_from_file_with_get_next(self):
         wait_for_interval(CHECK_INTERVAL)
         get_next_log_line = self.object.get_next(timeout=0.001)
-        assert get_next_log_line[0].get("message") == test_initial_log_data[0]
+        assert get_next_log_line.get("message") == test_initial_log_data[0]
 
     def test_log_from_file_is_put_in_queue(self):
         wait_for_interval(CHECK_INTERVAL)
