@@ -28,14 +28,14 @@ class TestJsonlInput(BaseInputTestCase):
     def test_get_next_returns_document(self, mock_parse):
         mock_parse.return_value = [{"message": "test_message"}]
         expected = {"message": "test_message"}
-        document, _ = self.object.get_next(self.timeout)
+        document = self.object.get_next(self.timeout)
         assert document == expected
 
     @mock.patch(parse_function)
     def test_get_next_returns_multiple_documents(self, mock_parse):
         mock_parse.return_value = [{"order": 0}, {"order": 1}]
-        assert ({"order": 0}, None) == self.object.get_next(self.timeout)
-        assert ({"order": 1}, None) == self.object.get_next(self.timeout)
+        assert {"order": 0} == self.object.get_next(self.timeout)
+        assert {"order": 1} == self.object.get_next(self.timeout)
 
     @mock.patch(parse_function)
     def test_raises_exception_if_not_a_dict(self, mock_parse):
@@ -56,8 +56,12 @@ class TestJsonlInput(BaseInputTestCase):
         config = copy.deepcopy(self.CONFIG)
         config["repeat_documents"] = True
         mock_parse.return_value = [{"order": 0}, {"order": 1}, {"order": 2}]
-        object = Factory.create(configuration={"Test Instance Name": config}, logger=self.logger)
+        object = Factory.create(configuration={"Test Instance Name": config})
 
         for order in range(0, 9):
-            event, _ = object.get_next(self.timeout)
+            event = object.get_next(self.timeout)
             assert event.get("order") == order % 3
+
+    @pytest.mark.skip(reason="not implemented")
+    def test_setup_calls_wait_for_health(self):
+        pass
