@@ -5,16 +5,20 @@ import re
 import pytest
 from pytest import raises
 
-from logprep.filter.lucene_filter import LuceneFilter, LuceneFilterError, LuceneTransformer
 from logprep.filter.expression.filter_expression import (
-    StringFilterExpression,
-    RegExFilterExpression,
-    Or,
-    And,
-    Null,
     Always,
+    And,
     Exists,
     Not,
+    Null,
+    Or,
+    RegExFilterExpression,
+    StringFilterExpression,
+)
+from logprep.filter.lucene_filter import (
+    LuceneFilter,
+    LuceneFilterError,
+    LuceneTransformer,
 )
 
 
@@ -451,3 +455,66 @@ class TestLueceneFilter:
     def test_create_filter_error(self, testcase, input_str, message):
         with raises(LuceneFilterError, match=re.escape(message)):
             LuceneFilter.create(f'foo: "{input_str}"')
+
+    def test_creates_lucene_compliance_filter_two_matching_regex_keys_of_two(self):
+        lucene_filter = LuceneFilter.create(
+            "regex_key_one: /.*value.*/ AND regex_key_two: /.*value.*/",
+        )
+
+        assert lucene_filter == And(
+            RegExFilterExpression(["regex_key_one"], ".*value.*"),
+            RegExFilterExpression(["regex_key_two"], ".*value.*"),
+        )
+
+    def test_creates_StringFilter_not_Regex(self):
+        lucene_filter = LuceneFilter.create(
+            'regex_key_one: "/.*value.*/"',
+        )
+
+        assert lucene_filter == StringFilterExpression(["regex_key_one"], "/.*value.*/")
+
+    def test_new_lucene_compliance(self):
+        lucene_filter = LuceneFilter.create("regex_key_one:/.*value.*/")
+
+        assert lucene_filter == RegExFilterExpression(["regex_key_one"], ".*value.*")
+
+    def test_creates_lucene_compliance_filter_one_matching_one_missmatch_regex_key_of_two(self):
+        lucene_filter = LuceneFilter.create(
+            'regex_key_one:/.*value.*/ AND key_two: "/.*value.*/"',
+        )
+
+        assert lucene_filter == And(
+            RegExFilterExpression(["regex_key_one"], ".*value.*"),
+            StringFilterExpression(["key_two"], "/.*value.*/"),
+        )
+
+    def test_new_lucene_compliance_double_escape(self):
+        lucene_filter = LuceneFilter.create("regex_key_one:/\\/.*value.*/")
+
+        assert lucene_filter == RegExFilterExpression(["regex_key_one"], "\/.*value.*")
+
+    def test_new_lucene_compliance_single_escape(self):
+        lucene_filter = LuceneFilter.create("regex_key_one:/\/.*value.*/")
+
+        assert lucene_filter == RegExFilterExpression(["regex_key_one"], "\/.*value.*")
+
+    def test_new_lucene_compliance_parentheses(self):
+        lucene_filter = LuceneFilter.create("regex_key_one:(/.*value.*/)")
+
+        assert lucene_filter == RegExFilterExpression(["regex_key_one"], ".*value.*")
+
+    def test_creates_lucene_compliance_filter_parentheses_or_both_regex(self):
+        lucene_filter = LuceneFilter.create("regex_key_one: (/.*value_one.*/ OR /.*value_two.*/)")
+
+        assert lucene_filter == Or(
+            RegExFilterExpression(["regex_key_one"], ".*value_one.*"),
+            RegExFilterExpression(["regex_key_one"], ".*value_two.*"),
+        )
+
+    def test_creates_lucene_compliance_filter_parentheses_or_one_regex(self):
+        lucene_filter = LuceneFilter.create('regex_key_one: (/.*value_one.*/ OR "/.*value_two.*/")')
+
+        assert lucene_filter == Or(
+            RegExFilterExpression(["regex_key_one"], ".*value_one.*"),
+            StringFilterExpression(["regex_key_one"], "/.*value_two.*/"),
+        )
