@@ -5,15 +5,13 @@
 import pytest
 
 from logprep.filter.expression.filter_expression import (
-    StringFilterExpression,
-    Not,
     Exists,
-    RegExFilterExpression,
+    Not,
+    StringFilterExpression,
 )
 from logprep.framework.rule_tree.rule_parser import RuleParser
 from logprep.processor.pre_detector.rule import PreDetectorRule
 
-
 pytest.importorskip("logprep.processor.pre_detector")
 
 string_filter_expression_1 = StringFilterExpression(["key1"], "value1")
@@ -28,7 +26,7 @@ class TestRuleParser:
         "rule, priority_dict, tag_map, expected_expressions",
         [
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "foo: bar",
                         "pre_detector": {
@@ -45,7 +43,7 @@ class TestRuleParser:
                 [[Exists(["foo"]), StringFilterExpression(["foo"], "bar")]],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "foo: bar AND bar: foo",
                         "pre_detector": {
@@ -69,7 +67,7 @@ class TestRuleParser:
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "foo: bar OR bar: foo",
                         "pre_detector": {
@@ -89,7 +87,7 @@ class TestRuleParser:
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "winlog: 123 AND test: (Good OR Okay OR Bad) OR foo: bar",
                         "pre_detector": {
@@ -126,7 +124,7 @@ class TestRuleParser:
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "(EventID: 1 AND ABC AND foo: bar)",
                         "pre_detector": {
@@ -151,7 +149,7 @@ class TestRuleParser:
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "(EventID: 17 AND PipeName: \\PSHost*) AND NOT (Image: *\\powershell.exe)",
                         "pre_detector": {
@@ -169,7 +167,6 @@ class TestRuleParser:
                     [
                         Exists(["EventID"]),
                         StringFilterExpression(["EventID"], "17"),
-                        Exists(["Image"]),
                         Not(StringFilterExpression(["Image"], "*\\powershell.exe")),
                         Exists(["PipeName"]),
                         StringFilterExpression(["PipeName"], "\\PSHost*"),
@@ -177,7 +174,7 @@ class TestRuleParser:
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "EventID: (17 OR 18) AND PipeName: (atctl OR userpipe OR iehelper)",
                         "pre_detector": {
@@ -231,7 +228,7 @@ class TestRuleParser:
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "EventID: 8 AND "
                         "SourceImage: (*System32cscript.exe OR *System32wscript.exe OR *System32mshta.exe) AND "
@@ -278,7 +275,7 @@ class TestRuleParser:
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "bar: foo AND NOT foo: bar",
                         "pre_detector": {
@@ -296,13 +293,12 @@ class TestRuleParser:
                     [
                         Exists(["bar"]),
                         StringFilterExpression(["bar"], "foo"),
-                        Exists(["foo"]),
                         Not(StringFilterExpression(["foo"], "bar")),
                     ]
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "winlog.event_id: 7036 AND NOT Something",
                         "pre_detector": {
@@ -325,7 +321,7 @@ class TestRuleParser:
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "NOT (foo: bar AND (test: ok OR msg: (123 OR 456)))",
                         "pre_detector": {
@@ -340,18 +336,16 @@ class TestRuleParser:
                 {},
                 {},
                 [
-                    [Exists(["foo"]), Not(StringFilterExpression(["foo"], "bar"))],
+                    [Not(StringFilterExpression(["foo"], "bar"))],
                     [
-                        Exists(["msg"]),
                         Not(StringFilterExpression(["msg"], "123")),
                         Not(StringFilterExpression(["msg"], "456")),
-                        Exists(["test"]),
                         Not(StringFilterExpression(["test"], "ok")),
                     ],
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "process.parent: (foo OR bar) AND process.executable: cmd.exe AND process.command_line: (perl OR python)",
                         "pre_detector": {
@@ -401,7 +395,7 @@ class TestRuleParser:
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "EventID: 15 AND NOT (Imphash: 000 OR NOT AImphash)",
                         "pre_detector": {
@@ -420,13 +414,12 @@ class TestRuleParser:
                         Not(Not(Exists(["AImphash"]))),
                         Exists(["EventID"]),
                         StringFilterExpression(["EventID"], "15"),
-                        Exists(["Imphash"]),
                         Not(StringFilterExpression(["Imphash"], "000")),
                     ]
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "(A1 OR A2) AND (B1 OR B2) AND (C1 OR C2) AND (D1 OR D2)",
                         "pre_detector": {
@@ -460,7 +453,7 @@ class TestRuleParser:
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "(A1 OR A2) AND (B1 OR (C1 AND C2))",
                         "pre_detector": {
@@ -482,7 +475,7 @@ class TestRuleParser:
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "((A1 OR A2) AND (B1 OR B2)) AND C1",
                         "pre_detector": {
@@ -504,7 +497,7 @@ class TestRuleParser:
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "winlog.channel: Security AND "
                         "winlog.event_id: 4625 AND "
@@ -528,7 +521,7 @@ class TestRuleParser:
                 None,
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "(EventID: 12 AND TargetObject: *cmmgr32.exe*) "
                         "OR (EventID: 13 AND TargetObject: *cmmgr32.exe*) "
@@ -569,7 +562,7 @@ class TestRuleParser:
                 ],
             ),
             (
-                PreDetectorRule._create_from_dict(
+                PreDetectorRule.create_from_dict(
                     {
                         "filter": "NOT bar",
                         "pre_detector": {
@@ -650,22 +643,7 @@ class TestRuleParser:
                     [Exists(["key3"]), string_filter_expression_3],
                 ],
             ),
-            (
-                [[Not(string_filter_expression_1)]],
-                [[Exists(["key1"]), Not(string_filter_expression_1)]],
-            ),
-            (
-                [[Not(Exists(["foo"]))]],
-                [[Not(Exists(["foo"]))]],
-            ),
-            (
-                [[RegExFilterExpression(["foo"], "bar")]],
-                [[Exists(["foo"]), RegExFilterExpression(["foo"], "bar")]],
-            ),
-            (
-                [[Not(RegExFilterExpression(["foo"], "bar"))]],
-                [[Exists(["foo"]), Not(RegExFilterExpression(["foo"], "bar"))]],
-            ),
+            ([[Not(string_filter_expression_1)]], [[Not(string_filter_expression_1)]]),
             (
                 [[string_filter_expression_1, Exists(["key1"])], [string_filter_expression_1]],
                 [
