@@ -1,5 +1,4 @@
 # pylint: disable=missing-docstring
-import logging
 import math
 import re
 
@@ -126,7 +125,7 @@ test_cases = [  # testcase, rule, event, expected
             "calculator": {
                 "calc": "${field1} + ${field2} +${field3}",
                 "target_field": "target",
-                "extend_target_list": True,
+                "merge_with_target": True,
             },
         },
         {"field1": "6", "field2": "4", "field3": 2, "target": [1, 5, 3]},
@@ -261,9 +260,9 @@ failure_test_cases = [  # testcase, rule, event, expected, error_message
         {
             "field2": "4",
             "field3": 2,
-            "tags": ["_calculator_failure"],
+            "tags": ["_calculator_missing_field_warning"],
         },
-        r"ProcessingWarning.*no value for fields: \['field1'\]",
+        r"ProcessingWarning.*missing source_fields: \['field1']",
     ),
     (
         "Tags failure if source_field is empty",
@@ -341,24 +340,22 @@ failure_test_cases = [  # testcase, rule, event, expected, error_message
 class TestCalculator(BaseProcessorTestCase):
     CONFIG: dict = {
         "type": "calculator",
-        "specific_rules": ["tests/testdata/unit/calculator/specific_rules"],
-        "generic_rules": ["tests/testdata/unit/calculator/generic_rules"],
+        "rules": ["tests/testdata/unit/calculator/rules"],
     }
 
     @pytest.mark.parametrize("testcase, rule, event, expected", test_cases)
     def test_testcases(self, testcase, rule, event, expected):  # pylint: disable=unused-argument
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         self.object.process(event)
         assert event == expected
 
     @pytest.mark.parametrize("testcase, rule, event, expected, error_message", failure_test_cases)
-    def test_testcases_failure_handling(
-        self, caplog, testcase, rule, event, expected, error_message
-    ):
-        self._load_specific_rule(rule)
-        with caplog.at_level(logging.WARNING):
-            self.object.process(event)
-            assert re.match(rf".*{error_message}", caplog.text)
+    def test_testcases_failure_handling(self, testcase, rule, event, expected, error_message):
+        self._load_rule(rule)
+
+        result = self.object.process(event)
+        assert len(result.warnings) == 1
+        assert re.match(rf".*{error_message}", str(result.warnings[0]))
         assert event == expected, testcase
 
     @pytest.mark.parametrize(
