@@ -2,6 +2,7 @@
 # pylint: disable=missing-docstring
 
 import pytest
+
 from logprep.processor.clusterer.rule import ClustererRule
 
 
@@ -10,7 +11,7 @@ def rule_definition():
     return {
         "filter": "message",
         "clusterer": {
-            "target": "message",
+            "source_fields": ["message"],
             "pattern": r"test (signature) test",
             "repl": "<+>\1</+>",
         },
@@ -20,9 +21,9 @@ def rule_definition():
 
 class TestClustererRule:
     def test_rules_are_equal(self, rule_definition):
-        rule1 = ClustererRule._create_from_dict(rule_definition)
+        rule1 = ClustererRule.create_from_dict(rule_definition)
 
-        rule2 = ClustererRule._create_from_dict(rule_definition)
+        rule2 = ClustererRule.create_from_dict(rule_definition)
 
         assert rule1 == rule2
 
@@ -34,7 +35,18 @@ class TestClustererRule:
                 {
                     "filter": "message",
                     "clusterer": {
-                        "target": "message",
+                        "source_fields": ["message"],
+                        "pattern": r"test (signature) test",
+                        "repl": "<+>\1</+>",
+                    },
+                },
+                True,
+            ),
+            (
+                "Should be equal cause the same with default source field",
+                {
+                    "filter": "message",
+                    "clusterer": {
                         "pattern": r"test (signature) test",
                         "repl": "<+>\1</+>",
                     },
@@ -46,7 +58,7 @@ class TestClustererRule:
                 {
                     "filter": "other_message",
                     "clusterer": {
-                        "target": "message",
+                        "source_fields": ["message"],
                         "pattern": r"test (signature) test",
                         "repl": "<+>\1</+>",
                     },
@@ -54,11 +66,11 @@ class TestClustererRule:
                 False,
             ),
             (
-                "Should be not equal cause other target",
+                "Should be not equal cause other source fields",
                 {
                     "filter": "message",
                     "clusterer": {
-                        "target": "other message",
+                        "source_fields": ["other message"],
                         "pattern": r"test (signature) test",
                         "repl": "<+>\1</+>",
                     },
@@ -70,7 +82,7 @@ class TestClustererRule:
                 {
                     "filter": "message",
                     "clusterer": {
-                        "target": "message",
+                        "source_fields": ["message"],
                         "pattern": r"other test (signature) test",
                         "repl": "<+>\1</+>",
                     },
@@ -82,7 +94,7 @@ class TestClustererRule:
                 {
                     "filter": "message",
                     "clusterer": {
-                        "target": "message",
+                        "source_fields": ["message"],
                         "pattern": r"test (signature) test",
                         "repl": "other <+>\1</+>",
                     },
@@ -92,6 +104,6 @@ class TestClustererRule:
         ],
     )
     def test_rules_equality(self, rule_definition, testcase, other_rule_definition, is_equal):
-        rule1 = ClustererRule._create_from_dict(rule_definition)
-        rule2 = ClustererRule._create_from_dict(other_rule_definition)
+        rule1 = ClustererRule.create_from_dict(rule_definition)
+        rule2 = ClustererRule.create_from_dict(other_rule_definition)
         assert (rule1 == rule2) == is_equal, testcase
