@@ -2,11 +2,10 @@
 # pylint: disable=missing-module-docstring
 # pylint: disable=wrong-import-position
 # pylint: disable=wrong-import-order
-import logging
-import re
 
 from dateutil.tz import tzutc
 
+from logprep.processor.base.exceptions import FieldExistsWarning
 from logprep.processor.datetime_extractor.processor import DatetimeExtractor
 from tests.unit.processor.base import BaseProcessorTestCase
 
@@ -14,18 +13,9 @@ from tests.unit.processor.base import BaseProcessorTestCase
 class TestDatetimeExtractor(BaseProcessorTestCase):
     CONFIG = {
         "type": "datetime_extractor",
-        "specific_rules": ["tests/testdata/unit/datetime_extractor/rules/specific"],
-        "generic_rules": ["tests/testdata/unit/datetime_extractor/rules/generic"],
+        "rules": ["tests/testdata/unit/datetime_extractor/rules"],
     }
 
-    @property
-    def specific_rules_dirs(self):
-        return self.CONFIG.get("specific_rules")
-
-    @property
-    def generic_rules_dirs(self):
-        return self.CONFIG.get("generic_rules")
-
     def test_an_event_extracted_datetime_utc(self):
         timestamp = "2019-07-30T14:37:42.861Z"
         document = {"@timestamp": timestamp, "winlog": {"event_id": 123}}
@@ -114,7 +104,7 @@ class TestDatetimeExtractor(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         self.object._local_timezone = tzutc()
         self.object._local_timezone_name = DatetimeExtractor._get_timezone_name(
             self.object._local_timezone
@@ -147,7 +137,7 @@ class TestDatetimeExtractor(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         self.object._local_timezone = tzutc()
         self.object._local_timezone_name = DatetimeExtractor._get_timezone_name(
             self.object._local_timezone
@@ -169,7 +159,7 @@ class TestDatetimeExtractor(BaseProcessorTestCase):
         }
         assert document == expected
 
-    def test_existing_target_raises_if_not_overwrite_target(self, caplog):
+    def test_existing_target_raises_if_not_overwrite_target(self):
         document = {"@timestamp": "2019-07-30T14:37:42.861+00:00", "winlog": {"event_id": 123}}
         rule = {
             "filter": "@timestamp",
@@ -180,10 +170,10 @@ class TestDatetimeExtractor(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule)
-        with caplog.at_level(logging.WARNING):
-            self.object.process(document)
-        assert re.match(".*FieldExistsWarning.*", caplog.text)
+        self._load_rule(rule)
+        result = self.object.process(document)
+        assert len(result.warnings) == 1
+        assert isinstance(result.warnings[0], FieldExistsWarning)
 
     @staticmethod
     def _parse_local_tz(tz_local_name):
