@@ -1,9 +1,8 @@
 # pylint: disable=missing-docstring
-import logging
-import re
 
 import pytest
 
+from logprep.processor.base.exceptions import ProcessingWarning
 from tests.unit.processor.base import BaseProcessorTestCase
 
 test_cases = [  # testcase, rule, event, expected
@@ -718,20 +717,19 @@ failure_test_cases = [  # testcase, rule, event, expected
 class TestDissector(BaseProcessorTestCase):
     CONFIG: dict = {
         "type": "dissector",
-        "generic_rules": ["tests/testdata/unit/dissector/generic_rules"],
-        "specific_rules": ["tests/testdata/unit/dissector/specific_rules"],
+        "rules": ["tests/testdata/unit/dissector/rules"],
     }
 
     @pytest.mark.parametrize("testcase, rule, event, expected", test_cases)
     def test_testcases(self, testcase, rule, event, expected):  # pylint: disable=unused-argument
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         self.object.process(event)
         assert event == expected
 
     @pytest.mark.parametrize("testcase, rule, event, expected", failure_test_cases)
-    def test_testcases_failure_handling(self, caplog, testcase, rule, event, expected):
-        self._load_specific_rule(rule)
-        with caplog.at_level(logging.WARNING):
-            self.object.process(event)
-        assert re.match(".*ProcessingWarning.*", caplog.text)
+    def test_testcases_failure_handling(self, testcase, rule, event, expected):
+        self._load_rule(rule)
+        result = self.object.process(event)
+        assert len(result.warnings) == 1
+        assert isinstance(result.warnings[0], ProcessingWarning)
         assert event == expected, testcase
