@@ -1,37 +1,19 @@
 # pylint: disable=protected-access
 # pylint: disable=missing-docstring
 
-import hashlib
-import logging
-import os
-import re
-import shutil
-import tempfile
-from pathlib import Path
-
-import responses
 
 from logprep.factory import Factory
-from logprep.processor.base.exceptions import ProcessingWarning
+from logprep.processor.base.exceptions import FieldExistsWarning
 from tests.unit.processor.base import BaseProcessorTestCase
 
 
 class TestDomainLabelExtractor(BaseProcessorTestCase):
     CONFIG = {
         "type": "domain_label_extractor",
-        "generic_rules": ["tests/testdata/unit/domain_label_extractor/rules/generic"],
-        "specific_rules": ["tests/testdata/unit/domain_label_extractor/rules/specific"],
+        "rules": ["tests/testdata/unit/domain_label_extractor/rules"],
         "tree_config": "tests/testdata/unit/shared_data/tree_config.json",
     }
 
-    @property
-    def generic_rules_dirs(self):
-        return self.CONFIG.get("generic_rules")
-
-    @property
-    def specific_rules_dirs(self):
-        return self.CONFIG.get("specific_rules")
-
     def test_domain_extraction_from_full_url(self):
         document = {"url": {"domain": "https://url.full.domain.de/path/file?param=1"}}
         expected_output = {
@@ -175,14 +157,13 @@ class TestDomainLabelExtractor(BaseProcessorTestCase):
         config = {
             "Test DomainLabelExtractor Name": {
                 "type": "domain_label_extractor",
-                "generic_rules": ["tests/testdata/unit/domain_label_extractor/rules/generic"],
-                "specific_rules": ["tests/testdata/unit/domain_label_extractor/rules/specific"],
+                "rules": ["tests/testdata/unit/domain_label_extractor/rules"],
                 "tagging_field_name": "special_tags",
                 "tree_config": "tests/testdata/unit/shared_data/tree_config.json",
             }
         }
 
-        domain_label_extractor = Factory.create(configuration=config, logger=self.logger)
+        domain_label_extractor = Factory.create(configuration=config)
         document = {"url": {"domain": "domain.fubarbo"}}
         expected_output = {
             "url": {"domain": "domain.fubarbo"},
@@ -196,14 +177,13 @@ class TestDomainLabelExtractor(BaseProcessorTestCase):
         config = {
             "Test DomainLabelExtractor Name": {
                 "type": "domain_label_extractor",
-                "generic_rules": ["tests/testdata/unit/domain_label_extractor/rules/generic"],
-                "specific_rules": ["tests/testdata/unit/domain_label_extractor/rules/specific"],
+                "rules": ["tests/testdata/unit/domain_label_extractor/rules"],
                 "tagging_field_name": "special_tags",
                 "tree_config": "tests/testdata/unit/shared_data/tree_config.json",
             }
         }
 
-        domain_label_extractor = Factory.create(config, self.logger)
+        domain_label_extractor = Factory.create(config)
         document = {"url": {"domain": "domain.fubarbo"}, "special_tags": ["source"]}
         expected_output = {
             "url": {"domain": "domain.fubarbo"},
@@ -244,12 +224,11 @@ class TestDomainLabelExtractor(BaseProcessorTestCase):
         self.object.process(document)
         assert document == expected_output
 
-    def test_domain_extraction_with_existing_output_field(self, caplog):
+    def test_domain_extraction_with_existing_output_field(self):
         document = {"url": {"domain": "test.domain.de", "subdomain": "exists already"}}
-
-        with caplog.at_level(logging.WARNING):
-            self.object.process(document)
-        assert re.match(".*FieldExistsWarning.*", caplog.text)
+        result = self.object.process(document)
+        assert len(result.warnings) == 1
+        assert isinstance(result.warnings[0], FieldExistsWarning)
 
     def test_domain_extraction_overwrites_target_field(self):
         document = {"url": {"domain": "test.domain.de", "subdomain": "exists already"}}
@@ -270,7 +249,7 @@ class TestDomainLabelExtractor(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.process(document)
         assert document == expected
 
@@ -293,13 +272,16 @@ class TestDomainLabelExtractor(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.process(document)
         assert document == expected
 
     def test_does_nothing_if_source_field_not_exits(self):
         document = {"url": {"domain": "test.domain.de", "subdomain": "exists already"}}
-        expected = {"url": {"domain": "test.domain.de", "subdomain": "exists already"}}
+        expected = {
+            "url": {"domain": "test.domain.de", "subdomain": "exists already"},
+            "tags": ["_domain_label_extractor_missing_field_warning"],
+        }
         rule_dict = {
             "filter": "url",
             "domain_label_extractor": {
@@ -310,11 +292,11 @@ class TestDomainLabelExtractor(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.process(document)
         assert document == expected
 
-    def test_raises_duplication_error_if_target_field_exits(self, caplog):
+    def test_raises_field_exists_warning_if_target_field_exits(self):
         document = {"url": {"domain": "test.domain.de", "subdomain": "exists already"}}
         expected = {
             "tags": ["_domain_label_extractor_failure"],
@@ -334,45 +316,8 @@ class TestDomainLabelExtractor(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
-        with caplog.at_level(logging.WARNING):
-            self.object.process(document)
-        assert re.match(".*FieldExistsWarning.*", caplog.text)
+        self._load_rule(rule_dict)
+        result = self.object.process(document)
+        assert len(result.warnings) == 1
+        assert isinstance(result.warnings[0], FieldExistsWarning)
         assert document == expected
-
-    @responses.activate
-    def test_setup_downloads_tld_lists_to_separate_process_file(self):
-        tld_list = "http://db-path-target/list.dat"
-        tld_list_path = Path("/usr/bin/ls") if Path("/usr/bin/ls").exists() else Path("/bin/ls")
-        tld_list_content = tld_list_path.read_bytes()
-        expected_checksum = hashlib.md5(tld_list_content).hexdigest()  # nosemgrep
-        responses.add(responses.GET, tld_list, tld_list_content)
-        self.object._config.tld_lists = [tld_list]
-        self.object.setup()
-        logprep_tmp_dir = Path(tempfile.gettempdir()) / "logprep"
-        downloaded_file = logprep_tmp_dir / f"{self.object.name}-tldlist-0.dat"
-        assert downloaded_file.exists()
-        downloaded_checksum = hashlib.md5(downloaded_file.read_bytes()).hexdigest()  # nosemgrep
-        assert expected_checksum == downloaded_checksum
-        # delete testfile
-        shutil.rmtree(logprep_tmp_dir)
-
-    @responses.activate
-    def test_setup_doesnt_overwrite_already_existing_tld_list_file(self):
-        tld_list = "http://db-path-target/list.dat"
-        tld_list_content = "some content"
-        responses.add(responses.GET, tld_list, tld_list_content.encode("utf8"))
-
-        logprep_tmp_dir = Path(tempfile.gettempdir()) / "logprep"
-        os.makedirs(logprep_tmp_dir, exist_ok=True)
-        tld_temp_file = logprep_tmp_dir / f"{self.object.name}-tldlist-0.dat"
-
-        pre_existing_content = "file exists already"
-        tld_temp_file.touch()
-        tld_temp_file.write_bytes(pre_existing_content.encode("utf8"))
-        self.object._config.tld_lists = [tld_list]
-        self.object.setup()
-        assert tld_temp_file.exists()
-        assert tld_temp_file.read_bytes().decode("utf8") == pre_existing_content
-        assert tld_temp_file.read_bytes().decode("utf8") != tld_list_content
-        shutil.rmtree(logprep_tmp_dir)  # delete testfile
