@@ -4,6 +4,7 @@ import re
 
 import pytest
 
+from logprep.processor.base.exceptions import FieldExistsWarning
 from tests.unit.processor.base import BaseProcessorTestCase
 
 test_cases = [  # testcase, rule, event, expected
@@ -66,13 +67,11 @@ test_cases = [  # testcase, rule, event, expected
             "field_manager": {
                 "source_fields": ["message"],
                 "target_field": "new_field",
-                "extend_target_list": True,
+                "merge_with_target": True,
                 "delete_source_fields": True,
             },
         },
-        {
-            "message": "This is a message",
-        },
+        {"message": "This is a message"},
         {"new_field": ["This is a message"]},
     ),
     (
@@ -82,7 +81,7 @@ test_cases = [  # testcase, rule, event, expected
             "field_manager": {
                 "source_fields": ["field1", "field2", "field3"],
                 "target_field": "new_field",
-                "extend_target_list": True,
+                "merge_with_target": True,
                 "delete_source_fields": True,
             },
         },
@@ -100,7 +99,7 @@ test_cases = [  # testcase, rule, event, expected
             "field_manager": {
                 "source_fields": ["field1", "field2", "field3"],
                 "target_field": "new_field",
-                "extend_target_list": True,
+                "merge_with_target": True,
                 "delete_source_fields": True,
                 "overwrite_target": True,
             },
@@ -113,6 +112,25 @@ test_cases = [  # testcase, rule, event, expected
         },
         {"new_field": ["value1", "value2", "value3"]},
     ),
+    (
+        "moves multiple fields and replaces existing target field with list including the existing value",
+        {
+            "filter": "field1 OR field2 OR field3",
+            "field_manager": {
+                "source_fields": ["field1", "field2", "field3"],
+                "target_field": "new_field",
+                "merge_with_target": True,
+                "delete_source_fields": True,
+            },
+        },
+        {
+            "field1": "value1",
+            "field2": "value2",
+            "field3": "value3",
+            "new_field": "i exist",
+        },
+        {"new_field": ["i exist", "value1", "value2", "value3"]},
+    ),
     (
         "moves multiple fields and writes them to a existing list",
         {
@@ -120,7 +138,7 @@ test_cases = [  # testcase, rule, event, expected
             "field_manager": {
                 "source_fields": ["field1", "field2", "field3"],
                 "target_field": "new_field",
-                "extend_target_list": True,
+                "merge_with_target": True,
                 "delete_source_fields": True,
             },
         },
@@ -139,7 +157,7 @@ test_cases = [  # testcase, rule, event, expected
             "field_manager": {
                 "source_fields": ["field1", "field2", "field3"],
                 "target_field": "new_field",
-                "extend_target_list": True,
+                "merge_with_target": True,
                 "delete_source_fields": True,
             },
         },
@@ -158,7 +176,7 @@ test_cases = [  # testcase, rule, event, expected
             "field_manager": {
                 "source_fields": ["field1", "field2", "field3"],
                 "target_field": "new_field",
-                "extend_target_list": True,
+                "merge_with_target": True,
                 "delete_source_fields": True,
             },
         },
@@ -177,7 +195,7 @@ test_cases = [  # testcase, rule, event, expected
             "field_manager": {
                 "source_fields": ["field1", "field2", "field3"],
                 "target_field": "new_field",
-                "extend_target_list": True,
+                "merge_with_target": True,
                 "delete_source_fields": True,
             },
         },
@@ -199,7 +217,7 @@ test_cases = [  # testcase, rule, event, expected
             "field_manager": {
                 "source_fields": ["field1", "field2", "field3"],
                 "target_field": "new_field",
-                "extend_target_list": True,
+                "merge_with_target": True,
                 "delete_source_fields": True,
             },
         },
@@ -209,7 +227,7 @@ test_cases = [  # testcase, rule, event, expected
             "field3": ["value5", "value6", "value4"],
             "new_field": ["i exist"],
         },
-        {"new_field": ["i exist", "value1", "value2", "value3", "value4", "value5", "value6"]},
+        {"new_field": ["i exist", "value1", "value2", "value3", "value5", "value4", "value6"]},
     ),
     (
         (
@@ -221,7 +239,7 @@ test_cases = [  # testcase, rule, event, expected
             "field_manager": {
                 "source_fields": ["field1", "field2", "field3"],
                 "target_field": "new_field",
-                "extend_target_list": True,
+                "merge_with_target": True,
                 "delete_source_fields": True,
                 "overwrite_target": True,
             },
@@ -232,7 +250,7 @@ test_cases = [  # testcase, rule, event, expected
             "field3": ["value5", "value6", "value4"],
             "new_field": ["i exist"],
         },
-        {"new_field": ["value1", "value2", "value3", "value4", "value5", "value6"]},
+        {"new_field": ["value1", "value2", "value3", "value5", "value4", "value6"]},
     ),
     (
         "real world example from documentation",
@@ -250,7 +268,7 @@ test_cases = [  # testcase, rule, event, expected
                     "client.nat.ip",
                 ],
                 "target_field": "related.ip",
-                "extend_target_list": True,
+                "merge_with_target": True,
             },
         },
         {
@@ -270,14 +288,14 @@ test_cases = [  # testcase, rule, event, expected
             "source": {"ip": "10.10.2.33"},
             "related": {
                 "ip": [
-                    "10.10.2.33",
                     "127.0.0.1",
-                    "180.22.66.1",
-                    "180.22.66.3",
-                    "192.168.5.1",
-                    "223.2.3.2",
-                    "8.8.8.8",
                     "fe89::",
+                    "192.168.5.1",
+                    "8.8.8.8",
+                    "180.22.66.3",
+                    "10.10.2.33",
+                    "180.22.66.1",
+                    "223.2.3.2",
                 ]
             },
         },
@@ -311,7 +329,7 @@ test_cases = [  # testcase, rule, event, expected
             "filter": "field",
             "field_manager": {
                 "mapping": {"field.one": "one", "field.two": "two", "field.three": "three"},
-                "extend_target_list": True,
+                "merge_with_target": True,
             },
         },
         {"field": {"one": 1, "two": 2, "three": 3}, "three": ["exists already"]},
@@ -327,8 +345,12 @@ test_cases = [  # testcase, rule, event, expected
         {
             "filter": "field",
             "field_manager": {
-                "mapping": {"field.one": "one", "field.two": "two", "field.three": "three"},
-                "extend_target_list": True,
+                "mapping": {
+                    "field.one": "one",
+                    "field.two": "two",
+                    "field.three": "three",
+                },
+                "merge_with_target": True,
             },
         },
         {"field": {"one": 1, "two": 2, "three": [3, 3]}, "three": ["exists already"]},
@@ -389,7 +411,7 @@ test_cases = [  # testcase, rule, event, expected
                 "source_fields": ["source.one", "source.two"],
                 "target_field": "merged",
                 "mapping": {"field.one": "one", "field.two": "two", "field.three": "three"},
-                "extend_target_list": True,
+                "merge_with_target": True,
             },
         },
         {"field": {"one": 1, "two": 2, "three": 3}, "source": {"one": ["a"], "two": ["b"]}},
@@ -420,6 +442,97 @@ test_cases = [  # testcase, rule, event, expected
             "target_field": "first",
         },
     ),
+    (
+        "merge_with_target preserves list ordering",
+        {
+            "filter": "(foo) OR (test)",
+            "field_manager": {
+                "id": "5cfa7a26-94af-49de-bc82-460c42e9dc56",
+                "source_fields": ["foo", "test"],
+                "target_field": "existing_list",
+                "delete_source_fields": False,
+                "overwrite_target": False,
+                "merge_with_target": True,
+            },
+        },
+        {"existing_list": ["hello", "world"], "foo": "bar", "test": "value"},
+        {"existing_list": ["hello", "world", "bar", "value"], "foo": "bar", "test": "value"},
+    ),
+    (
+        "Convert existing target to list",
+        {
+            "filter": "message",
+            "field_manager": {
+                "source_fields": ["message"],
+                "target_field": "new_field",
+                "merge_with_target": True,
+            },
+        },
+        {"message": "Value B", "new_field": "Value A"},
+        {"message": "Value B", "new_field": ["Value A", "Value B"]},
+    ),
+    (
+        "Convert existing target to list with multiple source fields",
+        {
+            "filter": "field1 OR field2 OR field3",
+            "field_manager": {
+                "source_fields": ["field1", "field2", "field3"],
+                "target_field": "new_field",
+                "merge_with_target": True,
+            },
+        },
+        {
+            "field1": "Value B",
+            "field2": "Value C",
+            "field3": "Value D",
+            "new_field": "Value A",
+        },
+        {
+            "field1": "Value B",
+            "field2": "Value C",
+            "field3": "Value D",
+            "new_field": ["Value A", "Value B", "Value C", "Value D"],
+        },
+    ),
+    (
+        "Merge source dict into existing target dict",
+        {
+            "filter": "source",
+            "field_manager": {
+                "source_fields": ["source"],
+                "target_field": "target",
+                "merge_with_target": True,
+            },
+        },
+        {"source": {"source1": "value"}, "target": {"target1": "value"}},
+        {"source": {"source1": "value"}, "target": {"source1": "value", "target1": "value"}},
+    ),
+    (
+        "Merge multiple source dicts into existing target dict",
+        {
+            "filter": "source1",
+            "field_manager": {
+                "source_fields": ["source1", "source2", "source3"],
+                "target_field": "target",
+                "delete_source_fields": True,
+                "merge_with_target": True,
+            },
+        },
+        {
+            "source1": {"source1": "value"},
+            "source2": {"source2": "value"},
+            "source3": {"source-nested": {"foo": "bar"}},
+            "target": {"target1": "value"},
+        },
+        {
+            "target": {
+                "source1": "value",
+                "source2": "value",
+                "source-nested": {"foo": "bar"},
+                "target1": "value",
+            },
+        },
+    ),
 ]
 
 failure_test_cases = [
@@ -507,26 +620,25 @@ failure_test_cases = [
 class TestFieldManager(BaseProcessorTestCase):
     CONFIG: dict = {
         "type": "field_manager",
-        "specific_rules": ["tests/testdata/unit/field_manager/specific_rules"],
-        "generic_rules": ["tests/testdata/unit/field_manager/generic_rules"],
+        "rules": ["tests/testdata/unit/field_manager/rules"],
     }
 
     @pytest.mark.parametrize("testcase, rule, event, expected", test_cases)
     def test_testcases(self, testcase, rule, event, expected):  # pylint: disable=unused-argument
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         self.object.process(event)
         assert event == expected
 
     @pytest.mark.parametrize("testcase, rule, event, expected, error", failure_test_cases)
-    def test_testcases_failure_handling(self, testcase, rule, event, expected, error, caplog):
-        self._load_specific_rule(rule)
-        with caplog.at_level(logging.WARNING):
-            self.object.process(event)
-        assert re.match(error, caplog.text)
+    def test_testcases_failure_handling(self, testcase, rule, event, expected, error):
+        self._load_rule(rule)
+        result = self.object.process(event)
+        assert len(result.warnings) == 1
+        assert re.match(error, str(result.warnings[0]))
         assert event == expected, testcase
 
-    def test_process_raises_duplication_error_if_target_field_exists_and_should_not_be_overwritten(
-        self, caplog
+    def test_process_raises_field_exists_warning_if_target_field_exists_and_should_not_be_overwritten(
+        self,
     ):
         rule = {
             "filter": "field.a",
@@ -537,16 +649,15 @@ class TestFieldManager(BaseProcessorTestCase):
                 "delete_source_fields": False,
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         document = {"field": {"a": "first", "b": "second"}, "target_field": "has already content"}
-        with caplog.at_level(logging.WARNING):
-            self.object.process(document)
-        assert re.match(".*FieldExistsWarning.*", caplog.text)
+        result = self.object.process(document)
+        assert isinstance(result.warnings[0], FieldExistsWarning)
         assert "target_field" in document
         assert document.get("target_field") == "has already content"
         assert document.get("tags") == ["_field_manager_failure"]
 
-    def test_process_raises_processing_warning_with_missing_fields(self, caplog):
+    def test_process_raises_processing_warning_with_missing_fields(self):
         rule = {
             "filter": "field.a",
             "field_manager": {
@@ -554,17 +665,16 @@ class TestFieldManager(BaseProcessorTestCase):
                 "target_field": "target_field",
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         document = {"field": {"a": "first", "b": "second"}}
-        with caplog.at_level(logging.WARNING):
-            self.object.process(document)
+        result = self.object.process(document)
+        assert len(result.warnings) == 1
         assert re.match(
-            r".*ProcessingWarning.*missing source_fields: \['does.not.exists'\]", caplog.text
+            r".*ProcessingWarning.*missing source_fields: \['does.not.exists'\]",
+            str(result.warnings[0]),
         )
 
-    def test_process_raises_processing_warning_with_missing_fields_but_event_is_processed(
-        self, caplog
-    ):
+    def test_process_raises_processing_warning_with_missing_fields_but_event_is_processed(self):
         rule = {
             "filter": "field.a",
             "field_manager": {
@@ -574,17 +684,18 @@ class TestFieldManager(BaseProcessorTestCase):
                 }
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         document = {"field": {"a": "first", "b": "second"}}
         expected = {
             "field": {"a": "first", "b": "second"},
             "target_field": "first",
             "tags": ["_field_manager_missing_field_warning"],
         }
-        with caplog.at_level(logging.WARNING):
-            self.object.process(document)
+        result = self.object.process(document)
+        assert len(result.warnings) == 1
         assert re.match(
-            r".*ProcessingWarning.*missing source_fields: \['does.not.exists'\]", caplog.text
+            r".*ProcessingWarning.*missing source_fields: \['does.not.exists'\]",
+            str(result.warnings[0]),
         )
         assert document == expected
 
@@ -601,7 +712,7 @@ class TestFieldManager(BaseProcessorTestCase):
                 "ignore_missing_fields": True,
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         document = {"field": {"a": "first", "b": "second"}}
         expected = {
             "field": {"a": "first", "b": "second"},
