@@ -2,13 +2,11 @@
 # pylint: disable=protected-access
 # pylint: disable=missing-docstring
 # pylint: disable=wrong-import-position
-import logging
-import re
 from collections import OrderedDict
+from copy import deepcopy
 
-import pytest
-
-from logprep.processor.base.exceptions import ProcessingCriticalError
+from logprep.factory import Factory
+from logprep.processor.base.exceptions import FieldExistsWarning
 from logprep.processor.generic_resolver.processor import GenericResolver
 from tests.unit.processor.base import BaseProcessorTestCase
 
@@ -16,24 +14,20 @@ from tests.unit.processor.base import BaseProcessorTestCase
 class TestGenericResolver(BaseProcessorTestCase):
     CONFIG = {
         "type": "generic_resolver",
-        "specific_rules": ["tests/testdata/unit/generic_resolver/rules/specific/"],
-        "generic_rules": ["tests/testdata/unit/generic_resolver/rules/generic/"],
+        "rules": ["tests/testdata/unit/generic_resolver/rules"],
         "tree_config": "tests/testdata/unit/shared_data/tree_config.json",
     }
 
-    @property
-    def specific_rules_dirs(self):
-        """Return the paths of the specific rules"""
-        return self.CONFIG["specific_rules"]
-
-    @property
-    def generic_rules_dirs(self):
-        """Return the paths of the generic rules"""
-        return self.CONFIG["generic_rules"]
+    expected_metrics = [
+        "logprep_generic_resolver_new_results",
+        "logprep_generic_resolver_cached_results",
+        "logprep_generic_resolver_num_cache_entries",
+        "logprep_generic_resolver_cache_load",
+    ]
 
     def test_resolve_generic_instantiates(self):
         rule = {"filter": "anything", "generic_resolver": {"field_mapping": {}}}
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         assert isinstance(self.object, GenericResolver)
 
     def test_resolve_not_dotted_field_no_conflict_match(self):
@@ -45,7 +39,7 @@ class TestGenericResolver(BaseProcessorTestCase):
             },
         }
 
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {"to_resolve": "something HELLO1", "resolved": "Greeting"}
 
@@ -55,6 +49,47 @@ class TestGenericResolver(BaseProcessorTestCase):
 
         assert document == expected
 
+    def test_resolve_with_dict_value(self):
+        rule = {
+            "filter": "to_resolve",
+            "generic_resolver": {
+                "field_mapping": {"to_resolve": "resolved"},
+                "resolve_list": {".*HELLO\\d": {"Greeting": "Hello"}},
+            },
+        }
+
+        self._load_rule(rule)
+
+        expected = {"to_resolve": "something HELLO1", "resolved": {"Greeting": "Hello"}}
+
+        document = {"to_resolve": "something HELLO1"}
+
+        self.object.process(document)
+
+        assert document == expected
+
+    def test_resolve_from_mapping_with_ignore_case(self):
+        rule = {
+            "filter": "to_resolve",
+            "generic_resolver": {
+                "field_mapping": {"to_resolve": "resolved"},
+                "resolve_list": {".*HELLO\\d": "Greeting"},
+                "ignore_case": True,
+            },
+        }
+
+        self._load_rule(rule)
+
+        expected = {"to_resolve": "something HELLO1", "resolved": "Greeting"}
+        document = {"to_resolve": "something HELLO1"}
+        self.object.process(document)
+        assert document == expected
+
+        expected = {"to_resolve": "something hello1", "resolved": "Greeting"}
+        document = {"to_resolve": "something hello1"}
+        self.object.process(document)
+        assert document == expected
+
     def test_resolve_not_dotted_field_no_conflict_and_to_list_entries_match(
         self,
     ):
@@ -66,7 +101,7 @@ class TestGenericResolver(BaseProcessorTestCase):
             },
         }
 
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {"to_resolve": "something HELLO1", "resolved": "Greeting"}
 
@@ -89,7 +124,7 @@ class TestGenericResolver(BaseProcessorTestCase):
             },
         }
 
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {"to_resolve": "something no"}
         document = {"to_resolve": "something no"}
@@ -106,7 +141,7 @@ class TestGenericResolver(BaseProcessorTestCase):
                 "resolve_list": {".*HELLO\\d": "Greeting"},
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {"to": {"resolve": "something HELLO1"}, "resolved": "Greeting"}
 
@@ -130,7 +165,7 @@ class TestGenericResolver(BaseProcessorTestCase):
                 "resolve_list": {"FOO": "BAR"},
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {"to_resolve": "ab", "resolved": "ab_server_type"}
 
@@ -140,6 +175,33 @@ class TestGenericResolver(BaseProcessorTestCase):
 
         assert document == expected
 
+    def test_resolve_from_file_with_ignore_case(
+        self,
+    ):
+        rule = {
+            "filter": "to_resolve",
+            "generic_resolver": {
+                "field_mapping": {"to_resolve": "resolved"},
+                "resolve_from_file": {
+                    "path": "tests/testdata/unit/generic_resolver/resolve_mapping.yml",
+                    "pattern": r"\d*(?P<mapping>[a-z]+)\d*",
+                },
+                "ignore_case": True,
+                "resolve_list": {"FOO": "BAR"},
+            },
+        }
+        self._load_rule(rule)
+
+        expected = {"to_resolve": "ab", "resolved": "ab_server_type"}
+        document = {"to_resolve": "ab"}
+        self.object.process(document)
+        assert document == expected
+
+        expected = {"to_resolve": "AB", "resolved": "ab_server_type"}
+        document = {"to_resolve": "AB"}
+        self.object.process(document)
+        assert document == expected
+
     def test_resolve_from_file_and_from_list(self):
         rule = {
             "filter": "to_resolve_1 AND to_resolve_2",
@@ -156,7 +218,7 @@ class TestGenericResolver(BaseProcessorTestCase):
             },
         }
 
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {
             "to_resolve_1": "ab",
@@ -185,7 +247,7 @@ class TestGenericResolver(BaseProcessorTestCase):
                 "resolve_list": {"FOO": "BAR"},
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {
             "to_resolve": "not_in_list",
@@ -208,10 +270,10 @@ class TestGenericResolver(BaseProcessorTestCase):
                     "path": "tests/testdata/unit/generic_resolver/resolve_mapping.yml",
                     "pattern": r"\d*(?P<mapping>[a-z]+)\d*",
                 },
-                "append_to_list": True,
+                "merge_with_target": True,
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {"to_resolve": "12ab34", "resolved": ["ab_server_type"]}
 
@@ -232,10 +294,10 @@ class TestGenericResolver(BaseProcessorTestCase):
                     "path": "tests/testdata/unit/generic_resolver/resolve_mapping.yml",
                     "pattern": r"\d*(?P<mapping>[a-z]+)\d*",
                 },
-                "append_to_list": True,
+                "merge_with_target": True,
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {"to_resolve": "12ab34", "resolved": ["ab_server_type"]}
 
@@ -260,10 +322,10 @@ class TestGenericResolver(BaseProcessorTestCase):
                     "path": "tests/testdata/unit/generic_resolver/resolve_mapping.yml",
                     "pattern": r"\d*(?P<mapping>[a-z]+)\d*",
                 },
-                "append_to_list": True,
+                "merge_with_target": True,
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {
             "to_resolve": "12ab34",
@@ -278,48 +340,6 @@ class TestGenericResolver(BaseProcessorTestCase):
 
         assert document == expected
 
-    def test_resolve_dotted_field_no_conflict_match_from_file_group_mapping_does_not_exist(
-        self,
-    ):
-        rule = {
-            "filter": "to_resolve",
-            "generic_resolver": {
-                "field_mapping": {"to_resolve": "resolved"},
-                "resolve_from_file": {
-                    "path": "tests/testdata/unit/generic_resolver/resolve_mapping.yml",
-                    "pattern": r"\d*(?P<foobar>[a-z]+)\d*",
-                },
-                "resolve_list": {"FOO": "BAR"},
-            },
-        }
-        self._load_specific_rule(rule)
-        document = {"to_resolve": "ab"}
-
-        with pytest.raises(
-            ProcessingCriticalError,
-            match=r"GenericResolver \(Test Instance Name\)\: Mapping group is missing in mapping "
-            r"file pattern!",
-        ):
-            self.object.process(document)
-
-    def test_resolve_generic_match_from_file_and_file_does_not_exist(self):
-        rule = {
-            "filter": "to.resolve",
-            "generic_resolver": {
-                "field_mapping": {"to.resolve": "resolved"},
-                "resolve_from_file": {"path": "foo", "pattern": "bar"},
-            },
-        }
-        self._load_specific_rule(rule)
-
-        document = {"to": {"resolve": "something HELLO1"}}
-
-        with pytest.raises(
-            ProcessingCriticalError,
-            match=r"GenericResolver \(Test Instance Name\)\: Additions file \'foo\' not found!",
-        ):
-            self.object.process(document)
-
     def test_resolve_dotted_field_no_conflict_no_match(self):
         rule = {
             "filter": "to.resolve",
@@ -328,7 +348,7 @@ class TestGenericResolver(BaseProcessorTestCase):
                 "resolve_list": {".*HELLO\\d": "Greeting"},
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {"to": {"resolve": "something no"}}
         document = {"to": {"resolve": "something no"}}
@@ -337,6 +357,26 @@ class TestGenericResolver(BaseProcessorTestCase):
 
         assert document == expected
 
+    def test_resolve_dotted_field_is_missing(self):
+        rule = {
+            "filter": "to.other_field",
+            "generic_resolver": {
+                "field_mapping": {"to.resolve": "resolved"},
+                "resolve_list": {".*HELLO\\d": "Greeting"},
+            },
+        }
+        self._load_rule(rule)
+
+        expected = {
+            "to": {"other_field": "something no"},
+            "tags": ["_generic_resolver_missing_field_warning"],
+        }
+        document = {"to": {"other_field": "something no"}}
+
+        self.object.process(document)
+
+        assert document == expected
+
     def test_resolve_dotted_dest_field_no_conflict_match(self):
         rule = {
             "filter": "to_resolve",
@@ -345,7 +385,7 @@ class TestGenericResolver(BaseProcessorTestCase):
                 "resolve_list": {".*HELLO\\d": "Greeting"},
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {"to_resolve": "something HELLO1", "re": {"solved": "Greeting"}}
         document = {"to_resolve": "something HELLO1"}
@@ -362,7 +402,7 @@ class TestGenericResolver(BaseProcessorTestCase):
                 "resolve_list": {".*HELLO\\d": "Greeting"},
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {"to_resolve": "something no"}
         document = {"to_resolve": "something no"}
@@ -381,7 +421,7 @@ class TestGenericResolver(BaseProcessorTestCase):
                 "resolve_list": {".*HELLO\\d": "Greeting"},
             },
         }
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
 
         expected = {"to": {"resolve": "something HELLO1"}, "re": {"solved": "Greeting"}}
         document = {"to": {"resolve": "something HELLO1"}}
@@ -398,8 +438,7 @@ class TestGenericResolver(BaseProcessorTestCase):
                 "resolve_list": {".*HELLO\\d": "Greeting"},
             },
         }
-        self._load_specific_rule(rule)
-
+        self._load_rule(rule)
         document = {
             "to": {"resolve": "something HELLO1"},
             "re": {"solved": "I already exist!"},
@@ -409,10 +448,9 @@ class TestGenericResolver(BaseProcessorTestCase):
             "to": {"resolve": "something HELLO1"},
             "re": {"solved": "I already exist!"},
         }
-        with caplog.at_level(logging.WARNING):
-            self.object.process(document)
-        assert re.match(".*FieldExistsWarning.*", caplog.text)
-
+        result = self.object.process(document)
+        assert len(result.warnings) == 1
+        assert isinstance(result.warnings[0], FieldExistsWarning)
         assert document == expected
 
     def test_resolve_generic_and_multiple_match_first_only(self):
@@ -430,10 +468,176 @@ class TestGenericResolver(BaseProcessorTestCase):
             },
         }
 
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         expected = {"to": {"resolve": "something HELLO1"}, "re": {"solved": "Greeting"}}
         document = {"to": {"resolve": "something HELLO1"}}
 
         self.object.process(document)
 
         assert document == expected
+
+    def test_resolve_from_cache_with_large_enough_cache(self):
+        """The metrics are mocked and their values are the sum of previously added cache values,
+        instead of being the current cache values."""
+        config = deepcopy(self.CONFIG)
+        config["max_cache_entries"] = 10
+        self.object = Factory.create({"generic_resolver": config})
+
+        rule_dict = {
+            "filter": "to_resolve",
+            "generic_resolver": {
+                "field_mapping": {"to_resolve": "resolved"},
+                "resolve_list": {".+ar": "res_bar", ".+oo": "res_foo"},
+            },
+        }
+        event = {"to_resolve": "foo"}
+        self._load_rule(rule_dict)
+        self.object.setup()
+
+        self.object.metrics.new_results = 0
+        self.object.metrics.cached_results = 0
+        self.object.metrics.num_cache_entries = 0
+
+        self.object.process(event)
+
+        assert self.object.metrics.new_results == 1
+        assert self.object.metrics.cached_results == 0
+        assert self.object.metrics.num_cache_entries == 1
+
+        self.object.process(event)
+
+        assert self.object.metrics.new_results == 2
+        assert self.object.metrics.cached_results == 1
+        assert self.object.metrics.num_cache_entries == 2
+
+        self.object.process({"to_resolve": "bar"})
+
+        assert self.object.metrics.new_results == 4
+        assert self.object.metrics.cached_results == 2
+        assert self.object.metrics.num_cache_entries == 4
+
+    def test_resolve_from_cache_with_cache_smaller_than_results(self):
+        """The metrics are mocked and their values are the sum of previously added cache values,
+        instead of being the current cache values."""
+        config = deepcopy(self.CONFIG)
+        config["max_cache_entries"] = 1
+        self.object = Factory.create({"generic_resolver": config})
+
+        rule_dict = {
+            "filter": "to_resolve",
+            "generic_resolver": {
+                "field_mapping": {"to_resolve": "resolved"},
+                "resolve_list": {".+ar": "res_bar", ".+oo": "res_foo"},
+            },
+        }
+        event = {"to_resolve": "foo"}
+        self._load_rule(rule_dict)
+        self.object.setup()
+
+        self.object.metrics.new_results = 0
+        self.object.metrics.cached_results = 0
+        self.object.metrics.num_cache_entries = 0
+
+        self.object.process(event)
+
+        assert self.object.metrics.new_results == 1
+        assert self.object.metrics.cached_results == 0
+        assert self.object.metrics.num_cache_entries == 1
+
+        self.object.process(event)
+
+        assert self.object.metrics.new_results == 2
+        assert self.object.metrics.cached_results == 1
+        assert self.object.metrics.num_cache_entries == 2
+
+        self.object.process({"to_resolve": "bar"})
+
+        assert self.object.metrics.new_results == 4
+        assert self.object.metrics.cached_results == 2
+        assert self.object.metrics.num_cache_entries == 3
+
+    def test_resolve_without_cache(self):
+        config = deepcopy(self.CONFIG)
+        config["max_cache_entries"] = 0
+        self.object = Factory.create({"generic_resolver": config})
+
+        rule_dict = {
+            "filter": "to_resolve",
+            "generic_resolver": {
+                "field_mapping": {"to_resolve": "resolved"},
+                "resolve_list": {".+ar": "res_bar", ".+oo": "res_foo"},
+            },
+        }
+        event = {"to_resolve": "foo"}
+        self._load_rule(rule_dict)
+        self.object.setup()
+
+        self.object.metrics.new_results = 0
+        self.object.metrics.cached_results = 0
+        self.object.metrics.num_cache_entries = 0
+
+        self.object.process(event)
+
+        assert self.object.metrics.new_results == 0
+        assert self.object.metrics.cached_results == 0
+        assert self.object.metrics.num_cache_entries == 0
+
+        self.object.process(event)
+
+        assert self.object.metrics.new_results == 0
+        assert self.object.metrics.cached_results == 0
+        assert self.object.metrics.num_cache_entries == 0
+
+        self.object.process({"to_resolve": "bar"})
+
+        assert self.object.metrics.new_results == 0
+        assert self.object.metrics.cached_results == 0
+        assert self.object.metrics.num_cache_entries == 0
+
+    def test_resolve_from_cache_with_update_interval_2(self):
+        """The metrics are mocked and their values are the sum of previously added cache values,
+        instead of being the current cache values."""
+        config = deepcopy(self.CONFIG)
+        config["cache_metrics_interval"] = 2
+        config["max_cache_entries"] = 10
+        self.object = Factory.create({"generic_resolver": config})
+
+        rule_dict = {
+            "filter": "to_resolve",
+            "generic_resolver": {
+                "field_mapping": {"to_resolve": "resolved"},
+                "resolve_list": {".+ar": "res_bar", ".+oo": "res_foo"},
+            },
+        }
+        event = {"to_resolve": "foo"}
+        other_event = {"to_resolve": "bar"}
+        self._load_rule(rule_dict)
+        self.object.setup()
+
+        self.object.metrics.new_results = 0
+        self.object.metrics.cached_results = 0
+        self.object.metrics.num_cache_entries = 0
+
+        self.object.process(event)
+
+        assert self.object.metrics.new_results == 0
+        assert self.object.metrics.cached_results == 0
+        assert self.object.metrics.num_cache_entries == 0
+
+        self.object.process(event)
+
+        assert self.object.metrics.new_results == 1
+        assert self.object.metrics.cached_results == 1
+        assert self.object.metrics.num_cache_entries == 1
+
+        self.object.process(other_event)
+
+        assert self.object.metrics.new_results == 1
+        assert self.object.metrics.cached_results == 1
+        assert self.object.metrics.num_cache_entries == 1
+
+        self.object.process(other_event)
+
+        assert self.object.metrics.new_results == 3
+        assert self.object.metrics.cached_results == 3
+        assert self.object.metrics.num_cache_entries == 3
