@@ -4,11 +4,12 @@
 # pylint: disable=wrong-import-order
 import pytest
 
+from logprep.factory_error import InvalidConfigurationError
 from logprep.processor.generic_resolver.rule import GenericResolverRule
 
 
-@pytest.fixture(name="specific_rule_definition")
-def fixture_specific_rule_definition():
+@pytest.fixture(name="rule_definition")
+def fixture_rule_definition():
     return {
         "filter": "message",
         "generic_resolver": {
@@ -18,7 +19,7 @@ def fixture_specific_rule_definition():
                 "path": "tests/testdata/unit/generic_resolver/resolve_mapping.yml",
                 "pattern": r"\d*(?P<mapping>[a-z]+)\d*",
             },
-            "append_to_list": False,
+            "merge_with_target": False,
         },
         "description": "insert a description text",
     }
@@ -39,7 +40,7 @@ class TestGenericResolverRule:
                             "path": "tests/testdata/unit/generic_resolver/resolve_mapping.yml",
                             "pattern": r"\d*(?P<mapping>[a-z]+)\d*",
                         },
-                        "append_to_list": False,
+                        "merge_with_target": False,
                     },
                 },
                 True,
@@ -70,7 +71,7 @@ class TestGenericResolverRule:
                             "path": "tests/testdata/unit/generic_resolver/resolve_mapping.yml",
                             "pattern": r"\d*(?P<mapping>[a-z]+)\d*",
                         },
-                        "append_to_list": False,
+                        "merge_with_target": False,
                     },
                 },
                 False,
@@ -86,7 +87,7 @@ class TestGenericResolverRule:
                             "path": "tests/testdata/unit/generic_resolver/resolve_mapping.yml",
                             "pattern": r"\d*(?P<mapping>[a-z]+)\d*",
                         },
-                        "append_to_list": False,
+                        "merge_with_target": False,
                     },
                 },
                 False,
@@ -102,7 +103,7 @@ class TestGenericResolverRule:
                             "path": "tests/testdata/unit/generic_resolver/resolve_mapping.yml",
                             "pattern": r"\d*(?P<mapping>[a-z]+)\d*",
                         },
-                        "append_to_list": False,
+                        "merge_with_target": False,
                     },
                 },
                 False,
@@ -117,7 +118,7 @@ class TestGenericResolverRule:
                             "path": "tests/testdata/unit/generic_resolver/resolve_mapping.yml",
                             "pattern": r"\d*(?P<mapping>[a-z]+)\d*",
                         },
-                        "append_to_list": False,
+                        "merge_with_target": False,
                     },
                 },
                 False,
@@ -133,7 +134,7 @@ class TestGenericResolverRule:
                             "path": "tests/testdata/unit/generic_resolver/resolve_mapping.yml",
                             "pattern": r"other_\d*(?P<mapping>[a-z]+)\d*",
                         },
-                        "append_to_list": False,
+                        "merge_with_target": False,
                     },
                 },
                 False,
@@ -145,16 +146,59 @@ class TestGenericResolverRule:
                     "generic_resolver": {
                         "field_mapping": {"to_resolve": "resolved"},
                         "resolve_list": {"pattern": "result"},
-                        "append_to_list": False,
+                        "merge_with_target": False,
                     },
                 },
                 False,
             ),
         ],
     )
-    def test_rules_equality(
-        self, specific_rule_definition, testcase, other_rule_definition, is_equal
-    ):
-        rule1 = GenericResolverRule._create_from_dict(specific_rule_definition)
-        rule2 = GenericResolverRule._create_from_dict(other_rule_definition)
+    def test_rules_equality(self, rule_definition, testcase, other_rule_definition, is_equal):
+        rule1 = GenericResolverRule.create_from_dict(rule_definition)
+        rule2 = GenericResolverRule.create_from_dict(other_rule_definition)
         assert (rule1 == rule2) == is_equal, testcase
+
+    @pytest.mark.parametrize(
+        ["rule", "error", "message"],
+        [
+            (
+                {
+                    "filter": "to_resolve",
+                    "generic_resolver": {
+                        "field_mapping": {"to_resolve": "resolved"},
+                        "resolve_from_file": {
+                            "path": "tests/testdata/unit/generic_resolver/resolve_mapping.yml",
+                            "pattern": r"\d*(?P<foobar>[a-z]+)\d*",
+                        },
+                        "resolve_list": {"FOO": "BAR"},
+                    },
+                },
+                InvalidConfigurationError,
+                "Mapping group is missing in mapping",
+            ),
+            (
+                {
+                    "filter": "to.resolve",
+                    "generic_resolver": {
+                        "field_mapping": {"to.resolve": "resolved"},
+                        "resolve_from_file": {
+                            "path": "foo",
+                            "pattern": r"\d*(?P<mapping>[a-z]+)\d*",
+                        },
+                    },
+                },
+                InvalidConfigurationError,
+                "Additions file 'foo' not found",
+            ),
+        ],
+    )
+    def test_create_from_dict_validates_config(self, rule, error, message):
+        if error:
+            with pytest.raises(error, match=message):
+                GenericResolverRule.create_from_dict(rule)
+        else:
+            rule_instance = GenericResolverRule.create_from_dict(rule)
+            assert hasattr(rule_instance, "_config")
+            for key, value in rule.get("generic_resolver").items():
+                assert hasattr(rule_instance._config, key)
+                assert value == getattr(rule_instance._config, key)
