@@ -2,8 +2,8 @@
 # pylint: disable=no-member
 # pylint: disable=protected-access
 # pylint: disable=too-many-statements
+import copy
 import hashlib
-import logging
 import os
 import re
 import shutil
@@ -15,7 +15,7 @@ import pytest
 import responses
 from geoip2.errors import AddressNotFoundError
 
-from logprep.processor.base.exceptions import ProcessingWarning
+from logprep.factory import Factory
 from tests.unit.processor.base import BaseProcessorTestCase
 
 
@@ -88,20 +88,11 @@ class TestGeoipEnricher(BaseProcessorTestCase):
 
     CONFIG = {
         "type": "geoip_enricher",
-        "specific_rules": ["tests/testdata/unit/geoip_enricher/rules/specific"],
-        "generic_rules": ["tests/testdata/unit/geoip_enricher/rules/generic"],
+        "rules": ["tests/testdata/unit/geoip_enricher/rules"],
         "db_path": "tests/testdata/mock_external/MockGeoLite2-City.mmdb",
         "tree_config": "tests/testdata/unit/shared_data/tree_config.json",
     }
 
-    @property
-    def generic_rules_dirs(self):
-        return self.CONFIG["generic_rules"]
-
-    @property
-    def specific_rules_dirs(self):
-        return self.CONFIG["specific_rules"]
-
     def test_geoip_data_added(self):
         document = {"client": {"ip": "1.2.3.4"}}
 
@@ -118,19 +109,18 @@ class TestGeoipEnricher(BaseProcessorTestCase):
 
     def test_no_geoip_data_added_if_source_field_is_none(self):
         document = {"client": {"ip": None}}
-
         self.object.process(document)
-
         assert document.get("geoip") is None
 
-    def test_source_field_is_none_raises_processing_warning(self):
+    def test_source_field_is_none_emits_missing_fields_warning(self):
         document = {"client": {"ip": None}}
-
-        with pytest.raises(
-            ProcessingWarning,
-            match=re.escape("Value of IP field 'client.ip' is 'None'"),
-        ):
-            self.object._apply_rules(document, self.object.rules[0])
+        expected = {"client": {"ip": None}, "tags": ["_geoip_enricher_missing_field_warning"]}
+        self.object.process(document)
+        assert document == expected
+        assert len(self.object.result.warnings) == 1
+        assert re.match(
+            r".*missing source_fields: \['client\.ip'].*", str(self.object.result.warnings[0])
+        )
 
     def test_nothing_to_enrich(self):
         document = {"something": {"something": "1.2.3.4"}}
@@ -163,12 +153,11 @@ class TestGeoipEnricher(BaseProcessorTestCase):
         assert geoip["properties"].get("country") == "MyCountry"
         assert geoip["properties"].get("accuracy_radius") == 1337
 
-    def test_enrich_an_event_geoip_with_existing_differing_geoip(self, caplog):
+    def test_enrich_an_event_geoip_with_existing_differing_geoip(self):
         document = {"client": {"ip": "8.8.8.8"}, "geoip": {"type": "Feature"}}
-
-        with caplog.at_level(logging.WARNING):
-            self.object.process(document)
-        assert re.match(".*FieldExistsWarning.*geoip.type", caplog.text)
+        result = self.object.process(document)
+        assert len(result.warnings) == 1
+        assert re.match(".*FieldExistsWarning.*geoip.type", str(result.warnings[0]))
 
     def test_configured_dotted_output_field(self):
         document = {"source": {"ip": "8.8.8.8"}}
@@ -189,7 +178,7 @@ class TestGeoipEnricher(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.process(document)
         assert "client" in document
         assert "ip" not in document.get("client")
@@ -205,7 +194,7 @@ class TestGeoipEnricher(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.process(document)
         assert "client" in document
         assert document.get("client").get("ip").get("type") is not None
@@ -234,7 +223,7 @@ class TestGeoipEnricher(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.process(document)
         expected_event = {
             "client": {
@@ -274,7 +263,7 @@ class TestGeoipEnricher(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.process(document)
         expected_event = {
             "client": {
@@ -314,7 +303,7 @@ class TestGeoipEnricher(BaseProcessorTestCase):
             "description": "",
         }
         with pytest.raises(ValueError, match=r"\'customize_target_subfields\' must be in"):
-            self._load_specific_rule(rule_dict)
+            self._load_rule(rule_dict)
 
     def test_geoip_db_returns_only_limited_data_without_missing_coordinates(self):
         document = {"client": {"ip": "13.21.21.37"}}
@@ -325,7 +314,7 @@ class TestGeoipEnricher(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.process(document)
         expected_event = {
             "client": {"ip": "13.21.21.37"},
@@ -350,7 +339,7 @@ class TestGeoipEnricher(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.process(document)
         expected_event = {
             "client": {"ip": source_ip},
@@ -368,7 +357,9 @@ class TestGeoipEnricher(BaseProcessorTestCase):
         db_path_content = db_path.read_bytes()
         expected_checksum = hashlib.md5(db_path_content).hexdigest()  # nosemgrep
         responses.add(responses.GET, geoip_database_path, db_path_content)
-        self.object._config.db_path = geoip_database_path
+        config = copy.deepcopy(self.CONFIG)
+        config["db_path"] = geoip_database_path
+        self.object = Factory.create({"geoip_enricher": config})
         self.object.setup()
         logprep_tmp_dir = Path(tempfile.gettempdir()) / "logprep"
         downloaded_file = logprep_tmp_dir / f"{self.object.name}.mmdb"
@@ -380,20 +371,22 @@ class TestGeoipEnricher(BaseProcessorTestCase):
 
     @responses.activate
     def test_setup_doesnt_overwrite_already_existing_geomap_file(self):
-        tld_list = "http://db-path-target/db_file.mmdb"
-        tld_list_content = "some content"
-        responses.add(responses.GET, tld_list, tld_list_content.encode("utf8"))
+        mmdb_file_path = "http://db-path-target/db_file.mmdb"
+        new_content = "some content"
+        responses.add(responses.GET, mmdb_file_path, new_content.encode("utf8"))
 
         logprep_tmp_dir = Path(tempfile.gettempdir()) / "logprep"
         os.makedirs(logprep_tmp_dir, exist_ok=True)
-        tld_temp_file = logprep_tmp_dir / f"{self.object.name}.mmdb"
+        temporary_file = logprep_tmp_dir / f"{self.object.name}.mmdb"
 
         pre_existing_content = "file exists already"
-        tld_temp_file.touch()
-        tld_temp_file.write_bytes(pre_existing_content.encode("utf8"))
-        self.object._config.tld_lists = [tld_list]
+        temporary_file.touch()
+        temporary_file.write_bytes(pre_existing_content.encode("utf8"))
+        config = copy.deepcopy(self.CONFIG)
+        config["db_path"] = mmdb_file_path
+        self.object = Factory.create({"geoip_enricher": config})
         self.object.setup()
-        assert tld_temp_file.exists()
-        assert tld_temp_file.read_bytes().decode("utf8") == pre_existing_content
-        assert tld_temp_file.read_bytes().decode("utf8") != tld_list_content
+        assert temporary_file.exists()
+        assert temporary_file.read_bytes().decode("utf8") == pre_existing_content
+        assert temporary_file.read_bytes().decode("utf8") != new_content
         shutil.rmtree(logprep_tmp_dir)  # delete testfile
