@@ -4,13 +4,13 @@
 # pylint: disable=missing-function-docstring
 # pylint: disable=wrong-import-position
 from copy import deepcopy
+
 import pytest
 
 from logprep.filter.expression.filter_expression import StringFilterExpression
 from logprep.processor.base.exceptions import InvalidRuleDefinitionError
 from logprep.processor.labeler.labeling_schema import LabelingSchema
 from logprep.processor.labeler.rule import LabelerRule
-from tests.testdata.FilledTempFile import JsonTempFile
 from tests.testdata.ruledata import simple_rule_dict
 
 
@@ -29,45 +29,32 @@ class MockLabelingSchema(LabelingSchema):
 
 
 class TestRule:
-    def test_create_from_file_fails_if_document_does_not_contain_filter_and_label(self):
-        with pytest.raises(InvalidRuleDefinitionError):
-            with JsonTempFile({}) as rule_path:
-                LabelerRule.create_rules_from_target(rule_path)
-
-        for missing_field in ["filter", "labeler"]:
-            invalid_rule_dict = deepcopy(simple_rule_dict)
-            del invalid_rule_dict[missing_field]
-
-            with pytest.raises(InvalidRuleDefinitionError):
-                with JsonTempFile([invalid_rule_dict]) as rule_path:
-                    LabelerRule.create_rules_from_target(rule_path)
-
     def test_create_from_dict_creates_expected_rule(self):
         rule_definition = {
             "filter": 'applyrule: "yes"',
             "labeler": {"label": {"reporter": ["windows"]}},
         }
-        rule = LabelerRule._create_from_dict(rule_definition)
+        rule = LabelerRule.create_from_dict(rule_definition)
         assert rule._filter == StringFilterExpression(["applyrule"], "yes")
         assert rule._config.label == simple_rule_dict["labeler"]["label"]
 
     def test_create_from_dict_fails_if_document_does_not_contain_filter_and_label(self):
         with pytest.raises(InvalidRuleDefinitionError):
-            LabelerRule._create_from_dict({})
+            LabelerRule.create_from_dict({})
 
         for missing_field in ["filter", "labeler"]:
             invalid_rule_dict = deepcopy(simple_rule_dict)
             del invalid_rule_dict[missing_field]
 
             with pytest.raises(InvalidRuleDefinitionError):
-                LabelerRule._create_from_dict(invalid_rule_dict)
+                LabelerRule.create_from_dict(invalid_rule_dict)
 
     def test_conforms_to_schema_is_false_when_labels_do_not_conform_to_schema(self):
         rule_definition = {
             "filter": 'applyrule: "yes"',
             "labeler": {"label": {"reporter": ["windows"]}},
         }
-        rule = LabelerRule._create_from_dict(rule_definition)
+        rule = LabelerRule.create_from_dict(rule_definition)
         dummy_schema = MockLabelingSchema(False)
 
         assert not rule.conforms_to_schema(dummy_schema)
@@ -77,7 +64,7 @@ class TestRule:
             "filter": 'applyrule: "yes"',
             "labeler": {"label": {"reporter": ["windows"]}},
         }
-        rule = LabelerRule._create_from_dict(rule_definition)
+        rule = LabelerRule.create_from_dict(rule_definition)
         dummy_schema = MockLabelingSchema(True)
 
         assert rule.conforms_to_schema(dummy_schema)
@@ -88,14 +75,14 @@ class TestRule:
             "labeler": {"label": {"reporter": ["windows"]}},
             "description": "this is the description",
         }
-        _ = LabelerRule._create_from_dict(rule_definition)
+        _ = LabelerRule.create_from_dict(rule_definition)
 
     def test_matches_returns_true_for_matching_document(self):
         rule_definition = {
             "filter": 'applyrule: "yes"',
             "labeler": {"label": {"reporter": ["windows"]}},
         }
-        rule = LabelerRule._create_from_dict(rule_definition)
+        rule = LabelerRule.create_from_dict(rule_definition)
         document = {"applyrule": "yes"}
 
         assert rule.matches(document)
@@ -105,24 +92,24 @@ class TestRule:
             "filter": 'applyrule: "yes"',
             "labeler": {"label": {"reporter": ["windows"]}},
         }
-        rule = LabelerRule._create_from_dict(rule_definition)
+        rule = LabelerRule.create_from_dict(rule_definition)
         non_matching_documents = [{}, {"applyrule": "wrong value"}, {"wrong key": "value"}]
         for document in non_matching_documents:
             assert not rule.matches(document)
 
     def test_rules_are_different_if_their_filters_differ(self):
-        rule1 = LabelerRule._create_from_dict(simple_rule_dict)
+        rule1 = LabelerRule.create_from_dict(simple_rule_dict)
         rule2_dict = deepcopy(simple_rule_dict)
         rule2_dict["filter"] = 'applyrule: "no"'
-        rule2 = LabelerRule._create_from_dict(rule2_dict)
+        rule2 = LabelerRule.create_from_dict(rule2_dict)
 
         assert rule1 != rule2
 
     def test_rules_are_different_if_their_assigned_labels_differ(self):
         rule1_dict = {"filter": 'applyrule: "yes"', "labeler": {"label": {"reporter": ["windows"]}}}
-        rule1 = LabelerRule._create_from_dict(rule1_dict)
+        rule1 = LabelerRule.create_from_dict(rule1_dict)
         rule2_dict = {"filter": 'applyrule: "yes"', "labeler": {"label": {"reporter": ["mac"]}}}
-        rule2 = LabelerRule._create_from_dict(rule2_dict)
+        rule2 = LabelerRule.create_from_dict(rule2_dict)
 
         assert rule1 != rule2
 
@@ -131,8 +118,8 @@ class TestRule:
             "filter": 'applyrule: "yes"',
             "labeler": {"label": {"reporter": ["windows"]}},
         }
-        rule1 = LabelerRule._create_from_dict(rule_definition)
-        rule2 = LabelerRule._create_from_dict(rule_definition)
+        rule1 = LabelerRule.create_from_dict(rule_definition)
+        rule2 = LabelerRule.create_from_dict(rule_definition)
 
         assert rule1 == rule2
 
@@ -141,11 +128,11 @@ class TestRule:
     ):
         rule_dict1 = deepcopy(simple_rule_dict)
         rule_dict1["description"] = "This is the first description"
-        rule1 = LabelerRule._create_from_dict(rule_dict1)
+        rule1 = LabelerRule.create_from_dict(rule_dict1)
 
         rule_dict2 = deepcopy(simple_rule_dict)
         rule_dict2["description"] = "This is the second description"
-        rule2 = LabelerRule._create_from_dict(rule_dict2)
+        rule2 = LabelerRule.create_from_dict(rule_dict2)
 
         assert rule1 == rule2
 
@@ -155,7 +142,7 @@ class TestRule:
             "regex_fields": ["applyrule"],
             "labeler": {"label": {"reporter": ["windows"]}},
         }
-        rule = LabelerRule._create_from_dict(rule_definition)
+        rule = LabelerRule.create_from_dict(rule_definition)
         assert rule.matches({"applyrule": "yes"})
         assert rule.matches({"applyrule": "yes!"})
         assert rule.matches({"applyrule": "no? yes!"})
@@ -166,7 +153,7 @@ class TestRule:
             "regex_fields": ["applyrule"],
             "labeler": {"label": {"reporter": ["windows"]}},
         }
-        rule = LabelerRule._create_from_dict(rule_definition)
+        rule = LabelerRule.create_from_dict(rule_definition)
         non_matching_documents = [
             {},
             {"applyrule": "no"},
@@ -184,7 +171,7 @@ class TestRule:
             "regex_fields": ["applyrule"],
             "labeler": {"label": {"reporter": ["windows"]}},
         }
-        rule = LabelerRule._create_from_dict(rule_definition)
+        rule = LabelerRule.create_from_dict(rule_definition)
         assert rule.matches({"applyrule": "UPlo8888"})
         assert rule.matches({"applyrule": "UPlo99999"})
         assert rule.matches({"applyrule": "UPlo$$$$"})
@@ -196,7 +183,7 @@ class TestRule:
             "regex_fields": ["applyrule"],
             "labeler": {"label": {"reporter": ["windows"]}},
         }
-        rule = LabelerRule._create_from_dict(rule_definition)
+        rule = LabelerRule.create_from_dict(rule_definition)
         assert not rule.matches({"applyrule": ""})
         assert not rule.matches({"applyrule": "UPlo777"})
         assert not rule.matches({"applyrule": "UP888888"})
@@ -210,7 +197,71 @@ class TestRule:
             "filter": "applyrule: null",
             "labeler": {"label": {"reporter": ["windows"]}},
         }
-        rule = LabelerRule._create_from_dict(rule_definition)
+        rule = LabelerRule.create_from_dict(rule_definition)
         document = {"applyrule": None}
 
         assert rule.matches(document)
+
+    def test_lucene_regex_matches_returns_true_for_matching_document(self):
+        rule_definition = {
+            "filter": "applyrule: /.*yes.*/",
+            "labeler": {"label": {"reporter": ["windows"]}},
+        }
+        rule = LabelerRule.create_from_dict(rule_definition)
+        assert rule.matches({"applyrule": "yes"})
+        assert rule.matches({"applyrule": "yes!"})
+        assert rule.matches({"applyrule": "no? yes!"})
+
+    def test_lucene_regex_matches_returns_false_for_non_matching_document(self):
+        rule_definition = {
+            "filter": "applyrule: /.*yes.*/",
+            "labeler": {"label": {"reporter": ["windows"]}},
+        }
+        rule = LabelerRule.create_from_dict(rule_definition)
+        non_matching_documents = [
+            {},
+            {"applyrule": "no"},
+            {"applyrule": "ye s"},
+            {"applyrule": "YES"},
+            {"wrong key": "yes"},
+        ]
+
+        for document in non_matching_documents:
+            assert not rule.matches(document)
+
+    def test_complex_lucene_regex_matches_returns_true_for_matching_document(self):
+        rule_definition = {
+            "filter": r"applyrule: /(?:(?=.*[a-z])(?:(?=.*[A-Z])(?=.*[\d\W])|(?=.*\W)(?=.*\d))|(?=.*\W)(?=.*[A-Z])(?=.*\d)).{8,}/",
+            # pylint: disable=line-too-long
+            "labeler": {"label": {"reporter": ["windows"]}},
+        }
+        rule = LabelerRule.create_from_dict(rule_definition)
+        assert rule.matches({"applyrule": "UPlo8888"})
+        assert rule.matches({"applyrule": "UPlo99999"})
+        assert rule.matches({"applyrule": "UPlo$$$$"})
+        assert rule.matches({"applyrule": "UP$$$$88"})
+
+    def test_complex_lucene_regex_does_not_match_returns_true_for_matching_document(self):
+        rule_definition = {
+            "filter": r"applyrule: /(?:(?=.*[a-z])(?:(?=.*[A-Z])(?=.*[\d\W])|(?=.*\W)(?=.*\d))|(?=.*\W)(?=.*[A-Z])(?=.*\d)).{8,}/",
+            # pylint: disable=line-too-long
+            "labeler": {"label": {"reporter": ["windows"]}},
+        }
+        rule = LabelerRule.create_from_dict(rule_definition)
+        assert not rule.matches({"applyrule": ""})
+        assert not rule.matches({"applyrule": "UPlo777"})
+        assert not rule.matches({"applyrule": "UP888888"})
+        assert not rule.matches({"applyrule": "lo888888"})
+        assert not rule.matches({"applyrule": "UPloXXXX"})
+        assert not rule.matches({"applyrule": "88888888"})
+        assert not rule.matches({"applyrule": "UPlo$$7"})
+
+    def test_prefixed_label_property_is_a_dict_with_only_list_values(self):
+        rule_definition = {
+            "filter": 'applyrule: "yes"',
+            "labeler": {"label": {"reporter": {"windows"}}},  # label is given as set
+        }
+        rule = LabelerRule.create_from_dict(rule_definition)
+        assert all(
+            isinstance(val, list) for val in rule.prefixed_label.values()
+        ), "prefixed_labels contain non-list values"
