@@ -1,23 +1,25 @@
 # pylint: disable=missing-docstring
 # pylint: disable=protected-access
-import logging
-import re
 
 import responses
 
 from logprep.factory import Factory
+from logprep.processor.base.exceptions import FieldExistsWarning
 from tests.unit.processor.base import BaseProcessorTestCase
 
 
 class TestListComparison(BaseProcessorTestCase):
     CONFIG = {
         "type": "list_comparison",
-        "specific_rules": ["tests/testdata/unit/list_comparison/rules/specific"],
-        "generic_rules": ["tests/testdata/unit/list_comparison/rules/generic"],
+        "rules": ["tests/testdata/unit/list_comparison/rules"],
         "tree_config": "tests/testdata/unit/shared_data/tree_config.json",
         "list_search_base_path": "tests/testdata/unit/list_comparison/rules",
     }
 
+    def setup_method(self):
+        super().setup_method()
+        self.object.setup()
+
     def test_element_in_list(self):
         document = {"user": "Franz"}
         expected = {"user": "Franz", "user_results": {"in_list": ["user_list.txt"]}}
@@ -102,7 +104,7 @@ class TestListComparison(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.setup()
         self.object.process(document)
 
@@ -125,7 +127,7 @@ class TestListComparison(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.setup()
         self.object.process(document)
 
@@ -135,7 +137,7 @@ class TestListComparison(BaseProcessorTestCase):
             len(document.get("dotted", {}).get("preexistent_output_field", {}).get("in_list")) == 1
         )
 
-    def test_target_field_exists_and_cant_be_extended(self, caplog):
+    def test_target_field_exists_and_cant_be_extended(self):
         document = {"dot_channel": "test", "user": "Franz", "dotted": "dotted_Franz"}
         expected = {
             "dot_channel": "test",
@@ -153,14 +155,14 @@ class TestListComparison(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.setup()
-        with caplog.at_level(logging.WARNING):
-            self.object.process(document)
-        assert re.match(".*FieldExistsWarning.*", caplog.text)
+        result = self.object.process(document)
+        assert len(result.warnings) == 1
+        assert isinstance(result.warnings[0], FieldExistsWarning)
         assert document == expected
 
-    def test_intermediate_output_field_is_wrong_type(self, caplog):
+    def test_intermediate_output_field_is_wrong_type(self):
         document = {
             "dot_channel": "test",
             "user": "Franz",
@@ -182,11 +184,11 @@ class TestListComparison(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.setup()
-        with caplog.at_level(logging.WARNING):
-            self.object.process(document)
-        assert re.match(".*FieldExistsWarning.*", caplog.text)
+        result = self.object.process(document)
+        assert len(result.warnings) == 1
+        assert isinstance(result.warnings[0], FieldExistsWarning)
         assert document == expected
 
     def test_check_in_dotted_subfield(self):
@@ -220,12 +222,12 @@ class TestListComparison(BaseProcessorTestCase):
             "description": "",
         }
         expected = {"user_results": {"in_list": ["user_list.txt"]}}
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.setup()
         self.object.process(document)
         assert document == expected
 
-    def test_overwrite_target_field(self, caplog):
+    def test_overwrite_target_field(self):
         document = {"user": "Franz"}
         expected = {"user": "Franz", "tags": ["_list_comparison_failure"]}
         rule_dict = {
@@ -238,11 +240,11 @@ class TestListComparison(BaseProcessorTestCase):
             },
             "description": "",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         self.object.setup()
-        with caplog.at_level(logging.WARNING):
-            self.object.process(document)
-        assert re.match(".*FieldExistsWarning.*", caplog.text)
+        result = self.object.process(document)
+        assert len(result.warnings) == 1
+        assert isinstance(result.warnings[0], FieldExistsWarning)
         assert document == expected
 
     @responses.activate
@@ -266,14 +268,11 @@ Hans
         }
         config = {
             "type": "list_comparison",
-            "specific_rules": [],
-            "generic_rules": [],
+            "rules": [],
             "list_search_base_path": "http://localhost/tests/testdata/${LOGPREP_LIST}?ref=bla",
         }
-        processor = Factory.create({"custom_lister": config}, self.logger)
-        rule = processor.rule_class._create_from_dict(rule_dict)
-        processor._specific_tree.add_rule(rule)
+        processor = Factory.create({"custom_lister": config})
+        rule = processor.rule_class.create_from_dict(rule_dict)
+        processor._rule_tree.add_rule(rule)
         processor.setup()
-        assert processor._specific_rules[0].compare_sets == {
-            "bad_users.list": {"Franz", "Heinz", "Hans"}
-        }
+        assert processor.rules[0].compare_sets == {"bad_users.list": {"Franz", "Heinz", "Hans"}}
