@@ -5,24 +5,24 @@
 # pylint: disable=line-too-long
 import re
 from copy import deepcopy
-from pathlib import Path
 
 import pytest
 
+from logprep.abc.processor import ProcessorResult
 from logprep.factory import Factory
+from logprep.factory_error import InvalidConfigurationError
+from logprep.util.pseudo.encrypter import (
+    DualPKCS1HybridCTREncrypter,
+    DualPKCS1HybridGCMEncrypter,
+)
 from tests.unit.processor.base import BaseProcessorTestCase
 
-REL_TLD_LIST_PATH = "tests/testdata/mock_external/tld_list.dat"
-
-TLD_LIST = f"file://{Path().absolute().joinpath(REL_TLD_LIST_PATH).as_posix()}"
-
-
 test_cases = [  # testcase, rule, event, expected, regex_mapping
     (
         "simple pseudonymization",
         {
             "filter": "event_id: 1234",
-            "pseudonymizer": {"pseudonyms": {"something": "RE_WHOLE_FIELD"}},
+            "pseudonymizer": {"mapping": {"something": "RE_WHOLE_FIELD"}},
             "description": "description content irrelevant for these tests",
         },
         {"event_id": 1234, "something": "something"},
@@ -36,7 +36,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         "pseudonymization_of_field_does_not_happen_if_already_pseudonymized",
         {
             "filter": "event_id: 1234",
-            "pseudonymizer": {"pseudonyms": {"something": "RE_WHOLE_FIELD"}},
+            "pseudonymizer": {"mapping": {"something": "RE_WHOLE_FIELD"}},
             "description": "description content irrelevant for these tests",
         },
         {
@@ -54,7 +54,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "winlog.event_id: 1234 AND winlog.provider_name: Test456",
             "pseudonymizer": {
-                "pseudonyms": {
+                "mapping": {
                     "winlog.event_data.param1": "RE_WHOLE_FIELD",
                     "winlog.event_data.param2": "RE_WHOLE_FIELD",
                 }
@@ -87,7 +87,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": 'winlog.event_id: 789 AND winlog.provider_name: "Test123"',
             "pseudonymizer": {
-                "pseudonyms": {"winlog.event_data.param1": "RE_DOMAIN_BACKSLASH_USERNAME"}
+                "mapping": {"winlog.event_data.param1": "RE_DOMAIN_BACKSLASH_USERNAME"}
             },
         },
         {
@@ -112,7 +112,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         "match replace whole field 1",
         {
             "filter": "filter_this: does_not_matter",
-            "pseudonymizer": {"pseudonyms": {"pseudo_this": "RE_WHOLE_FIELD_CAP"}},
+            "pseudonymizer": {"mapping": {"pseudo_this": "RE_WHOLE_FIELD_CAP"}},
         },
         {
             "filter_this": "does_not_matter",
@@ -130,7 +130,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         "match replace whole field 2",
         {
             "filter": "filter_this: does_not_matter",
-            "pseudonymizer": {"pseudonyms": {"pseudo_this": "RE_WHOLE_FIELD_EMPTY_CAPS"}},
+            "pseudonymizer": {"mapping": {"pseudo_this": "RE_WHOLE_FIELD_EMPTY_CAPS"}},
         },
         {
             "filter_this": "does_not_matter",
@@ -148,7 +148,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         "match_capture_group_surrounded",
         {
             "filter": "filter_this: does_not_matter",
-            "pseudonymizer": {"pseudonyms": {"pseudo_this": "RE_CAP"}},
+            "pseudonymizer": {"mapping": {"pseudo_this": "RE_CAP"}},
         },
         {
             "filter_this": "does_not_matter",
@@ -168,7 +168,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         "match_capture_group_right",
         {
             "filter": "filter_this: does_not_matter",
-            "pseudonymizer": {"pseudonyms": {"pseudo_this": "RE_PATTERN_CAP"}},
+            "pseudonymizer": {"mapping": {"pseudo_this": "RE_PATTERN_CAP"}},
         },
         {
             "filter_this": "does_not_matter",
@@ -187,7 +187,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         "match_capture_group_left",
         {
             "filter": "filter_this: does_not_matter",
-            "pseudonymizer": {"pseudonyms": {"pseudo_this": "RE_CAP_PATTERN"}},
+            "pseudonymizer": {"mapping": {"pseudo_this": "RE_CAP_PATTERN"}},
         },
         {
             "filter_this": "does_not_matter",
@@ -206,7 +206,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         "match_two_capture_groups_covering_match",
         {
             "filter": "filter_this: does_not_matter",
-            "pseudonymizer": {"pseudonyms": {"pseudo_this": "RE_TWO_CAPS"}},
+            "pseudonymizer": {"mapping": {"pseudo_this": "RE_TWO_CAPS"}},
         },
         {
             "filter_this": "does_not_matter",
@@ -225,7 +225,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         "match_two_capture_groups_with_gap",
         {
             "filter": "filter_this: does_not_matter",
-            "pseudonymizer": {"pseudonyms": {"pseudo_this": "RE_TWO_CAPS_WITH_GAP"}},
+            "pseudonymizer": {"mapping": {"pseudo_this": "RE_TWO_CAPS_WITH_GAP"}},
         },
         {
             "filter_this": "does_not_matter",
@@ -246,7 +246,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_ALL_NO_CAP"},
+                "mapping": {"pseudo_this": "RE_ALL_NO_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -269,7 +269,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_ALL_NO_CAP"},
+                "mapping": {"pseudo_this": "RE_ALL_NO_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -291,7 +291,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_ALL_NO_CAP"},
+                "mapping": {"pseudo_this": "RE_ALL_NO_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -313,7 +313,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_ALL_NO_CAP"},
+                "mapping": {"pseudo_this": "RE_ALL_NO_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -337,7 +337,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_ALL_NO_CAP"},
+                "mapping": {"pseudo_this": "RE_ALL_NO_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -363,7 +363,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_ALL_NO_CAP"},
+                "mapping": {"pseudo_this": "RE_ALL_NO_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -386,7 +386,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_ALL_NO_CAP"},
+                "mapping": {"pseudo_this": "RE_ALL_NO_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -412,7 +412,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_ALL_NO_CAP"},
+                "mapping": {"pseudo_this": "RE_ALL_NO_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -439,7 +439,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_ALL_NO_CAP"},
+                "mapping": {"pseudo_this": "RE_ALL_NO_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -464,7 +464,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_ALL_NO_CAP"},
+                "mapping": {"pseudo_this": "RE_ALL_NO_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -486,7 +486,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_ALL_NO_CAP"},
+                "mapping": {"pseudo_this": "RE_ALL_NO_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -512,7 +512,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_ALL_NO_CAP"},
+                "mapping": {"pseudo_this": "RE_ALL_NO_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -534,7 +534,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_ALL_NO_CAP"},
+                "mapping": {"pseudo_this": "RE_ALL_NO_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -557,7 +557,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {
+                "mapping": {
                     "pseudo_this": "RE_ALL_NO_CAP",
                     "and_pseudo_this": "RE_ALL_NO_CAP",
                 },
@@ -589,7 +589,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {"pseudo_this": "RE_CAP"},
+                "mapping": {"pseudo_this": "RE_CAP"},
                 "url_fields": ["pseudo_this"],
             },
         },
@@ -614,7 +614,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "pseudo_this",
             "pseudonymizer": {
-                "pseudonyms": {
+                "mapping": {
                     "pseudo_this": "RE_WHOLE_FIELD",
                 }
             },
@@ -634,7 +634,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "pseudo_this",
             "pseudonymizer": {
-                "pseudonyms": {
+                "mapping": {
                     "pseudo_this": "RE_WHOLE_FIELD",
                 }
             },
@@ -655,7 +655,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "pseudo_this",
             "pseudonymizer": {
-                "pseudonyms": {
+                "mapping": {
                     "pseudo_this": "RE_WHOLE_FIELD",
                 }
             },
@@ -676,7 +676,7 @@ test_cases = [  # testcase, rule, event, expected, regex_mapping
         {
             "filter": "pseudo_this",
             "pseudonymizer": {
-                "pseudonyms": {
+                "mapping": {
                     "pseudo_this": "RE_DOMAIN_BACKSLASH_USERNAME",
                 }
             },
@@ -702,9 +702,8 @@ class TestPseudonymizer(BaseProcessorTestCase):
         "pubkey_analyst": "tests/testdata/unit/pseudonymizer/example_analyst_pub.pem",
         "pubkey_depseudo": "tests/testdata/unit/pseudonymizer/example_depseudo_pub.pem",
         "hash_salt": "a_secret_tasty_ingredient",
-        "specific_rules": ["tests/testdata/unit/pseudonymizer/rules/specific/"],
-        "generic_rules": ["tests/testdata/unit/pseudonymizer/rules/generic/"],
-        "regex_mapping": "tests/testdata/unit/pseudonymizer/rules/regex_mapping.yml",
+        "rules": ["tests/testdata/unit/pseudonymizer/rules"],
+        "regex_mapping": "tests/testdata/unit/pseudonymizer/regex_mapping.yml",
         "max_cached_pseudonyms": 1000000,
     }
 
@@ -724,7 +723,7 @@ class TestPseudonymizer(BaseProcessorTestCase):
         "config_change, error, msg",
         [
             ({"outputs": [{"kafka": "topic"}]}, None, None),
-            ({"outputs": []}, ValueError, "Length of 'outputs' must be => 1"),
+            ({"outputs": []}, ValueError, "Length of 'outputs' must be >= 1: 0"),
             (
                 {"outputs": [{"kafka": 1}]},
                 TypeError,
@@ -747,32 +746,24 @@ class TestPseudonymizer(BaseProcessorTestCase):
         config |= config_change
         if error:
             with pytest.raises(error, match=msg):
-                Factory.create({"name": config}, self.logger)
+                Factory.create({"name": config})
         else:
-            Factory.create({"name": config}, self.logger)
+            Factory.create({"name": config})
 
     @pytest.mark.parametrize("testcase, rule, event, expected, regex_mapping", test_cases)
     def test_testcases(self, testcase, rule, event, expected, regex_mapping):
         if regex_mapping is not None:
             self.regex_mapping = regex_mapping
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         self.object.process(event)
         assert event == expected, testcase
 
-    def test_tld_extractor_uses_file(self):
+    def _load_rule(self, rule):
         config = deepcopy(self.CONFIG)
-        config["tld_lists"] = [TLD_LIST]
-        object_with_tld_list = Factory.create({"pseudonymizer": config}, self.logger)
-        assert len(object_with_tld_list._tld_extractor.suffix_list_urls) == 1
-        assert object_with_tld_list._tld_extractor.suffix_list_urls[0].endswith(
-            "tests/testdata/mock_external/tld_list.dat",
-        )
-
-    def _load_specific_rule(self, rule):
-        self.object._config.regex_mapping = self.regex_mapping
-        del self.object.__dict__["_regex_mapping"]
-        super()._load_specific_rule(rule)
-        self.object._replace_regex_keywords_by_regex_expression()
+        config["regex_mapping"] = self.regex_mapping
+        self.object = Factory.create({"pseudonymizer": config})
+        super()._load_rule(rule)
+        self.object.setup()
 
     def test_pseudonymize_url_fields_not_in_pseudonymize(self):
         pseudonym = "<pseudonym:d95ac3629be3245d3f5e836c059516ad04081d513d2888f546b783d178b02e5a>"
@@ -786,11 +777,11 @@ class TestPseudonymizer(BaseProcessorTestCase):
         }
         rule = {
             "filter": "filter_this: does_not_matter",
-            "pseudonymizer": {"pseudonyms": {"pseudo_this": regex_pattern}},
+            "pseudonymizer": {"mapping": {"pseudo_this": regex_pattern}},
             "url_fields": ["do_not_pseudo_this"],
         }
         self.regex_mapping = "tests/testdata/unit/pseudonymizer/pseudonymizer_regex_mapping.yml"
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         self.object.process(event)
 
         assert event["do_not_pseudo_this"] == url
@@ -799,27 +790,25 @@ class TestPseudonymizer(BaseProcessorTestCase):
     def test_replace_regex_keywords_by_regex_expression_is_idempotent(self):
         rule_dict = {
             "filter": "event_id: 1234",
-            "pseudonymizer": {"pseudonyms": {"something": "RE_WHOLE_FIELD"}},
+            "pseudonymizer": {"mapping": {"something": "RE_WHOLE_FIELD"}},
             "description": "description content irrelevant for these tests",
         }
-        self._load_specific_rule(rule_dict)  # First call
+        self._load_rule(rule_dict)  # First call
         expected_pattern = re.compile("(.*)")
-        assert self.object._specific_tree.rules[0].pseudonyms == {"something": expected_pattern}
+        assert self.object._rule_tree.rules[0].pseudonyms == {"something": expected_pattern}
         self.object._replace_regex_keywords_by_regex_expression()  # Second Call
-        assert self.object._specific_tree.rules[0].pseudonyms == {"something": expected_pattern}
+        assert self.object._rule_tree.rules[0].pseudonyms == {"something": expected_pattern}
 
     def test_pseudonymize_string_adds_pseudonyms(self):
+        self.object.result = ProcessorResult(processor_name="test")
         assert self.object._pseudonymize_string("foo").startswith("<pseudonym:")
-        assert len(self.object.pseudonyms) == 1
+        assert len(self.object.result.data) == 1
 
     def test_resolve_from_cache_pseudonym(self):
-        self.object.metrics.new_results = 0
-        self.object.metrics.cached_results = 0
-        self.object.metrics.num_cache_entries = 0
         rule_dict = {
             "filter": "winlog.event_id: 1234 AND winlog.provider_name: Test456",
             "pseudonymizer": {
-                "pseudonyms": {
+                "mapping": {
                     "winlog.event_data.param1": "RE_WHOLE_FIELD",
                     "winlog.event_data.param2": "RE_WHOLE_FIELD",
                 }
@@ -835,20 +824,20 @@ class TestPseudonymizer(BaseProcessorTestCase):
                 },
             }
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
+        self.object.metrics.new_results = 0
+        self.object.metrics.cached_results = 0
+        self.object.metrics.num_cache_entries = 0
         self.object.process(event)
         assert self.object.metrics.new_results == 1
         assert self.object.metrics.cached_results == 1
         assert self.object.metrics.num_cache_entries == 1
 
     def test_resolve_from_cache_pseudonymize_urls(self):
-        self.object.metrics.new_results = 0
-        self.object.metrics.cached_results = 0
-        self.object.metrics.num_cache_entries = 0
         rule_dict = {
             "filter": "filter_this: does_not_matter",
             "pseudonymizer": {
-                "pseudonyms": {
+                "mapping": {
                     "pseudo_this": "RE_ALL_NO_CAP",
                     "and_pseudo_this": "RE_ALL_NO_CAP",
                 },
@@ -860,7 +849,10 @@ class TestPseudonymizer(BaseProcessorTestCase):
             "pseudo_this": "https://www.pseudo.this.de",
             "and_pseudo_this": "https://www.pseudo.this.de",
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
+        self.object.metrics.new_results = 0
+        self.object.metrics.cached_results = 0
+        self.object.metrics.num_cache_entries = 0
         self.object.process(event)
         # 1 subdomains -> pseudonym_cache, 1 url -> url_cache
         assert self.object.metrics.new_results == 2
@@ -885,7 +877,6 @@ class TestPseudonymizer(BaseProcessorTestCase):
             ),
             (
                 "https://test.de/?a=b&c=d",
-                # nosemgrep
                 (
                     "https://test.de/?a="
                     "<pseudonym:4c77fcd97a3d4d98eb062561c37e4ef000f0476bdf153b25ba8031f90ac89877>"
@@ -895,7 +886,6 @@ class TestPseudonymizer(BaseProcessorTestCase):
             ),
             (
                 "https://test.de/#test",
-                # nosemgrep
                 (
                     "https://test.de/#"
                     "<pseudonym:d95ac3629be3245d3f5e836c059516ad04081d513d2888f546b783d178b02e5a>"
@@ -904,13 +894,14 @@ class TestPseudonymizer(BaseProcessorTestCase):
         ],
     )
     def test_pseudonymize_url(self, url, expected):
+        self.object.result = ProcessorResult(processor_name="test")
         assert self.object._pseudonymize_url(url) == expected
 
     def test_process_returns_extra_output(self):
         rule_dict = {
             "filter": "winlog.event_id: 1234 AND winlog.provider_name: Test456",
             "pseudonymizer": {
-                "pseudonyms": {
+                "mapping": {
                     "winlog.event_data.param1": "RE_WHOLE_FIELD",
                 }
             },
@@ -925,19 +916,19 @@ class TestPseudonymizer(BaseProcessorTestCase):
                 },
             },
         }
-        self._load_specific_rule(rule_dict)  # First call
+        self._load_rule(rule_dict)  # First call
         extra_output = self.object.process(event)
-        assert extra_output
-        assert isinstance(extra_output, tuple)
-        assert len(extra_output) == 2
-        assert isinstance(extra_output[0], list)
-        assert isinstance(extra_output[1], tuple)
-        assert isinstance(extra_output[1][0], dict)
-        assert extra_output[1][0] == {"kafka": "topic"}, "Output is set as in CONFIG"
-        assert len(extra_output[0]) == 1, "Should contain only one pseudonym"
-        assert extra_output[0][0].get("pseudonym"), "pseudonym is set"
-        assert extra_output[0][0].get("origin"), "encrypted original is set"
-        assert extra_output[0][0].get("@timestamp"), "timestamp is set if present in event"
+        assert extra_output.data
+        assert isinstance(extra_output.data, list)
+        assert isinstance(extra_output, ProcessorResult)
+        assert isinstance(extra_output.data[0], tuple)
+        assert isinstance(extra_output.data[0][0], dict)
+        assert isinstance(extra_output.data[0][1], tuple)
+        assert extra_output.data[0][1] == ({"kafka": "topic"},), "Output is set as in CONFIG"
+        assert len(extra_output.data) == 1, "Should contain only one pseudonym"
+        assert extra_output.data[0][0].get("pseudonym"), "pseudonym is set"
+        assert extra_output.data[0][0].get("origin"), "encrypted original is set"
+        assert extra_output.data[0][0].get("@timestamp"), "timestamp is set if present in event"
 
     def test_extra_output_contains_only_one_pseudonym_even_if_pseudonym_appears_multiple_times_in_event(
         self,
@@ -945,7 +936,7 @@ class TestPseudonymizer(BaseProcessorTestCase):
         rule_dict = {
             "filter": "winlog.event_id: 1234 AND winlog.provider_name: Test456",
             "pseudonymizer": {
-                "pseudonyms": {
+                "mapping": {
                     "winlog.event_data.param1": "RE_WHOLE_FIELD",
                     "winlog.event_data.param2": "RE_WHOLE_FIELD",
                 }
@@ -962,27 +953,28 @@ class TestPseudonymizer(BaseProcessorTestCase):
                 },
             },
         }
-        self._load_specific_rule(rule_dict)  # First call
+        self._load_rule(rule_dict)  # First call
         extra_output = self.object.process(event)
         assert extra_output
-        assert isinstance(extra_output, tuple)
-        assert len(extra_output) == 2
-        assert isinstance(extra_output[0], list)
-        assert isinstance(extra_output[1], tuple)
-        assert isinstance(extra_output[1][0], dict)
-        assert extra_output[1][0] == {"kafka": "topic"}, "Output is set as in CONFIG"
+        assert isinstance(extra_output.data, list)
+        assert len(extra_output.data[0]) == 2
+        assert isinstance(extra_output.data[0], tuple)
+        assert isinstance(extra_output.data[0][0], dict)
+        assert isinstance(extra_output.data[0][1], tuple)
+        assert isinstance(extra_output.data[0][1][0], dict)
+        assert extra_output.data[0][1] == ({"kafka": "topic"},), "Output is set as in CONFIG"
         assert (
-            len(extra_output[0]) == 1
+            len(extra_output.data) == 1
         ), "Should contain only one pseudonym, as the value for both is the same"
-        assert extra_output[0][0].get("pseudonym"), "pseudonym is set"
-        assert extra_output[0][0].get("origin"), "encrypted original is set"
-        assert extra_output[0][0].get("@timestamp"), "timestamp is set if present in event"
+        assert extra_output.data[0][0].get("pseudonym"), "pseudonym is set"
+        assert extra_output.data[0][0].get("origin"), "encrypted original is set"
+        assert extra_output.data[0][0].get("@timestamp"), "timestamp is set if present in event"
 
     def test_extra_output_contains_different_pseudonyms_for_different_values(self):
         rule_dict = {
             "filter": "winlog.event_id: 1234 AND winlog.provider_name: Test456",
             "pseudonymizer": {
-                "pseudonyms": {
+                "mapping": {
                     "winlog.event_data.param1": "RE_WHOLE_FIELD",
                     "winlog.event_data.param2": "RE_WHOLE_FIELD",
                 }
@@ -999,34 +991,38 @@ class TestPseudonymizer(BaseProcessorTestCase):
                 },
             },
         }
-        self._load_specific_rule(rule_dict)  # First call
+        self._load_rule(rule_dict)  # First call
         extra_output = self.object.process(event)
-        assert extra_output
-        assert isinstance(extra_output, tuple)
-        assert len(extra_output) == 2
-        assert isinstance(extra_output[0], list)
-        assert isinstance(extra_output[1], tuple)
-        assert isinstance(extra_output[1][0], dict)
-        assert extra_output[1][0] == {"kafka": "topic"}, "Output is set as in CONFIG"
-        assert len(extra_output[0]) == 2, "Should contain two pseudonyms, for each value one"
-        assert extra_output[0][0].get("pseudonym"), "pseudonym is set"
-        assert extra_output[0][0].get("origin"), "encrypted original is set"
-        assert extra_output[0][0].get("@timestamp"), "timestamp is set if present in event"
-        assert extra_output[0][1].get("pseudonym"), "pseudonym is set"
-        assert extra_output[0][1].get("origin"), "encrypted original is set"
-        assert extra_output[0][1].get("@timestamp"), "timestamp is set if present in event"
-        assert extra_output[0][0].get("pseudonym") != extra_output[0][1].get(
+        assert extra_output.data
+        assert isinstance(extra_output.data, list)
+        assert len(extra_output.data) == 2
+        assert isinstance(extra_output.data[0], tuple)  # First item of extra_output
+        assert isinstance(extra_output.data[0][0], dict)  # Pseudonym
+        assert isinstance(extra_output.data[0][1], tuple)  # Outputs
+        assert isinstance(extra_output.data[0][1][0], dict)  # Output
+        assert extra_output.data[0][1] == ({"kafka": "topic"},), "Output is set as in CONFIG"
+        assert len(extra_output.data) == 2, "Should contain two pseudonyms, for each value one"
+
+        pseudonym_1 = extra_output.data[0][0]
+        assert pseudonym_1.get("pseudonym"), "pseudonym is set"
+        assert pseudonym_1.get("origin"), "encrypted original is set"
+        assert pseudonym_1.get("@timestamp"), "timestamp is set if present in event"
+
+        pseudonym_2 = extra_output.data[1][0]
+        assert pseudonym_2.get("pseudonym"), "pseudonym is set"
+        assert pseudonym_2.get("origin"), "encrypted original is set"
+        assert pseudonym_2.get("@timestamp"), "timestamp is set if present in event"
+
+        assert pseudonym_1.get("pseudonym") != pseudonym_2.get(
             "pseudonym"
         ), "pseudonyms should differ"
-        assert extra_output[0][0].get("origin") != extra_output[0][1].get(
-            "origin"
-        ), "origins should differ"
+        assert pseudonym_1.get("origin") != pseudonym_2.get("origin"), "origins should differ"
 
-    def test_ignores_missing_field(self):
+    def test_ignores_missing_field_but_add_warning(self):
         rule_dict = {
             "filter": "winlog.event_id: 1234 AND winlog.provider_name: Test456",
             "pseudonymizer": {
-                "pseudonyms": {
+                "mapping": {
                     "does_not_exists": "RE_WHOLE_FIELD",
                     "winlog.event_data.param2": "RE_WHOLE_FIELD",
                 }
@@ -1043,7 +1039,69 @@ class TestPseudonymizer(BaseProcessorTestCase):
                 },
             },
         }
-        self._load_specific_rule(rule_dict)
+        self._load_rule(rule_dict)
         extra_output = self.object.process(event)
-        assert extra_output[0][0].get("pseudonym"), "pseudonym is set"
-        assert len(extra_output[1]) == 1, "only ONE pseudonym is set"
+        assert extra_output.data[0][0].get("pseudonym"), "pseudonym is set"
+        assert "_pseudonymizer_missing_field_warning" in event.get("tags", [])
+        assert len(extra_output.data) == 1, "only ONE pseudonym is set"
+
+    @pytest.mark.parametrize(
+        "mode, encrypter_class",
+        [("CTR", DualPKCS1HybridCTREncrypter), ("GCM", DualPKCS1HybridGCMEncrypter)],
+    )
+    def test_uses_encrypter(self, mode, encrypter_class):
+        config = deepcopy(self.CONFIG)
+        config["mode"] = mode
+        object_with_encrypter = Factory.create({"pseudonymizer": config})
+        assert isinstance(object_with_encrypter._encrypter, encrypter_class)
+
+    def test_setup_raises_invalid_configuration_on_missing_regex_mapping(self):
+        rule_dict = {
+            "filter": "winlog.event_id: 1234 AND winlog.provider_name: Test456",
+            "pseudonymizer": {
+                "mapping": {
+                    "winlog.event_data.param2": "RE_WHOLE_FIELD",
+                }
+            },
+        }
+        self._load_rule(rule_dict)
+        self.object.rules[0].mapping["winlog.event_data.param2"] = "RE_DOES_NOT_EXIST"
+        error_message = (
+            r"Regex keyword 'RE_DOES_NOT_EXIST' not found in regex_mapping '.*\/regex_mapping.yml'"
+        )
+        with pytest.raises(InvalidConfigurationError, match=error_message):
+            self.object.setup()
+
+    def test_cache_metrics_updated(self):
+        rule_dict = {
+            "filter": "winlog.event_id: 1234 AND winlog.provider_name: Test456",
+            "pseudonymizer": {
+                "mapping": {
+                    "winlog.event_data.param1": "RE_WHOLE_FIELD",
+                }
+            },
+        }
+        event = {
+            "@timestamp": "custom timestamp",
+            "winlog": {
+                "event_id": 1234,
+                "provider_name": "Test456",
+                "event_data": {
+                    "param1": "Pseudonymize me - appears twice!",
+                },
+            },
+        }
+        self._load_rule(rule_dict)
+
+        self.object.metrics.new_results = 0
+        self.object.metrics.cached_results = 0
+        self.object.metrics.num_cache_entries = 0
+
+        self.object.process(deepcopy(event))
+        self.object.process(deepcopy(event))
+        self.object.process(event)
+        # because the event is the same, the result is cached
+        # metrics are mocked by integers and incremented by cache_info results
+        assert self.object.metrics.new_results == 3
+        assert self.object.metrics.cached_results == 3
+        assert self.object.metrics.num_cache_entries == 3
