@@ -6,12 +6,12 @@ from logprep.processor.base.exceptions import InvalidRuleDefinitionError
 from logprep.processor.pseudonymizer.rule import PseudonymizerRule
 
 
-@pytest.fixture(name="specific_rule_definition")
-def get_specific_rule_definition():
+@pytest.fixture(name="rule_definition")
+def get_rule_definition():
     return {
         "filter": 'winlog.event_id: 123 AND source_name: "Test123"',
         "pseudonymizer": {
-            "pseudonyms": {
+            "mapping": {
                 "winlog.event_data.param1": "RE_WHOLE_FIELD",
                 "winlog.event_data.param2": "RE_WHOLE_FIELD",
             }
@@ -35,14 +35,14 @@ class TestPseudonomyzerRule:
                 "config is not a dict",
             ),
             (
-                {"filter": "message", "pseudonymizer": {"pseudonyms": {}}},
+                {"filter": "message", "pseudonymizer": {"mapping": {}}},
                 ValueError,
-                "Length of 'pseudonyms' must be => 1",
+                "Length of 'mapping' must be >= 1: 0",
             ),
             (
                 {
                     "filter": "message",
-                    "pseudonymizer": {"pseudonyms": {"field": "regex"}},
+                    "pseudonymizer": {"mapping": {"field": "regex"}},
                 },
                 None,
                 None,
@@ -52,9 +52,9 @@ class TestPseudonomyzerRule:
     def test_create_from_dict_validates_config(self, rule, error, message):
         if error:
             with pytest.raises(error, match=message):
-                PseudonymizerRule._create_from_dict(rule)
+                PseudonymizerRule.create_from_dict(rule)
         else:
-            rule_instance = PseudonymizerRule._create_from_dict(rule)
+            rule_instance = PseudonymizerRule.create_from_dict(rule)
             assert hasattr(rule_instance, "_config")
             for key, value in rule.get("pseudonymizer").items():
                 assert hasattr(rule_instance._config, key)
@@ -68,7 +68,7 @@ class TestPseudonomyzerRule:
                 {
                     "filter": 'winlog.event_id: 123 AND source_name: "Test123"',
                     "pseudonymizer": {
-                        "pseudonyms": {
+                        "mapping": {
                             "winlog.event_data.param1": "RE_WHOLE_FIELD",
                             "winlog.event_data.param2": "RE_WHOLE_FIELD",
                         }
@@ -82,7 +82,7 @@ class TestPseudonomyzerRule:
                 {
                     "filter": "otherfilter",
                     "pseudonymizer": {
-                        "pseudonyms": {
+                        "mapping": {
                             "winlog.event_data.param1": "RE_WHOLE_FIELD",
                             "winlog.event_data.param2": "RE_WHOLE_FIELD",
                         }
@@ -96,7 +96,7 @@ class TestPseudonomyzerRule:
                 {
                     "filter": 'winlog.event_id: 123 AND source_name: "Test123"',
                     "pseudonymizer": {
-                        "pseudonyms": {
+                        "mapping": {
                             "winlog.event_data.param1": "RE_WHOLE_FIELD",
                             "winlog.event_data.paramother": "RE_WHOLE_FIELD",
                         }
@@ -107,9 +107,7 @@ class TestPseudonomyzerRule:
             ),
         ],
     )
-    def test_rules_equality(
-        self, specific_rule_definition, testcase, other_rule_definition, is_equal
-    ):
-        rule_1 = PseudonymizerRule._create_from_dict(specific_rule_definition)
-        rule_2 = PseudonymizerRule._create_from_dict(other_rule_definition)
+    def test_rules_equality(self, rule_definition, testcase, other_rule_definition, is_equal):
+        rule_1 = PseudonymizerRule.create_from_dict(rule_definition)
+        rule_2 = PseudonymizerRule.create_from_dict(other_rule_definition)
         assert (rule_1 == rule_2) == is_equal, testcase
