@@ -1,5 +1,4 @@
 # pylint: disable=missing-docstring
-import logging
 import re
 
 import pytest
@@ -172,6 +171,27 @@ test_cases = [
             "status": 200,
         },
     ),
+    (
+        "use target_field and target_field_mapping at the same time, with error in target_field",
+        {
+            "filter": "message",
+            "requester": {
+                "url": "http://mock-mock/",
+                "method": "GET",
+                "target_field": "message",  # will fail as it is already present
+                "target_field_mapping": {"key1.key2.key3": "result.custom"},
+            },
+        },
+        {"message": "the message"},
+        {"message": "the message", "result": {"custom": "value"}, "tags": ["_requester_failure"]},
+        {
+            "method": "GET",
+            "url": "http://mock-mock/",
+            "json": {"key1": {"key2": {"key3": "value"}}},
+            "content_type": "text/plain",
+            "status": 200,
+        },
+    ),
     (
         "parses json result with simple target field mapping and overwrite target",
         {
@@ -257,6 +277,28 @@ test_cases = [
             "status": 200,
         },
     ),
+    (
+        "merge response with existing dict",
+        {
+            "filter": "data",
+            "requester": {
+                "url": "http://localhost/",
+                "method": "GET",
+                "target_field": "data",
+                "delete_source_fields": True,
+                "merge_with_target": True,
+            },
+        },
+        {"data": {"existing": "data"}},
+        {"data": {"existing": "data", "new-data": {"dict": "value"}}},
+        {
+            "method": "GET",
+            "url": "http://localhost/",
+            "json": {"new-data": {"dict": "value"}},
+            "content_type": "text/plain",
+            "status": 200,
+        },
+    ),
 ]  # testcase, rule, event, expected, response
 
 failure_test_cases = [
@@ -319,7 +361,7 @@ failure_test_cases = [
             "requester": {"url": "http://${missingfield}", "method": "GET"},
         },
         {"message": "the message"},
-        {"message": "the message", "tags": ["_requester_failure"]},
+        {"message": "the message", "tags": ["_requester_missing_field_warning"]},
         {},
         ".*ProcessingWarning.*",
     ),
@@ -329,15 +371,14 @@ failure_test_cases = [
 class TestRequester(BaseProcessorTestCase):
     CONFIG: dict = {
         "type": "requester",
-        "specific_rules": ["tests/testdata/unit/requester/specific_rules"],
-        "generic_rules": ["tests/testdata/unit/requester/generic_rules"],
+        "rules": ["tests/testdata/unit/requester/rules"],
     }
 
     @responses.activate
     @pytest.mark.parametrize("testcase, rule, event, expected, response_kwargs", test_cases)
     def test_testcases(self, testcase, rule, event, expected, response_kwargs):
         responses.add(responses.Response(**response_kwargs))
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         self.object.process(event)
         assert event == expected, testcase
 
@@ -346,12 +387,12 @@ class TestRequester(BaseProcessorTestCase):
         "testcase, rule, event, expected, response_kwargs, error_message", failure_test_cases
     )
     def test_requester_testcases_failure_handling(
-        self, testcase, rule, event, expected, response_kwargs, error_message, caplog
+        self, testcase, rule, event, expected, response_kwargs, error_message
     ):
         if response_kwargs:
             responses.add(responses.Response(**response_kwargs))
-        self._load_specific_rule(rule)
-        with caplog.at_level(logging.WARNING):
-            self.object.process(event)
-        assert re.match(error_message, caplog.text)
+        self._load_rule(rule)
+        result = self.object.process(event)
+        assert len(result.warnings) == 1
+        assert re.match(error_message, str(result.warnings[0]))
         assert event == expected, testcase
