@@ -4,18 +4,18 @@
 
 from typing import Hashable
 from unittest import mock
+
 import pytest
 
 from logprep.processor.base.exceptions import InvalidRuleDefinitionError
-from logprep.factory_error import InvalidConfigurationError
 from logprep.processor.selective_extractor.rule import (
     SelectiveExtractorRule,
     SelectiveExtractorRuleError,
 )
 
 
-@pytest.fixture(name="specific_rule_definition")
-def fixture_specific_rule_definition():
+@pytest.fixture(name="rule_definition")
+def fixture_rule_definition():
     return {
         "filter": "test",
         "selective_extractor": {
@@ -38,7 +38,7 @@ class TestSelectiveExtractorRule:
         }
         read_lines = b"test1\r\ntest2"
         with mock.patch("pathlib.Path.read_bytes", return_value=read_lines):
-            rule = SelectiveExtractorRule._create_from_dict(rule_definition)
+            rule = SelectiveExtractorRule.create_from_dict(rule_definition)
             extracted_field_list = rule.extracted_field_list
             assert rule._config.extract_from_file == "my/file"
             assert "test1" in extracted_field_list
@@ -54,7 +54,7 @@ class TestSelectiveExtractorRule:
             },
         }
         with pytest.raises(SelectiveExtractorRuleError):
-            _ = SelectiveExtractorRule._create_from_dict(rule_definition)
+            _ = SelectiveExtractorRule.create_from_dict(rule_definition)
 
     @pytest.mark.parametrize(
         "testcase, other_rule_definition, is_equal",
@@ -173,17 +173,15 @@ class TestSelectiveExtractorRule:
             ),
         ],
     )
-    def test_rules_equality(
-        self, specific_rule_definition, testcase, other_rule_definition, is_equal
-    ):
+    def test_rules_equality(self, rule_definition, testcase, other_rule_definition, is_equal):
         with mock.patch("pathlib.Path.is_file", return_value=True):
             read_lines = other_rule_definition.get("selective_extractor").get("extract_from_file")
             if read_lines is not None:
                 read_lines = read_lines.encode("utf8")
 
             with mock.patch("pathlib.Path.read_bytes", return_value=read_lines):
-                rule1 = SelectiveExtractorRule._create_from_dict(specific_rule_definition)
-                rule2 = SelectiveExtractorRule._create_from_dict(other_rule_definition)
+                rule1 = SelectiveExtractorRule.create_from_dict(rule_definition)
+                rule2 = SelectiveExtractorRule.create_from_dict(other_rule_definition)
                 assert (rule1 == rule2) == is_equal, testcase
 
     @pytest.mark.parametrize(
@@ -282,12 +280,12 @@ class TestSelectiveExtractorRule:
                     "selective_extractor": {
                         "source_fields": ["field1"],
                         "outputs": [{"kafka": "topic"}],
-                        "extend_target_list": True,
+                        "merge_with_target": True,
                     },
                 },
                 b"",
                 TypeError,
-                "got an unexpected keyword argument 'extend_target_list'",
+                "got an unexpected keyword argument 'merge_with_target'",
             ),
         ],
     )
@@ -296,11 +294,11 @@ class TestSelectiveExtractorRule:
             with mock.patch("pathlib.Path.read_bytes", return_value=read_lines):
                 if raised:
                     with pytest.raises(raised, match=message):
-                        _ = SelectiveExtractorRule._create_from_dict(rule_definition)
+                        _ = SelectiveExtractorRule.create_from_dict(rule_definition)
                 else:
-                    extractor_rule = SelectiveExtractorRule._create_from_dict(rule_definition)
+                    extractor_rule = SelectiveExtractorRule.create_from_dict(rule_definition)
                     assert isinstance(extractor_rule, SelectiveExtractorRule)
 
-    def test_rule_is_hashable(self, specific_rule_definition):
-        rule = SelectiveExtractorRule._create_from_dict(specific_rule_definition)
+    def test_rule_is_hashable(self, rule_definition):
+        rule = SelectiveExtractorRule.create_from_dict(rule_definition)
         assert isinstance(rule, Hashable)
