@@ -1,5 +1,4 @@
 # pylint: disable=missing-docstring
-import logging
 import re
 
 import pytest
@@ -184,7 +183,7 @@ test_cases = [  # testcase, rule, event, expected
             "timestamp_differ": {
                 "diff": "${subfield.field2} - ${field1:%Y-%m-%d %H:%M:%S}",
                 "target_field": "time_diff",
-                "extend_target_list": True,
+                "merge_with_target": True,
             },
         },
         {
@@ -344,7 +343,7 @@ failure_test_cases = [  # testcase, rule, event, expected, error_message
             "subfield": {"field2": "2022-12-05 12:00:00"},
             "tags": ["_timestamp_differ_failure"],
         },
-        r".*ProcessingWarning.*Invalid character while parsing",
+        r".*ProcessingWarning.*Invalid isoformat string: 'non-timestamp'",
     ),
     (
         "diff between two timestamps with partial timestamp format match",
@@ -392,9 +391,9 @@ failure_test_cases = [  # testcase, rule, event, expected, error_message
         {"field1": "2022-12-05"},
         {
             "field1": "2022-12-05",
-            "tags": ["_timestamp_differ_failure"],
+            "tags": ["_timestamp_differ_missing_field_warning"],
         },
-        r".*ProcessingWarning.*no value for fields: \['subfield.field2'\]",
+        r".*ProcessingWarning.*missing source_fields: \['subfield.field2'\]",
     ),
     (
         "diff between two timestamps with non existing fields",
@@ -408,9 +407,9 @@ failure_test_cases = [  # testcase, rule, event, expected, error_message
         {"some_field": "some value"},
         {
             "some_field": "some value",
-            "tags": ["_timestamp_differ_failure"],
+            "tags": ["_timestamp_differ_missing_field_warning"],
         },
-        r".*ProcessingWarning.*no value for fields: \['subfield.field2', 'field1'\]",
+        r".*ProcessingWarning.*missing source_fields: \['subfield.field2', 'field1']",
     ),
     (
         "diff between two timestamps with already existing output field",
@@ -436,22 +435,19 @@ failure_test_cases = [  # testcase, rule, event, expected, error_message
 class TestTimestampDiffer(BaseProcessorTestCase):
     CONFIG: dict = {
         "type": "timestamp_differ",
-        "specific_rules": ["tests/testdata/unit/timestamp_differ/specific_rules"],
-        "generic_rules": ["tests/testdata/unit/timestamp_differ/generic_rules"],
+        "rules": ["tests/testdata/unit/timestamp_differ/rules"],
     }
 
     @pytest.mark.parametrize("testcase, rule, event, expected", test_cases)
     def test_testcases(self, testcase, rule, event, expected):
-        self._load_specific_rule(rule)
+        self._load_rule(rule)
         self.object.process(event)
         assert event == expected, testcase
 
     @pytest.mark.parametrize("testcase, rule, event, expected, error_message", failure_test_cases)
-    def test_testcases_failure_handling(
-        self, testcase, rule, event, expected, error_message, caplog
-    ):
-        self._load_specific_rule(rule)
-        with caplog.at_level(logging.WARNING):
-            self.object.process(event)
-        assert re.match(error_message, caplog.text)
+    def test_testcases_failure_handling(self, testcase, rule, event, expected, error_message):
+        self._load_rule(rule)
+        result = self.object.process(event)
+        assert len(result.warnings) == 1
+        assert re.match(error_message, str(result.warnings[0]))
         assert event == expected, testcase
